@@ -19,7 +19,7 @@
 #ifndef CMYK_PLUGIN_H_
 #define CMYK_PLUGIN_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 /**
  * A plugin wrapper around the CMYK colour space strategy.
@@ -27,7 +27,7 @@
 class CMYKPlugin : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     CMYKPlugin(TQObject *parent, const char *name, const TQStringList &);
     virtual ~CMYKPlugin();
