@@ -19,7 +19,7 @@
 #ifndef GRAY_U16_PLUGIN_H_
 #define GRAY_U16_PLUGIN_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 /**
  * A plugin wrapper around the GRAY U16 colour space strategy.
@@ -27,7 +27,7 @@
 class GRAYU16Plugin : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     GRAYU16Plugin(TQObject *parent, const char *name, const TQStringList &);
     virtual ~GRAYU16Plugin();
