@@ -19,7 +19,7 @@
 #ifndef RGB_PLUGIN_H_
 #define RGB_PLUGIN_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 /**
  * A plugin wrapper around the RGB colour space strategy.
@@ -27,7 +27,7 @@
 class RGBPlugin : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     RGBPlugin(TQObject *parent, const char *name, const TQStringList &);
     virtual ~RGBPlugin();
