@@ -19,7 +19,7 @@
 #ifndef WET_STICKY_PLUGIN_H_
 #define WET_STICKY_PLUGIN_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 /**
  * A plugin wrapper around the Wet & Sticky colour space strategy.
@@ -32,7 +32,7 @@
 class WetStickyPlugin : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     WetStickyPlugin(TQObject *parent, const char *name, const TQStringList &);
     virtual ~WetStickyPlugin();
