@@ -57,10 +57,10 @@ class KisRandomSubAccessorPixel;
 class KisUndoAdapter;
 class KisFilter;
 class KisDataManager;
-typedef KSharedPtr<KisDataManager> KisDataManagerSP;
+typedef TDESharedPtr<KisDataManager> KisDataManagerSP;
 
 class KisMemento;
-typedef KSharedPtr<KisMemento> KisMementoSP;
+typedef TDESharedPtr<KisMemento> KisMementoSP;
 
 
 /**
@@ -72,11 +72,11 @@ typedef KSharedPtr<KisMemento> KisMementoSP;
  */
 class KRITACORE_EXPORT KisPaintDevice
     : public TQObject
-    , public KShared
+    , public TDEShared
 {
 
         Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
 
