@@ -21,12 +21,12 @@
 #ifndef TOOL_BEZIER_H_
 #define TOOL_BEZIER_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class ToolCurves : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     ToolCurves(TQObject *parent, const char *name, const TQStringList &);
     virtual ~ToolCurves();
