@@ -19,7 +19,7 @@
 #ifndef TOOL_POLYGON_H_
 #define TOOL_POLYGON_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 /**
  * A module that provides a polygon tool.
@@ -27,7 +27,7 @@
 class ToolPolygon : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
 
