@@ -21,7 +21,7 @@
 #ifndef COLORSPACECONVERSION_H
 #define COLORSPACECONVERSION_H
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class KisView;
 
@@ -31,7 +31,7 @@ class KisView;
 class ColorSpaceConversion : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     ColorSpaceConversion(TQObject *parent, const char *name, const TQStringList &);
     virtual ~ColorSpaceConversion();
