@@ -20,7 +20,7 @@
 #ifndef _KIS_DROPSHADOW_PLUGIN_H_
 #define _KIS_DROPSHADOW_PLUGIN_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class KisView;
 
@@ -29,7 +29,7 @@ class KisView;
 class KisDropshadowPlugin : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     KisDropshadowPlugin(TQObject *parent, const char *name, const TQStringList &);
     virtual ~KisDropshadowPlugin();
