@@ -21,16 +21,16 @@
 #ifndef HISTOGRAM_H
 #define HISTOGRAM_H
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class KisView;
-class KAction;
+class TDEAction;
 class KisImage;
 
 class Histogram : public KParts::Plugin
 {
         Q_OBJECT
-  TQ_OBJECT
+  
     public:
         Histogram(TQObject *parent, const char *name, const TQStringList &);
         virtual ~Histogram();
@@ -43,7 +43,7 @@ class Histogram : public KParts::Plugin
         KisImage* m_img;
         KisView * m_view;
         KisPainter * m_painter;
-        KAction* m_action;
+        TDEAction* m_action;
 
 };
 
