@@ -20,14 +20,14 @@
 #ifndef MODIFY_SELECTION_H
 #define MODIFY_SELECTION_H
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class KisView;
 
 class ModifySelection : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     ModifySelection(TQObject *parent, const char *name, const TQStringList &);
     virtual ~ModifySelection();
