@@ -20,14 +20,14 @@
 #ifndef ROTATEIMAGE_H
 #define ROTATEIMAGE_H
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class KisView;
 
 class RotateImage : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     RotateImage(TQObject *parent, const char *name, const TQStringList &);
     virtual ~RotateImage();
