@@ -21,14 +21,14 @@
 #ifndef SELECTOPAQUE_H
 #define SELECTOPAQUE_H
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class KisView;
 
 class SelectOpaque : public KParts::Plugin
 {
         Q_OBJECT
-  TQ_OBJECT
+  
     public:
         SelectOpaque(TQObject *parent, const char *name, const TQStringList &);
         virtual ~SelectOpaque();
