@@ -28,11 +28,11 @@
 #include <tqcursor.h>
 
 #include <kdebug.h>
-#include <kglobalsettings.h>
-#include <kaction.h>
-#include <ktoolbar.h>
+#include <tdeglobalsettings.h>
+#include <tdeaction.h>
+#include <tdetoolbar.h>
 #include <knuminput.h>
-#include <klocale.h>
+#include <tdelocale.h>
 
 #include <KoDocument.h>
 
@@ -71,8 +71,8 @@ KoBirdEyePanel::KoBirdEyePanel( KoZoomAdapter * zoomListener,
     m_page->view->installEventFilter(this);
     m_page->view->setBackgroundMode(TQt::NoBackground);
 
-    m_zoomIn = new KAction( i18n("Zoom In"), "birdeye_zoom_plus", 0, TQT_TQOBJECT(this), TQT_SLOT(zoomPlus()), TQT_TQOBJECT(this), "zoomIn" );
-    m_zoomOut = new KAction( i18n("Zoom Out"), "birdeye_zoom_minus", 0, TQT_TQOBJECT(this), TQT_SLOT(zoomMinus()), TQT_TQOBJECT(this), "zoomOut" );
+    m_zoomIn = new TDEAction( i18n("Zoom In"), "birdeye_zoom_plus", 0, TQT_TQOBJECT(this), TQT_SLOT(zoomPlus()), TQT_TQOBJECT(this), "zoomIn" );
+    m_zoomOut = new TDEAction( i18n("Zoom Out"), "birdeye_zoom_minus", 0, TQT_TQOBJECT(this), TQT_SLOT(zoomMinus()), TQT_TQOBJECT(this), "zoomOut" );
 
     l->addWidget(m_page);
 
