@@ -22,7 +22,7 @@
 
 #include <KoView.h>
 
-class KAction;
+class TDEAction;
 class TQPaintEvent;
 
 class ExamplePart;
@@ -30,7 +30,7 @@ class ExamplePart;
 class ExampleView : public KoView
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     ExampleView( ExamplePart* part, TQWidget* parent = 0, const char* name = 0 );
 
@@ -44,7 +44,7 @@ protected:
     virtual void updateReadWrite( bool readwrite );
 
 private:
-    //KAction* m_cut;
+    //TDEAction* m_cut;
 };
 
 #endif
