@@ -23,14 +23,14 @@
 
 #include <tqstring.h>
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 /**
  */
 class ImageToolPlugin : public KParts::Plugin
 {
 	Q_OBJECT
-  TQ_OBJECT
+  
 public:
 	ImageToolPlugin(TQObject *parent, const char *name, const TQStringList &);
 	virtual ~ImageToolPlugin();
