@@ -23,7 +23,7 @@
 
 #include <tqstring.h>
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 /**
  * A module that provides the default tools
@@ -31,7 +31,7 @@
 class VDefaultTools : public KParts::Plugin
 {
 	Q_OBJECT
-  TQ_OBJECT
+  
 public:
 	VDefaultTools(TQObject *parent, const char *name, const TQStringList &);
 	virtual ~VDefaultTools();
