@@ -101,24 +101,18 @@
 #endif // Q_OS_TEMP
 #endif // TQT_NO_COMPAT
 
-#define TQPtrList TQList
-#define TQPtrListIterator TQListIterator
-#define TQPtrVector TQVector
 #define TQMemArray TQArray
 
-#include <tqlist.h>
-#include <tqvector.h>
 #include <tqarray.h>
 
 #else
 
-#include <tqptrlist.h>
-#include <tqptrvector.h>
 #include <tqmemarray.h>
 
 #endif
 // end of #if COMPAT_TQT_VERSION < 0x030000
 
-
+#include <tqptrlist.h>
+#include <tqptrvector.h>
 
 #endif
