@@ -25,12 +25,12 @@
 class KexiActionProxy;
 
 //! Helper class for KexiActionProxy::plugSharedActionToExternalGUI() method.
-class KAction_setEnabled_Helper : public TQObject
+class TDEAction_setEnabled_Helper : public TQObject
 {
 	Q_OBJECT
-  TQ_OBJECT
+  
 	public:
-		KAction_setEnabled_Helper(KexiActionProxy* proxy);
+		TDEAction_setEnabled_Helper(KexiActionProxy* proxy);
 
 	public slots:
 		void slotSetEnabled(bool enabled);
