@@ -25,10 +25,10 @@
 #include <tqmetaobject.h>
 
 #include <kdebug.h>
-#include <klocale.h>
-#include <kpopupmenu.h>
-#include <kmessagebox.h>
-#include <kaccelmanager.h>
+#include <tdelocale.h>
+#include <tdepopupmenu.h>
+#include <tdemessagebox.h>
+#include <tdeaccelmanager.h>
 
 #include "formIO.h"
 #include "container.h"
@@ -147,13 +147,13 @@ PropertyCommand::name() const
 void
 PropertyCommand::debug()
 {
-	kdDebug() << "PropertyCommand: name=\"" << name() << "\" widgets=" << m_oldvalues.keys() 
+	kdDebug() << "PropertyCommand: name=\"" << name() << "\" widgets=" << m_oldvalues.keys()
 		<< " value=" << m_value << " oldValues=" << m_oldvalues.values() << endl;
 }
 
 // GeometryPropertyCommand (for multiples widgets)
 
-GeometryPropertyCommand::GeometryPropertyCommand(WidgetPropertySet *set, 
+GeometryPropertyCommand::GeometryPropertyCommand(WidgetPropertySet *set,
 	const TQStringList &names, const TQPoint& oldPos)
  : Command(), m_propSet(set), m_names(names), m_oldPos(oldPos)
 {
@@ -215,7 +215,7 @@ GeometryPropertyCommand::name() const
 void
 GeometryPropertyCommand::debug()
 {
-	kdDebug() << "GeometryPropertyCommand: pos=" << m_pos << " oldPos=" << m_oldPos 
+	kdDebug() << "GeometryPropertyCommand: pos=" << m_pos << " oldPos=" << m_oldPos
 		<< " widgets=" << m_names << endl;
 }
 
@@ -367,7 +367,7 @@ AlignWidgetsCommand::name() const
 void
 AlignWidgetsCommand::debug()
 {
-	kdDebug() << "AlignWidgetsCommand: name=\"" << name() << "\" form=" << m_form->widget()->name() 
+	kdDebug() << "AlignWidgetsCommand: name=\"" << name() << "\" form=" << m_form->widget()->name()
 		<< " widgets=" << m_pos.keys() << endl;
 }
 
@@ -606,13 +606,13 @@ AdjustSizeCommand::name() const
 void
 AdjustSizeCommand::debug()
 {
-	kdDebug() << "AdjustSizeCommand: name=\"" << name() << "\" form=" << m_form->widget()->name() 
+	kdDebug() << "AdjustSizeCommand: name=\"" << name() << "\" form=" << m_form->widget()->name()
 		<< " widgets=" << m_sizes.keys() << endl;
 }
 
 // LayoutPropertyCommand
 
-LayoutPropertyCommand::LayoutPropertyCommand(WidgetPropertySet *buf, const TQCString &wname, 
+LayoutPropertyCommand::LayoutPropertyCommand(WidgetPropertySet *buf, const TQCString &wname,
 	const TQVariant &oldValue, const TQVariant &value)
  : PropertyCommand(buf, wname, oldValue, value, "layout")
 {
@@ -744,11 +744,11 @@ InsertWidgetCommand::execute()
 		kdWarning() << "InsertWidgetCommand::execute() ERROR: widget creation failed" << endl;
 		return;
 	}
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,4,0) 
+#if TDE_VERSION >= TDE_MAKE_VERSION(3,4,0)
 //! @todo allow setting this for data view mode as well
 	if (m_form->designMode()) {
 		//don't generate accelerators for widgets in design mode
-		KAcceleratorManager::setNoAccel(w);
+		TDEAcceleratorManager::setNoAccel(w);
 	}
 #endif
 
@@ -805,7 +805,7 @@ InsertWidgetCommand::execute()
 	m_container->reloadLayout(); // reload the layout to take the new wigdet into account
 
 	m_container->setSelectedWidget(w, false);
-	if (m_container->form()->library()->internalProperty(w->className(), 
+	if (m_container->form()->library()->internalProperty(w->className(),
 			"dontStartEditingOnInserting").isEmpty())
 	{
 		m_container->form()->library()->startEditing(
@@ -838,9 +838,9 @@ InsertWidgetCommand::name() const
 void
 InsertWidgetCommand::debug()
 {
-	kdDebug() << "InsertWidgetCommand: name=\"" << name() << "\" generatedName=" << m_name 
+	kdDebug() << "InsertWidgetCommand: name=\"" << name() << "\" generatedName=" << m_name
 		<< " container=" << m_containername
-		<< " form=" << m_form->widget()->name() << " class=" << m_class 
+		<< " form=" << m_form->widget()->name() << " class=" << m_class
 		<< " rect=" << m_insertRect << " pos=" << m_point << endl;
 }
 
@@ -897,12 +897,12 @@ CreateLayoutCommand::execute()
 		m_name = m_form->objectTree()->generateUniqueName(classname);
 
 	TQWidget *w = lib->createWidget(classname, container->widget(), m_name.latin1(), container);
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,4,0) 
+#if TDE_VERSION >= TDE_MAKE_VERSION(3,4,0)
 //! @todo allow setting this for data view mode as well
 	if (w) {
 		if (m_form->designMode()) {
 			//don't generate accelerators for widgets in design mode
-			KAcceleratorManager::setNoAccel(w);
+			TDEAcceleratorManager::setNoAccel(w);
 		}
 	}
 #endif
@@ -983,19 +983,19 @@ CreateLayoutCommand::name() const
 	switch(m_type)
 	{
 		case Container::HBox:
-			return i18n("Group WidgetsQt::Horizontally");
+			return i18n("Group Widgets Horizontally");
 		case Container::VBox:
-			return i18n("Group WidgetsQt::Vertically");
+			return i18n("Group Widgets Vertically");
 		case Container::Grid:
 			return i18n("Group Widgets in a Grid");
 		case Container::HSplitter:
-			return i18n("Group WidgetsQt::Horizontally in a Splitter");
+			return i18n("Group Widgets Horizontally in a Splitter");
 		case Container::VSplitter:
-			return i18n("Group WidgetsQt::Vertically in a Splitter");
+			return i18n("Group Widgets Vertically in a Splitter");
 		case Container::HFlow:
 			return i18n("Group Widgets By Rows");
 		case Container::VFlow:
-			return i18n("Group WidgetsQt::Vertically By Columns");
+			return i18n("Group Widgets Vertically By Columns");
 		default:
 			return i18n("Group widgets");
 	}
@@ -1004,7 +1004,7 @@ CreateLayoutCommand::name() const
 void
 CreateLayoutCommand::debug()
 {
-	kdDebug() << "CreateLayoutCommand: name=\"" << name() << "\" generatedName=" << m_name 
+	kdDebug() << "CreateLayoutCommand: name=\"" << name() << "\" generatedName=" << m_name
 		<< " widgets=" << m_pos.keys() << " container=" << m_containername
 		<< " form=" << m_form->widget()->name() << endl;
 }
@@ -1366,7 +1366,7 @@ PasteWidgetCommand::debug()
 {
 	kdDebug() << "PasteWidgetCommand: pos=" << m_point
 		<< " widgets=" << m_names << " container=" << m_containername
-		<< " form=" << m_form->widget()->name() 
+		<< " form=" << m_form->widget()->name()
 		<< " data=\"" << m_data.left(80) << "...\"" << endl;
 }
 
@@ -1588,7 +1588,7 @@ CommandGroup::debug()
 	kdDebug() << "*CommandGroup: name=\"" << name() << "\" #=" << m_subCommands->commands().count() << endl;
 	uint i = 1;
 	for (TQPtrListIterator<KCommand> it(m_subCommands->commands()); it.current(); ++it, i++) {
-		kdDebug() << "#" << i << ":" 
+		kdDebug() << "#" << i << ":"
 			<< (m_commandsShouldntBeExecuted[it.current()] ? "!" : "") << "allowExecute:" << endl;
 		if (dynamic_cast<Command*>(it.current()))
 			dynamic_cast<Command*>(it.current())->debug();
