@@ -27,8 +27,8 @@
 #include <tqcursor.h>
 
 #include <kdebug.h>
-#include <klocale.h>
-#include <kpopupmenu.h>
+#include <tdelocale.h>
+#include <tdepopupmenu.h>
 
 #include <cstdlib> // for abs()
 
