@@ -109,9 +109,9 @@ EditListViewDialog::EditListViewDialog(TQWidget *parent)
 	m_propSet = new KoProperty::Set(TQT_TQOBJECT(this), "columns");
 	m_propSet->addProperty(new KoProperty::Property("caption", "Caption", i18n("Caption"),i18n("Caption")));
 	m_propSet->addProperty(new KoProperty::Property("width", 100, i18n("Width"), i18n("Width")));
-	m_propSet->addProperty(new KoProperty::Property("clickable", TQVariant(true, 3), i18n("Clickable"), i18n("Clickable") ));
-	m_propSet->addProperty(new KoProperty::Property("resizable", TQVariant(true, 3), i18n("Resizable"), i18n("Resizable") ));
-	m_propSet->addProperty(new KoProperty::Property("fullwidth", TQVariant(false, 3), i18n("Full Width"), i18n("Full Width") ));
+	m_propSet->addProperty(new KoProperty::Property("clickable", TQVariant(true), i18n("Clickable"), i18n("Clickable") ));
+	m_propSet->addProperty(new KoProperty::Property("resizable", TQVariant(true), i18n("Resizable"), i18n("Resizable") ));
+	m_propSet->addProperty(new KoProperty::Property("fullwidth", TQVariant(false), i18n("Full Width"), i18n("Full Width") ));
 	m_editor->changeSet(m_propSet);
 	connect(m_propSet, TQT_SIGNAL(propertyChanged(KoProperty::Set & KoProperty::Property&)),
 		this, TQT_SLOT(changeProperty(KoProperty::Set & KoProperty::Property&)));
@@ -256,9 +256,9 @@ EditListViewDialog::updateItemProperties(TQListBoxItem *item)
 		m_propSet->blockSignals(true); // we don't want changeProperty to be called
 		(*m_propSet)["caption"].setValue(m_listview->columnText(id), false);
 		(*m_propSet)["width"].setValue(m_listview->columnWidth(id), false);
-		(*m_propSet)["clickable"].setValue(TQVariant(m_listview->header()->isClickEnabled(id), 4), false);
-		(*m_propSet)["resizable"].setValue(TQVariant(m_listview->header()->isResizeEnabled(id), 4), false);
-		(*m_propSet)["fullwidth"].setValue(TQVariant(m_listview->header()->isStretchEnabled(id), 4), false);
+		(*m_propSet)["clickable"].setValue(TQVariant(m_listview->header()->isClickEnabled(id)), false);
+		(*m_propSet)["resizable"].setValue(TQVariant(m_listview->header()->isResizeEnabled(id)), false);
+		(*m_propSet)["fullwidth"].setValue(TQVariant(m_listview->header()->isStretchEnabled(id)), false);
 		m_propSet->blockSignals(false);
 		m_editor->changeSet(m_propSet);
 	}
