@@ -27,7 +27,7 @@
 #include <tqmetaobject.h>
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 //#ifdef KEXI_KTEXTEDIT
 #include <ktextedit.h>
 //#else
@@ -36,7 +36,7 @@
 #include <kdialogbase.h>
 #include <keditlistbox.h>
 #include <kxmlguiclient.h>
-#include <kactioncollection.h>
+#include <tdeactioncollection.h>
 
 #include "richtextdialog.h"
 #include "editlistviewdialog.h"
