@@ -275,8 +275,8 @@ WidgetPropertySet::createPropertiesForWidget(TQWidget *w)
 	if(!tree)
 		return;
 
-	const TQVariantMap* modifiedProperties = tree->modifiedProperties();
-	TQVariantMapConstIterator modifiedPropertiesIt;
+	const TQStringVariantMap* modifiedProperties = tree->modifiedProperties();
+	TQStringVariantMapConstIterator modifiedPropertiesIt;
 	bool isTopLevel = KFormDesigner::FormManager::self()->isTopLevel(w);
 //	int count = 0;
 	KoProperty::Property *newProp = 0;
@@ -378,7 +378,7 @@ WidgetPropertySet::createPropertiesForWidget(TQWidget *w)
 	}
 
 	(*this)["name"].setAutoSync(false); // name should be updated only when pressing Enter
-	(*this)["enabled"].setValue( TQVariant(tree->isEnabled(), 3));
+	(*this)["enabled"].setValue( TQVariant(tree->isEnabled()));
 
 	if (winfo) {
 		form->library()->setPropertyOptions(*this, *winfo, w);
@@ -416,7 +416,7 @@ WidgetPropertySet::updatePropertyValue(ObjectTreeItem *tree, const char *propert
 	KoProperty::Property p( d->set[propertyName] );
 
 //! \todo what about set properties, and lists properties
-	TQMap<TQString, TQVariant>::ConstIterator it( tree->modifiedProperties()->find(propertyName) );
+	TQStringVariantMap::ConstIterator it( tree->modifiedProperties()->find(propertyName) );
 	if (it != tree->modifiedProperties()->constEnd()) {
 		blockSignals(true);
 		if(meta && meta->isEnumType()) {
@@ -664,7 +664,7 @@ WidgetPropertySet::saveEnabledProperty(bool value)
 		(*it)->setPalette(p);
 
 		tree->setEnabled(value);
-		emit widgetPropertyChanged((*it), "enabled", TQVariant(value, 3));
+		emit widgetPropertyChanged((*it), "enabled", TQVariant(value));
 	}
 }
 
@@ -837,7 +837,7 @@ WidgetPropertySet::createAlignProperty(const TQMetaProperty *meta, TQWidget *wid
 	) {
 		// Create the wordbreak property
 		KoProperty::Property *p = new KoProperty::Property("wordbreak", 
-			TQVariant(alignment & TQt::WordBreak, 3), i18n("Word Break"), i18n("Word Break") );
+			TQVariant(alignment & TQt::WordBreak), i18n("Word Break"), i18n("Word Break") );
 		d->set.addProperty(p);
 		updatePropertyValue(tree, "wordbreak");
 		if (!KFormDesigner::FormManager::self()->activeForm()->library()->isPropertyVisible(
@@ -1081,7 +1081,7 @@ WidgetPropertySet::valueCaption(const TQCString &name)
 KoProperty::Property::ListData*
 WidgetPropertySet::createValueList(WidgetInfo *winfo, const TQStringList &list)
 {
-//	TQMap <TQString, TQVariant> map;
+//	TQStringVariantMap map;
 	TQStringList names;
 	TQStringList::ConstIterator endIt = list.end();
 	for(TQStringList::ConstIterator it = list.begin(); it != endIt; ++it) {
