@@ -254,7 +254,7 @@ class KEXI_DB_EXPORT Cursor: public TQObject, public Object
 
 	protected:
 		//! possible results of row fetching, used for m_result
-		typedef enum FetchResult { FetchError=0, FetchOK=1, FetchEnd=2 };
+		enum FetchResult { FetchError=0, FetchOK=1, FetchEnd=2 };
 
 		/*! Cursor will operate on \a conn, raw \a statement will be used to execute query. */
 		Cursor(Connection* conn, const TQString& statement, uint options = NoOptions );
