@@ -30,7 +30,7 @@
 #include <tqcheckbox.h>
 
 #include <kcombobox.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kpushbutton.h>
 #include <kdebug.h>
 #include <klineedit.h>
@@ -110,7 +110,7 @@ ImportWizard::ImportWizard(TQWidget *parent, TQMap<TQString,TQString>* args)
 		}
 	}
 
-	m_sourceDBEncoding = TQString::fromLatin1(KGlobal::locale()->encoding()); //default
+	m_sourceDBEncoding = TQString::fromLatin1(TDEGlobal::locale()->encoding()); //default
 }
 
 //===========================================================
@@ -600,7 +600,7 @@ bool ImportWizard::fileBasedDstSelected() const
 
 void ImportWizard::progressUpdated(int percent) {
 	m_progressBar->setProgress(percent);
-	KApplication::kApplication()->processEvents();
+	TDEApplication::kApplication()->processEvents();
 }
 
 //===========================================================
