@@ -27,8 +27,8 @@
 #include <kexipart.h>
 #include <kexiactioncategories.h>
 
-#include <klistview.h>
-#include <kaction.h>
+#include <tdelistview.h>
+#include <tdeaction.h>
 #include <kiconloader.h>
 #include <kdebug.h>
 #include <kstdguiitem.h>
@@ -41,12 +41,12 @@
 #include <tqtooltip.h>
 #include <tqwidgetstack.h>
 
-#include <widget/utils/klistviewitemtemplate.h>
+#include <widget/utils/tdelistviewitemtemplate.h>
 #include <widget/kexibrowser.h>
 #include <widget/kexibrowseritem.h>
 #include <kexiutils/utils.h>
 
-typedef KListViewItemTemplate<TQString> ActionSelectorDialogListItemBase;
+typedef TDEListViewItemTemplate<TQString> ActionSelectorDialogListItemBase;
 
 class ActionSelectorDialogListItem : public ActionSelectorDialogListItemBase
 {
@@ -79,7 +79,7 @@ protected:
 //---------------------------------------
 
 ActionsListViewBase::ActionsListViewBase(TQWidget* parent)
- : KListView(parent)
+ : TDEListView(parent)
 {
 	setResizeMode(TQListView::AllColumns);
 	addColumn("");
@@ -115,27 +115,27 @@ void ActionsListViewBase::selectAction(const TQString& actionName)
 
 //---------------------------------------
 
-KActionsListViewBase::KActionsListViewBase(TQWidget* parent, KexiMainWindow* mainWin)
+TDEActionsListViewBase::TDEActionsListViewBase(TQWidget* parent, KexiMainWindow* mainWin)
 	: ActionsListViewBase(parent)
 	, m_mainWin(mainWin)
 {
 }
 
-KActionsListViewBase::~KActionsListViewBase() {}
+TDEActionsListViewBase::~TDEActionsListViewBase() {}
 
-void KActionsListViewBase::init()
+void TDEActionsListViewBase::init()
 {
 	setSorting(0);
-	const TQPixmap noIcon( KexiUtils::emptyIcon(KIcon::Small) );
-	KActionPtrList sharedActions( m_mainWin->allActions() );
+	const TQPixmap noIcon( KexiUtils::emptyIcon(TDEIcon::Small) );
+	TDEActionPtrList sharedActions( m_mainWin->allActions() );
 	const Kexi::ActionCategories *acat = Kexi::actionCategories();
-	foreach (KActionPtrList::ConstIterator, it, sharedActions) {
+	foreach (TDEActionPtrList::ConstIterator, it, sharedActions) {
 //			kdDebug() << (*it)->name() << " " << (*it)->text() << endl;
 		//! @todo group actions
-		//! @todo: store KAction* here?
+		//! @todo: store TDEAction* here?
 		const int actionCategories = acat->actionCategories((*it)->name());
 		if (actionCategories==-1) {
-			kexipluginswarn << "KActionsListViewBase(): no category declared for action \"" 
+			kexipluginswarn << "TDEActionsListViewBase(): no category declared for action \"" 
 				<< (*it)->name() << "\"! Fix this!" << endl;
 			continue;
 		}
@@ -144,7 +144,7 @@ void KActionsListViewBase::init()
 		ActionSelectorDialogListItem *pitem = new ActionSelectorDialogListItem((*it)->name(), 
 			this, (*it)->toolTip().isEmpty() ? (*it)->text().replace("&", "") : (*it)->toolTip() );
 		pitem->fifoSorting = false; //alpha sort
-		pitem->setPixmap( 0, (*it)->iconSet( KIcon::Small, 16 ).pixmap( TQIconSet::Small, TQIconSet::Active ) );
+		pitem->setPixmap( 0, (*it)->iconSet( TDEIcon::Small, 16 ).pixmap( TQIconSet::Small, TQIconSet::Active ) );
 		if (!pitem->pixmap(0) || pitem->pixmap(0)->isNull())
 			pitem->setPixmap( 0, noIcon );
 	}
@@ -152,15 +152,15 @@ void KActionsListViewBase::init()
 
 //---------------------------------------
 
-//! @internal Used to display KActions (in column 2)
-class KActionsListView : public KActionsListViewBase
+//! @internal Used to display TDEActions (in column 2)
+class TDEActionsListView : public TDEActionsListViewBase
 {
 public:
-	KActionsListView(TQWidget* parent, KexiMainWindow* mainWin)
-		: KActionsListViewBase(parent, mainWin)
+	TDEActionsListView(TQWidget* parent, KexiMainWindow* mainWin)
+		: TDEActionsListViewBase(parent, mainWin)
 	{
 	}
-	virtual ~KActionsListView() {}
+	virtual ~TDEActionsListView() {}
 
 	virtual bool isActionVisible(const char* actionName, int actionCategories) const {
 		Q_UNUSED(actionName);
@@ -168,12 +168,12 @@ public:
 	}
 };
 
-//! @internal Used to display KActions (in column 2)
-class CurrentFormActionsListView : public KActionsListViewBase
+//! @internal Used to display TDEActions (in column 2)
+class CurrentFormActionsListView : public TDEActionsListViewBase
 {
 public:
 	CurrentFormActionsListView(TQWidget* parent, KexiMainWindow* mainWin)
-		: KActionsListViewBase(parent, mainWin)
+		: TDEActionsListViewBase(parent, mainWin)
 	{
 	}
 	virtual ~CurrentFormActionsListView() {}
@@ -192,9 +192,9 @@ public:
 	 : ActionsListViewBase(parent)
 	{
 		TQListViewItem *item = new ActionSelectorDialogListItem("noaction", this, i18n("No action") );
-		const TQPixmap noIcon( KexiUtils::emptyIcon(KIcon::Small) );
+		const TQPixmap noIcon( KexiUtils::emptyIcon(TDEIcon::Small) );
 		item->setPixmap(0, noIcon);
-		item = new ActionSelectorDialogListItem("kaction", this, i18n("Application actions") );
+		item = new ActionSelectorDialogListItem("tdeaction", this, i18n("Application actions") );
 		item->setPixmap(0, SmallIcon("form_action"));
 
 		KexiPart::PartInfoList *pl = Kexi::partManager().partInfoList();
@@ -263,20 +263,20 @@ class ActionToExecuteListView : public ActionsListViewBase
 				return;
 			int supportedViewModes = part->supportedViewModes();
 			ActionSelectorDialogListItem *item;
-			const TQPixmap noIcon( KexiUtils::emptyIcon(KIcon::Small) );
+			const TQPixmap noIcon( KexiUtils::emptyIcon(TDEIcon::Small) );
 			if (supportedViewModes & Kexi::DataViewMode) {
 				item = new ActionSelectorDialogListItem("open", this, i18n("Open in Data View"));
-				item->setPixmap(0, SmallIcon("fileopen"));
+				item->setPixmap(0, SmallIcon("document-open"));
 			}
 			if (part->info()->isExecuteSupported()) {
 				item = new ActionSelectorDialogListItem("execute", this, i18n("Execute"));
-				item->setPixmap(0, SmallIcon("player_play"));
+				item->setPixmap(0, SmallIcon("media-playback-start"));
 			}
 			if (part->info()->isPrintingSupported()) {
 				ActionSelectorDialogListItem *printItem = new ActionSelectorDialogListItem(
 					"print", this, i18n("Print"));
-				printItem->setPixmap(0, SmallIcon("fileprint"));
-				KAction *a = KStdAction::printPreview(0, 0, 0);
+				printItem->setPixmap(0, SmallIcon("document-print"));
+				TDEAction *a = KStdAction::printPreview(0, 0, 0);
 				item = new ActionSelectorDialogListItem("printPreview", printItem, 
 					a->text().replace("&", "").replace("...", ""));
 				item->setPixmap(0, SmallIcon(a->icon()));
@@ -301,7 +301,7 @@ class ActionToExecuteListView : public ActionsListViewBase
 				exportItem->setExpandable(false);
 			}
 			item = new ActionSelectorDialogListItem("new", this, i18n("Create New Object"));
-			item->setPixmap(0, SmallIcon("filenew"));
+			item->setPixmap(0, SmallIcon("document-new"));
 			if (supportedViewModes & Kexi::DesignViewMode) {
 				item = new ActionSelectorDialogListItem("design", this, i18n("Open in Design View"));
 				item->setPixmap(0, SmallIcon("edit"));
@@ -311,7 +311,7 @@ class ActionToExecuteListView : public ActionsListViewBase
 				item->setPixmap(0, noIcon);
 			}
 			item = new ActionSelectorDialogListItem("close", this, i18n("Close View"));
-			item->setPixmap(0, SmallIcon("fileclose"));
+			item->setPixmap(0, SmallIcon("window-close"));
 			updateWidth();
 		}
 
@@ -331,7 +331,7 @@ class KexiActionSelectionDialog::KexiActionSelectionDialogPrivate
 {
 public:
 	KexiActionSelectionDialogPrivate() 
-		: kactionPageWidget(0), kactionListView(0), objectsListView(0)
+		: tdeactionPageWidget(0), tdeactionListView(0), objectsListView(0)
 		, currentFormActionsPageWidget(0)
 		, currentFormActionsListView(0)
 		, secondAnd3rdColumnMainWidget(0)
@@ -376,8 +376,8 @@ public:
 	KexiMainWindow* mainWin;
 	TQString actionWidgetName;
 	ActionCategoriesListView* actionCategoriesListView; //!< for column #1
-	TQWidget *kactionPageWidget;
-	KActionsListView* kactionListView;  //!< for column #2
+	TQWidget *tdeactionPageWidget;
+	TDEActionsListView* tdeactionListView;  //!< for column #2
 	KexiBrowser* objectsListView; //!< for column #2
 	TQWidget *currentFormActionsPageWidget; //!< for column #2
 	CurrentFormActionsListView* currentFormActionsListView; //!< for column #2
@@ -419,9 +419,9 @@ KexiActionSelectionDialog::KexiActionSelectionDialog(KexiMainWindow* mainWin, TQ
    \______________________________________________/
                         glyr
   [a]- TQWidgetStack *secondAnd3rdColumnStack, 
-    - for displaying KActions, the stack contains d->kactionPageWidget TQWidget
+    - for displaying TDEActions, the stack contains d->tdeactionPageWidget TQWidget
     - for displaying objects, the stack contains secondAnd3rdColumnMainWidget TQWidget and TQGridLayout *secondAnd3rdColumnGrLyr
-	 - kactionPageWidget contains only a TQVBoxLayout and label+kactionListView
+	 - tdeactionPageWidget contains only a TQVBoxLayout and label+tdeactionListView
 */
 	d->glyr = new TQGridLayout(mainWidget, 2, 2, KDialog::marginHint(), KDialog::spacingHint());
 	d->glyr->setRowStretch(1, 1);
@@ -495,9 +495,9 @@ KexiActionSelectionDialog::KexiActionSelectionDialog(KexiMainWindow* mainWin, TQ
 	KexiPart::Info* partInfo = action.decodeString(actionType, actionArg, ok);
 	if (ok) {
 		d->actionCategoriesListView->selectAction(actionType);
-		if (actionType=="kaction") {
-			d->kactionListView->selectAction(actionArg);
-			d->kactionListView->setFocus();
+		if (actionType=="tdeaction") {
+			d->tdeactionListView->selectAction(actionArg);
+			d->tdeactionListView->setFocus();
 		}
 		else if (actionType=="currentForm") {
 			d->currentFormActionsListView->selectAction(actionArg);
@@ -530,12 +530,12 @@ KexiActionSelectionDialog::~KexiActionSelectionDialog()
 	delete d;
 }
 
-void KexiActionSelectionDialog::slotKActionItemExecuted(TQListViewItem*)
+void KexiActionSelectionDialog::slotTDEActionItemExecuted(TQListViewItem*)
 {
 	accept();
 }
 
-void KexiActionSelectionDialog::slotKActionItemSelected(TQListViewItem*)
+void KexiActionSelectionDialog::slotTDEActionItemSelected(TQListViewItem*)
 {
 	d->setActionToExecuteSectionVisible(false);
 	updateOKButtonStatus();
@@ -574,34 +574,34 @@ void KexiActionSelectionDialog::slotActionToExecuteItemSelected(TQListViewItem*)
 void KexiActionSelectionDialog::slotActionCategorySelected(TQListViewItem* item)
 {
 	ActionSelectorDialogListItem *simpleItem = dynamic_cast<ActionSelectorDialogListItem*>(item);
-	// simple case: part-less item, e.g. kaction:
+	// simple case: part-less item, e.g. tdeaction:
 	if (simpleItem) {
 		d->updateSelectActionToBeExecutedMessage(simpleItem->data);
 		TQString selectActionToBeExecutedMsg(
 			i18n("&Select action to be executed after clicking \"%1\" button:")); // msg for a label
-		if (simpleItem->data == "kaction") {
-			if (!d->kactionPageWidget) {
+		if (simpleItem->data == "tdeaction") {
+			if (!d->tdeactionPageWidget) {
 				//create lbl+list view with a vlayout
-				d->kactionPageWidget = new TQWidget();
-				d->kactionPageWidget->setSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Minimum);
-				TQVBoxLayout *vlyr = new TQVBoxLayout(d->kactionPageWidget, 0, KDialog::spacingHint());
-				d->kactionListView = new KActionsListView(d->kactionPageWidget, d->mainWin);
-				d->kactionListView->init();
-				TQLabel *lbl = new TQLabel(d->kactionListView, selectActionToBeExecutedMsg.arg(d->actionWidgetName),
-					d->kactionPageWidget);
+				d->tdeactionPageWidget = new TQWidget();
+				d->tdeactionPageWidget->setSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Minimum);
+				TQVBoxLayout *vlyr = new TQVBoxLayout(d->tdeactionPageWidget, 0, KDialog::spacingHint());
+				d->tdeactionListView = new TDEActionsListView(d->tdeactionPageWidget, d->mainWin);
+				d->tdeactionListView->init();
+				TQLabel *lbl = new TQLabel(d->tdeactionListView, selectActionToBeExecutedMsg.arg(d->actionWidgetName),
+					d->tdeactionPageWidget);
 				lbl->setAlignment(TQt::AlignTop|TQt::AlignLeft|TQt::WordBreak);
 				lbl->setMinimumHeight(lbl->fontMetrics().height()*2);
 				vlyr->addWidget(lbl);
-				vlyr->addWidget(d->kactionListView);
-				d->secondAnd3rdColumnStack->addWidget(d->kactionPageWidget);
-				connect(d->kactionListView, TQT_SIGNAL(executed(TQListViewItem*)),
-					this, TQT_SLOT(slotKActionItemExecuted(TQListViewItem*)));
-				connect( d->kactionListView, TQT_SIGNAL(selectionChanged(TQListViewItem*)), 
-					this, TQT_SLOT(slotKActionItemSelected(TQListViewItem*)));
+				vlyr->addWidget(d->tdeactionListView);
+				d->secondAnd3rdColumnStack->addWidget(d->tdeactionPageWidget);
+				connect(d->tdeactionListView, TQT_SIGNAL(executed(TQListViewItem*)),
+					this, TQT_SLOT(slotTDEActionItemExecuted(TQListViewItem*)));
+				connect( d->tdeactionListView, TQT_SIGNAL(selectionChanged(TQListViewItem*)), 
+					this, TQT_SLOT(slotTDEActionItemSelected(TQListViewItem*)));
 			}
 			d->setActionToExecuteSectionVisible(false);
-			d->raiseWidget(d->kactionPageWidget);
-			slotKActionItemSelected(d->kactionListView->selectedItem()); //to refresh column #3
+			d->raiseWidget(d->tdeactionPageWidget);
+			slotTDEActionItemSelected(d->tdeactionListView->selectedItem()); //to refresh column #3
 		}
 		else if (simpleItem->data == "currentForm") {
 			if (!d->currentFormActionsPageWidget) {
@@ -669,12 +669,12 @@ KexiFormEventAction::ActionData KexiActionSelectionDialog::currentAction() const
 	KexiFormEventAction::ActionData data;
 	ActionSelectorDialogListItem *simpleItem = dynamic_cast<ActionSelectorDialogListItem*>(
 		d->actionCategoriesListView->selectedItem());
-	// simple case: part-less item, e.g. kaction:
+	// simple case: part-less item, e.g. tdeaction:
 	if (simpleItem) {
-		if (simpleItem->data == "kaction") {
-			if (d->kactionListView->selectedItem()) {
-				data.string = TQString("kaction:")
-					+ dynamic_cast<ActionSelectorDialogListItem*>( d->kactionListView->selectedItem() )->data;
+		if (simpleItem->data == "tdeaction") {
+			if (d->tdeactionListView->selectedItem()) {
+				data.string = TQString("tdeaction:")
+					+ dynamic_cast<ActionSelectorDialogListItem*>( d->tdeactionListView->selectedItem() )->data;
 				return data;
 			}
 		}
