@@ -25,10 +25,10 @@
 #include <tqheader.h>
 
 #include <kiconloader.h>
-#include <klocale.h>
-#include <ktoolbarbutton.h>
+#include <tdelocale.h>
+#include <tdetoolbarbutton.h>
 #include <kdebug.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 
 #include <widget/kexipropertyeditorview.h>
 #include <widget/kexidatasourcecombobox.h>
@@ -80,7 +80,7 @@ KexiDataSourcePage::KexiDataSourcePage(TQWidget *parent, const char *name)
 #endif
 	m_widgetDSLabel->setSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Fixed);
 	m_widgetDSLabel->setMargin(2);
-	m_widgetDSLabel->setMinimumHeight(IconSize(KIcon::Small)+4);
+	m_widgetDSLabel->setMinimumHeight(IconSize(TDEIcon::Small)+4);
 	m_widgetDSLabel->setAlignment(AlignLeft|AlignBottom);
 	hlyr->addWidget(m_widgetDSLabel);
 
@@ -106,7 +106,7 @@ KexiDataSourcePage::KexiDataSourcePage(TQWidget *parent, const char *name)
 	m_dataSourceLabel = new TQLabel(i18n("Form's data source:"), contents);
 	m_dataSourceLabel->setSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Fixed);
 	m_dataSourceLabel->setMargin(2);
-	m_dataSourceLabel->setMinimumHeight(IconSize(KIcon::Small)+4);
+	m_dataSourceLabel->setMinimumHeight(IconSize(TDEIcon::Small)+4);
 	m_dataSourceLabel->setAlignment(AlignLeft|AlignBottom);
 	hlyr->addWidget(m_dataSourceLabel);
 
@@ -138,7 +138,7 @@ KexiDataSourcePage::KexiDataSourcePage(TQWidget *parent, const char *name)
 	separator->setFrameShadow(TQFrame::Sunken);
 	vlyr->addWidget(separator);*/
 /*
-	KPopupTitle *title = new KPopupTitle(this);
+	TDEPopupTitle *title = new TDEPopupTitle(this);
 	title->setTitle(i18n("Inserting fields"));
 	vlyr->addWidget(title);
 	vlyr->addSpacing(4);*/
@@ -169,7 +169,7 @@ KexiDataSourcePage::KexiDataSourcePage(TQWidget *parent, const char *name)
 	m_availableFieldsLabel = new TQLabel(i18n("Available fields:"), contents);
 	m_availableFieldsLabel->setSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Fixed);
 	m_availableFieldsLabel->setMargin(2);
-	m_availableFieldsLabel->setMinimumHeight(IconSize(KIcon::Small));
+	m_availableFieldsLabel->setMinimumHeight(IconSize(TDEIcon::Small));
 	hlyr->addWidget(m_availableFieldsLabel);
 
 	m_addField = new KexiSmallToolButton(contents, i18n("Insert selected field into form", "Insert"), 
