@@ -28,7 +28,7 @@
 #include <tqapplication.h>
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 
 #include "kexidbcheckbox.h"
 #include "kexidbimagebox.h"
