@@ -27,7 +27,7 @@ class CopyCenter:
 					return getattr(self.plugin, plugintype)(self.plugin)
 			except:
 				import traceback
-				print "".join( traceback.format_exception(sys.exc_info()[0],sys.exc_info()[1],sys.exc_info()[2]) )
+				print("".join( traceback.format_exception(sys.exc_info()[0],sys.exc_info()[1],sys.exc_info()[2]) ))
 			return None
 
 	def __init__(self, scriptpath):
@@ -38,7 +38,7 @@ class CopyCenter:
 		import os
 		import sys
 		if not os.path.exists(scriptpath):
-			print "The Path %s does not exist" % scriptpath
+			print("The Path %s does not exist" % scriptpath)
 		else:
 			import re
 			regexp = re.compile('^CopyCenterPlugin(.*)\\.py$')
@@ -47,17 +47,17 @@ class CopyCenter:
 				if not os.path.isfile(file): continue
 				m = regexp.match(f)
 				if not m: continue
-				print "Plugin name=%s file=%s" % (m.group(1),file)
+				print("Plugin name=%s file=%s" % (m.group(1),file))
 				mylocals = {}
 				try:
-					execfile(file, globals(), mylocals)
-					if mylocals.has_key("CopyCenterPlugin"):
+					exec(compile(open(file, "rb").read(), file, 'exec'), globals(), mylocals)
+					if "CopyCenterPlugin" in mylocals:
 						plugin = mylocals.get("CopyCenterPlugin")(self)
 						self.plugins[plugin.name] = self.Plugin(plugin)
 				except:
-					print "Failed to import file=%s" % file
+					print("Failed to import file=%s" % file)
 					import traceback
-					print "".join( traceback.format_exception(sys.exc_info()[0],sys.exc_info()[1],sys.exc_info()[2]) )
+					print("".join( traceback.format_exception(sys.exc_info()[0],sys.exc_info()[1],sys.exc_info()[2]) ))
 
 	def getHomePath(self):
 		""" Return the homedirectory. """
@@ -83,38 +83,38 @@ class Copierer:
 	def writeFailed(self,record): pass
 
 def runGuiApp(copycenter, name):
-	import qt
+	from TQt import tqt
 	import sys
 
 	#--------------------------------------------------------------------
 
-	class ListViewDialog(qt.QDialog):
+	class ListViewDialog(tqt.TQDialog):
 		def __init__(self, parent, caption):
-			qt.QDialog.__init__(self, parent, "ProgressDialog", 1)
+			tqt.TQDialog.__init__(self, parent, "ProgressDialog", 1)
 			self.parent = parent
 			self.setCaption(caption)
-			layout = qt.QVBoxLayout(self)
-			box = qt.QVBox(self)
+			layout = tqt.TQVBoxLayout(self)
+			box = tqt.TQVBox(self)
 			box.setMargin(2)
 			layout.addWidget(box)
-			self.listview = qt.QListView(box)
+			self.listview = tqt.TQListView(box)
 			self.listview.setAllColumnsShowFocus(True)
 			self.listview.header().setStretchEnabled(True,0)
-			btnbox = qt.QHBox(box)
+			btnbox = tqt.TQHBox(box)
 			btnbox.setMargin(6)
 			btnbox.setSpacing(6)
-			self.okbtn = qt.QPushButton(btnbox)
+			self.okbtn = tqt.TQPushButton(btnbox)
 			self.okbtn.setText("Ok")
-			#qt.QObject.connect(okbtn, qt.SIGNAL("clicked()"), self.okClicked)
-			self.cancelbtn = qt.QPushButton(btnbox)
+			#tqt.TQObject.connect(okbtn, tqt.SIGNAL("clicked()"), self.okClicked)
+			self.cancelbtn = tqt.TQPushButton(btnbox)
 			self.cancelbtn.setText("Cancel")
-			qt.QObject.connect(self.cancelbtn, qt.SIGNAL("clicked()"), self.close)
-			box.setMinimumSize(qt.QSize(460,380))
+			tqt.TQObject.connect(self.cancelbtn, tqt.SIGNAL("clicked()"), self.close)
+			box.setMinimumSize(tqt.TQSize(460,380))
 		def addItem(self,valuelist,afteritem = None):
 			if afteritem == None:
-				item = qt.QListViewItem(self.listview)
+				item = tqt.TQListViewItem(self.listview)
 			else:
-				item = qt.QListViewItem(self.listview,afteritem)
+				item = tqt.TQListViewItem(self.listview,afteritem)
 			i = 0
 			for value in valuelist:
 				item.setText(i,value)
@@ -123,20 +123,20 @@ def runGuiApp(copycenter, name):
 
 	#--------------------------------------------------------------------
 
-	class CopyJobWidget(qt.QVBox):
+	class CopyJobWidget(tqt.TQVBox):
 		def __init__(self,dialog,parent):
 			self.dialog = dialog
-			qt.QVBox.__init__(self,parent)
+			tqt.TQVBox.__init__(self,parent)
 			self.setSpacing(6)
-			typebox = qt.QHBox(self)
+			typebox = tqt.TQHBox(self)
 			typebox.setSpacing(6)
-			label = qt.QLabel("Job File:",typebox)
-			self.jobfilecombobox = qt.QComboBox(typebox)
+			label = tqt.TQLabel("Job File:",typebox)
+			self.jobfilecombobox = tqt.TQComboBox(typebox)
 			typebox.setStretchFactor(self.jobfilecombobox,1)
 			self.jobfilecombobox.setEditable(True)
 			self.jobfilecombobox.insertItem("")
 			label.setBuddy(self.jobfilecombobox)
-			qt.QObject.connect(self.jobfilecombobox, qt.SIGNAL("textChanged(const QString&)"), self.jobfilecomboboxChanged)
+			tqt.TQObject.connect(self.jobfilecombobox, tqt.SIGNAL("textChanged(const TQString&)"), self.jobfilecomboboxChanged)
 
 			import os
 			import re
@@ -145,38 +145,38 @@ def runGuiApp(copycenter, name):
 				if os.path.isfile(file) and re.search(".+\\.copycenterjob.xml$",f):
 					self.jobfilecombobox.insertItem(file)
 
-			loadbtn = qt.QPushButton(typebox)
+			loadbtn = tqt.TQPushButton(typebox)
 			loadbtn.setText("Open...")
-			qt.QObject.connect(loadbtn, qt.SIGNAL("clicked()"), self.openClicked)
-			savebtn = qt.QPushButton(typebox)
+			tqt.TQObject.connect(loadbtn, tqt.SIGNAL("clicked()"), self.openClicked)
+			savebtn = tqt.TQPushButton(typebox)
 			savebtn.setText("Save...")
-			qt.QObject.connect(savebtn, qt.SIGNAL("clicked()"), self.saveClicked)
+			tqt.TQObject.connect(savebtn, tqt.SIGNAL("clicked()"), self.saveClicked)
 
-			self.listview = qt.QListView(self)
+			self.listview = tqt.TQListView(self)
 			self.listview.setAllColumnsShowFocus(True)
 			self.listview.setSorting(-1)
-			self.listview.setDefaultRenameAction(qt.QListView.Reject)
+			self.listview.setDefaultRenameAction(tqt.TQListView.Reject)
 			self.listview.header().setClickEnabled(False)
 			self.listview.addColumn("Name")
 			self.listview.addColumn("Value")
-			qt.QObject.connect(self.listview, qt.SIGNAL("doubleClicked(QListViewItem*, const QPoint&, int)"), self.doubleClicked)
-			#qt.QObject.connect(self.listview, qt.SIGNAL("itemRenamed(QListViewItem*, int, const QString&)"), self.itemRenamed)
+			tqt.TQObject.connect(self.listview, tqt.SIGNAL("doubleClicked(TQListViewItem*, const TQPoint&, int)"), self.doubleClicked)
+			#tqt.TQObject.connect(self.listview, tqt.SIGNAL("itemRenamed(TQListViewItem*, int, const TQString&)"), self.itemRenamed)
 
 		def doubleClicked(self, **args):
-			print "CopyJobWidget.doubleClicked"
+			print("CopyJobWidget.doubleClicked")
 			item = self.listview.selectedItem()
 			if item and item.parent(): item.startRename(1)
 
 		def readOptions(self,domnode,plugininst):
-			print "CopyJobWidget.readOptions plugintype=\"%s\"" % plugininst.plugintype
+			print("CopyJobWidget.readOptions plugintype=\"%s\"" % plugininst.plugintype)
 			for node in domnode.childNodes:
 				if node.nodeType == node.ELEMENT_NODE:
 					v = node.getAttribute("value")
 					plugininst.options[node.nodeName] = v
-					print "Option \"%s\" has value \"%s\" now." % (node.nodeName, v)
+					print("Option \"%s\" has value \"%s\" now." % (node.nodeName, v))
 
 		def jobfilecomboboxChanged(self, **args):
-			print "CopyJobWidget.jobfilecomboboxChanged"
+			print("CopyJobWidget.jobfilecomboboxChanged")
 			import os
 			import xml.dom.minidom
 			filename = str(self.jobfilecombobox.currentText())
@@ -187,16 +187,16 @@ def runGuiApp(copycenter, name):
 				sourcenode = elements.getElementsByTagName("Source")[0]
 				destinationnode = elements.getElementsByTagName("Destination")[0]
 			except:
-				raise "The XML-file \"%s\" does not contain a valid copy-job." % filename
-			
+				raise Exception("The XML-file \"%s\" does not contain a valid copy-job." % filename)
+
 			sourcepluginname = str(sourcenode.getAttribute('plugin'))
-			if not self.dialog.sourcedata.combobox.listBox().findItem(sourcepluginname,qt.Qt.ExactMatch):
-				raise "There exists no plugin with the name \"%s\"." % sourcepluginname
+			if not self.dialog.sourcedata.combobox.listBox().findItem(sourcepluginname,tqt.TQt.ExactMatch):
+				raise Exception("There exists no plugin with the name \"%s\"." % sourcepluginname)
 			self.dialog.sourcedata.combobox.setCurrentText(sourcepluginname)
 
 			destinationpluginname = str(destinationnode.getAttribute('plugin'))
-			if not self.dialog.destinationdata.combobox.listBox().findItem(destinationpluginname,qt.Qt.ExactMatch):
-				raise "There exists no plugin with the name \"%s\"." % destinationpluginname
+			if not self.dialog.destinationdata.combobox.listBox().findItem(destinationpluginname,tqt.TQt.ExactMatch):
+				raise Exception("There exists no plugin with the name \"%s\"." % destinationpluginname)
 			self.dialog.destinationdata.combobox.setCurrentText(destinationpluginname)
 
 			self.readOptions(sourcenode,self.dialog.getSourcePluginImpl())
@@ -206,17 +206,17 @@ def runGuiApp(copycenter, name):
 		def openClicked(self):
 			text = str(self.jobfilecombobox.currentText())
 			if text == "": text = self.dialog.copycenter.homepath
-			filename = str(qt.QFileDialog.getOpenFileName(text,"*.copycenterjob.xml;;*",self.dialog))
+			filename = str(tqt.TQFileDialog.getOpenFileName(text,"*.copycenterjob.xml;;*",self.dialog))
 			if filename != "": self.jobfilecombobox.setCurrentText(filename)
 
 		def escape(self,s):
 			return s.replace("&", "&amp;").replace("'", "&apos;").replace("<", "&lt;").replace(">", "&gt;").replace('"', "&quot;")
 
 		def writeOptions(self,writer,pluginname,plugininst):
-			print "CopyJobWidget.writeOptions"
+			print("CopyJobWidget.writeOptions")
 			writer.write("<%s plugin=\"%s\">\n" % (plugininst.plugintype, pluginname))
 			for optionname in plugininst.options:
-				value = self.escape( unicode(plugininst.options[optionname]).encode("utf-8") )
+				value = self.escape( str(plugininst.options[optionname]).encode("utf-8") )
 				writer.write("\t<%s value=\"%s\" />\n" % (optionname,value))
 			writer.write("</%s>\n" % plugininst.plugintype)
 
@@ -225,7 +225,7 @@ def runGuiApp(copycenter, name):
 			if text == "":
 				import os
 				text = os.path.join(self.dialog.copycenter.homepath,"default.copycenterjob.xml")
-			filename = str(qt.QFileDialog.getSaveFileName(text,"*.copycenterjob.xml;;*",self.dialog))
+			filename = str(tqt.TQFileDialog.getSaveFileName(text,"*.copycenterjob.xml;;*",self.dialog))
 			if str(filename) == "": return
 			f = open(filename, "w")
 			f.write("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n")
@@ -236,44 +236,44 @@ def runGuiApp(copycenter, name):
 			self.writeOptions(f, destinationpluginname, self.dialog.getDestinationPluginImpl())
 			f.write("</CopyCenterJob>\n")
 			f.close()
-			print "File \%s\" successfully written." % filename
+			print("File \%s\" successfully written." % filename)
 
 		def addItem(self, pluginimpl, afteritem = None, parentitem = None):
 			#print "CopyJobWidget.addItem"
-			class ListViewItem(qt.QListViewItem):
+			class ListViewItem(tqt.TQListViewItem):
 				def __init__(self, pluginimpl, listview, parentitem = None, afteritem = None):
 					self.pluginimpl = pluginimpl
 					if parentitem == None:
-						qt.QListViewItem.__init__(self,listview)
+						tqt.TQListViewItem.__init__(self,listview)
 						self.setOpen(True)
 					else:
 						if afteritem == None:
-							qt.QListViewItem.__init__(self,parentitem)
+							tqt.TQListViewItem.__init__(self,parentitem)
 						else:
-							qt.QListViewItem.__init__(self,parentitem,afteritem)
+							tqt.TQListViewItem.__init__(self,parentitem,afteritem)
 						self.setRenameEnabled(1,True)
 				def startRename(self, columnindex):
-					qt.QListViewItem.startRename(self,columnindex)
-					#lineedit = self.listView().viewport().child("qt_renamebox")
+					tqt.TQListViewItem.startRename(self,columnindex)
+					#lineedit = self.listView().viewport().child("tqt_renamebox")
 					#if lineedit:
-					#	regexp = qt.QRegExp("^[_A-Z]+[_A-Z0-9]*$", False)
-					#	v = qt.QRegExpValidator(regexp, self.listView());
+					#	regexp = tqt.TQRegExp("^[_A-Z]+[_A-Z0-9]*$", False)
+					#	v = tqt.TQRegExpValidator(regexp, self.listView());
 					#	lineedit.setValidator(v)
 				def okRename(self, columnindex):
 					if columnindex == 1:
 						n = str(self.text(0))
-						if not self.pluginimpl.options.has_key(n):
-							raise "No such option \"%s\"" % n
-						qt.QListViewItem.okRename(self,columnindex)
-						v = str(qt.QListViewItem.text(self,1))
-						print "Option \"%s\" has value \"%s\" now." % (n,v)
+						if n not in self.pluginimpl.options:
+							raise Exception("No such option \"%s\"" % n)
+						tqt.TQListViewItem.okRename(self,columnindex)
+						v = str(tqt.TQListViewItem.text(self,1))
+						print("Option \"%s\" has value \"%s\" now." % (n,v))
 						self.pluginimpl.options[n] = v
 
 				def text(self, columnindex):
 					if columnindex == 1:
-						if qt.QListViewItem.text(self,0).contains("password"):
-							return "*" * len(str(qt.QListViewItem.text(self,1)))
-					return qt.QListViewItem.text(self,columnindex)
+						if tqt.TQListViewItem.text(self,0).contains("password"):
+							return "*" * len(str(tqt.TQListViewItem.text(self,1)))
+					return tqt.TQListViewItem.text(self,columnindex)
 			return ListViewItem(pluginimpl, self.listview, parentitem, afteritem)
 
 		def updateItem(self,pluginname,pluginimpl):
@@ -287,63 +287,63 @@ def runGuiApp(copycenter, name):
 				afteritem = self.addItem(pluginimpl, afteritem, item)
 				afteritem.setText(0,str(i))
 				afteritem.setText(1,str(pluginimpl.options[i]))
-				print "CopyJobWidget.updateItem Added item with name \"%s\" and value \"%s\"" % (str(i),str(pluginimpl.options[i]))
+				print("CopyJobWidget.updateItem Added item with name \"%s\" and value \"%s\"" % (str(i),str(pluginimpl.options[i])))
 			pass
-		
+
 		def maybeUpdate(self):
-			print "CopyJobWidget.maybeUpdate"
+			print("CopyJobWidget.maybeUpdate")
 			self.listview.clear()
 			try:
 				self.updateItem(self.dialog.getDestinationPluginName(), self.dialog.getDestinationPluginImpl())
 				self.updateItem(self.dialog.getSourcePluginName(), self.dialog.getSourcePluginImpl())
 			except:
 				import traceback
-				print "".join( traceback.format_exception(sys.exc_info()[0],sys.exc_info()[1],sys.exc_info()[2]) )
+				print("".join( traceback.format_exception(sys.exc_info()[0],sys.exc_info()[1],sys.exc_info()[2]) ))
 				self.listview.clear()
 
 	#--------------------------------------------------------------------
 
-	class ProgressDialog(qt.QDialog):
+	class ProgressDialog(tqt.TQDialog):
 		def __init__(self, dialog):
 			self.dialog = dialog
 			self.starttime = None
-			qt.QDialog.__init__(self, dialog, "ProgressDialog", 1)
+			tqt.TQDialog.__init__(self, dialog, "ProgressDialog", 1)
 			self.setCaption("Copying...")
-			layout = qt.QVBoxLayout(self)
-			box = qt.QVBox(self)
+			layout = tqt.TQVBoxLayout(self)
+			box = tqt.TQVBox(self)
 			box.setSpacing(6)
 			box.setMargin(6)
 			layout.addWidget(box)
-			self.textbrowser = qt.QTextBrowser(box)
-			self.textbrowser.setWordWrap(qt.QTextEdit.WidgetWidth)
-			self.textbrowser.setTextFormat(qt.Qt.RichText)
-			statusbox = qt.QFrame(box)
-			layout = qt.QGridLayout(statusbox,4,2,0,2)
-			layout.addWidget(qt.QLabel("Number of records done:",statusbox),0,0)
+			self.textbrowser = tqt.TQTextBrowser(box)
+			self.textbrowser.setWordWrap(tqt.TQTextEdit.WidgetWidth)
+			self.textbrowser.setTextFormat(tqt.TQt.RichText)
+			statusbox = tqt.TQFrame(box)
+			layout = tqt.TQGridLayout(statusbox,4,2,0,2)
+			layout.addWidget(tqt.TQLabel("Number of records done:",statusbox),0,0)
 			self.donecounter = 0
-			self.donelabel = qt.QLabel("-",statusbox)
+			self.donelabel = tqt.TQLabel("-",statusbox)
 			layout.addWidget(self.donelabel,0,1)
-			layout.addWidget(qt.QLabel("Successfully copied records:",statusbox),1,0)
+			layout.addWidget(tqt.TQLabel("Successfully copied records:",statusbox),1,0)
 			self.successcounter = 0
-			self.successlabel = qt.QLabel("-",statusbox)
+			self.successlabel = tqt.TQLabel("-",statusbox)
 			layout.addWidget(self.successlabel,1,1)
-			layout.addWidget(qt.QLabel("Failed to copy records:",statusbox),2,0)
+			layout.addWidget(tqt.TQLabel("Failed to copy records:",statusbox),2,0)
 			self.failedcounter = 0
-			self.failedlabel = qt.QLabel("-",statusbox)
+			self.failedlabel = tqt.TQLabel("-",statusbox)
 			layout.addWidget(self.failedlabel,2,1)
-			layout.addWidget(qt.QLabel("Elapsed time in seconds:",statusbox),3,0)
-			self.elapsedlabel = qt.QLabel("-",statusbox)
+			layout.addWidget(tqt.TQLabel("Elapsed time in seconds:",statusbox),3,0)
+			self.elapsedlabel = tqt.TQLabel("-",statusbox)
 			layout.addWidget(self.elapsedlabel,3,1)
-			btnbox = qt.QHBox(box)
+			btnbox = tqt.TQHBox(box)
 			btnbox.setSpacing(6)
-			self.donebtn = qt.QPushButton(btnbox)
+			self.donebtn = tqt.TQPushButton(btnbox)
 			self.donebtn.setText("Done")
 			self.donebtn.setEnabled(False)
-			qt.QObject.connect(self.donebtn,qt.SIGNAL("clicked()"),self.close)
-			self.cancelbtn = qt.QPushButton(btnbox)
+			tqt.TQObject.connect(self.donebtn,tqt.SIGNAL("clicked()"),self.close)
+			self.cancelbtn = tqt.TQPushButton(btnbox)
 			self.cancelbtn.setText("Cancel")
-			qt.QObject.connect(self.cancelbtn,qt.SIGNAL("clicked()"),self.close)
-			box.setMinimumSize( qt.QSize(500,380) )
+			tqt.TQObject.connect(self.cancelbtn,tqt.SIGNAL("clicked()"),self.close)
+			box.setMinimumSize( tqt.TQSize(500,380) )
 
 		def updateStates(self):
 			if self.starttime != None:
@@ -359,11 +359,11 @@ def runGuiApp(copycenter, name):
 		def writeSuccess(self, record, rowcount):
 			self.donecounter += rowcount
 			self.successcounter += rowcount
-			qt.tqApp.processEvents()
+			tqt.tqApp.processEvents()
 		def writeFailed(self, record):
 			self.donecounter += 1
 			self.failedcounter += 1
-			qt.tqApp.processEvents()
+			tqt.tqApp.processEvents()
 
 		def startCopy(self):
 			try:
@@ -373,16 +373,16 @@ def runGuiApp(copycenter, name):
 				copierer.writeSuccess = self.writeSuccess
 				copierer.writeFailed = self.writeFailed
 
-				self.starttime = qt.QTime()
-				self.updatetimer = qt.QTimer(self)
-				qt.QObject.connect(self.updatetimer,qt.SIGNAL("timeout()"),self.updateStates)
+				self.starttime = tqt.TQTime()
+				self.updatetimer = tqt.TQTimer(self)
+				tqt.TQObject.connect(self.updatetimer,tqt.SIGNAL("timeout()"),self.updateStates)
 
 				# Initialize the source
 				sourcename = self.dialog.getSourcePluginName()
 				sourceimpl = self.dialog.getSourcePluginImpl()
 				self.textbrowser.append("Source: %s" % sourcename)
 				if sourceimpl == None:
-					raise "No such source."
+					raise Exception("No such source.")
 				try:
 					sourceimpl.init(copierer)
 
@@ -391,13 +391,13 @@ def runGuiApp(copycenter, name):
 					destinationimpl = self.dialog.getDestinationPluginImpl()
 					self.textbrowser.append("<hr>Destination: %s" % destinationname)
 					if destinationimpl == None:
-						raise "No such destination."
+						raise Exception("No such destination.")
 					try:
 						destinationimpl.init(copierer)
 
 						self.starttime.start()
 						self.updatetimer.start(500)
-						qt.tqApp.processEvents()
+						tqt.tqApp.processEvents()
 
 						# Copy the records
 						self.textbrowser.append("<hr><i>Copy the records...</i>")
@@ -418,7 +418,7 @@ def runGuiApp(copycenter, name):
 				self.setCaption("Copy failed")
 				self.textbrowser.append("<b>Error: %s</b>" % sys.exc_info()[0])
 				import traceback
-				print "".join( traceback.format_exception(sys.exc_info()[0],sys.exc_info()[1],sys.exc_info()[2]) )
+				print("".join( traceback.format_exception(sys.exc_info()[0],sys.exc_info()[1],sys.exc_info()[2]) ))
 			#self.progressbar.setEnabled(False)
 			self.donebtn.setEnabled(True)
 			self.cancelbtn.setEnabled(False)
@@ -426,13 +426,13 @@ def runGuiApp(copycenter, name):
 			self.starttime = None
 
 		def show(self):
-			qt.QDialog.show(self)
-			qt.QTimer.singleShot(10,self.startCopy)
-			qt.tqApp.processEvents()
+			tqt.TQDialog.show(self)
+			tqt.TQTimer.singleShot(10,self.startCopy)
+			tqt.tqApp.processEvents()
 
 		def closeEvent(self, closeevent):
 			if not self.dialog.getSourcePluginImpl().isFinished():
-				if qt.QMessageBox.warning(self,"Abort?","Abort the copy?",qt.QMessageBox.Yes,qt.QMessageBox.No) != qt.QMessageBox.Yes:
+				if tqt.TQMessageBox.warning(self,"Abort?","Abort the copy?",tqt.TQMessageBox.Yes,tqt.TQMessageBox.No) != tqt.TQMessageBox.Yes:
 					closeevent.ignore()
 					return
 				self.dialog.getSourcePluginImpl().finish()
@@ -441,38 +441,38 @@ def runGuiApp(copycenter, name):
 
 	#--------------------------------------------------------------------
 
-	class DataSelector(qt.QVGroupBox):
+	class DataSelector(tqt.TQVGroupBox):
 		def __init__(self, plugintype, title, caption, parent, dialog, items):
 			self.plugintype = plugintype
 			self.pluginimpl = None
 			self.dialog = dialog
 			self.mainbox = None
 
-			qt.QVGroupBox.__init__(self,title,parent)
+			tqt.TQVGroupBox.__init__(self,title,parent)
 			self.setInsideMargin(6)
 			self.setInsideSpacing(0)
 
-			typebox = qt.QHBox(self)
-			label = qt.QLabel(caption,typebox)
-			self.combobox = qt.QComboBox(typebox)
+			typebox = tqt.TQHBox(self)
+			label = tqt.TQLabel(caption,typebox)
+			self.combobox = tqt.TQComboBox(typebox)
 			for item in items:
 				self.combobox.insertItem(str(item))
 			label.setBuddy(self.combobox)
 			typebox.setStretchFactor(self.combobox,1)
 
-			self.scrollview = qt.QScrollView(self)
+			self.scrollview = tqt.TQScrollView(self)
 			try:
-				self.scrollview.setResizePolicy(qt.QScrollView.AutoOne)
-				self.scrollview.setFrameStyle(qt.QFrame.NoFrame);
-				self.scrollview.setResizePolicy(qt.QScrollView.AutoOneFit);
+				self.scrollview.setResizePolicy(tqt.TQScrollView.AutoOne)
+				self.scrollview.setFrameStyle(tqt.TQFrame.NoFrame);
+				self.scrollview.setResizePolicy(tqt.TQScrollView.AutoOneFit);
 				self.scrollview.viewport().setPaletteBackgroundColor(self.paletteBackgroundColor())
 			except:
 				import traceback
-				print "".join( traceback.format_exception(sys.exc_info()[0],sys.exc_info()[1],sys.exc_info()[2]) )
-			qt.QObject.connect(self.combobox, qt.SIGNAL("activated(int)"), self.activated)
+				print("".join( traceback.format_exception(sys.exc_info()[0],sys.exc_info()[1],sys.exc_info()[2]) ))
+			tqt.TQObject.connect(self.combobox, tqt.SIGNAL("activated(int)"), self.activated)
 
 		def updatePlugin(self):
-			print "DataSelector.updatePlugin"
+			print("DataSelector.updatePlugin")
 			self.pluginimpl = None
 			text = str(self.combobox.currentText())
 			plugin = self.dialog.copycenter.plugins[text]
@@ -488,17 +488,17 @@ def runGuiApp(copycenter, name):
 			self.mainbox = None
 
 		def updateMainBox(self):
-			print "DataSelector.updateMainBox"
+			print("DataSelector.updateMainBox")
 			self.removeMainBox()
-			self.mainbox = qt.QVBox( self.scrollview.viewport() )
+			self.mainbox = tqt.TQVBox( self.scrollview.viewport() )
 			self.mainbox.setSpacing(2)
 			if self.pluginimpl != None:
 				try:
 					self.pluginimpl.createWidget(self.dialog, self.mainbox)
 				except:
 					import traceback
-					print "".join( traceback.format_exception(sys.exc_info()[0],sys.exc_info()[1],sys.exc_info()[2]) )
-			self.mainbox.setStretchFactor(qt.QWidget(self.mainbox), 1)
+					print("".join( traceback.format_exception(sys.exc_info()[0],sys.exc_info()[1],sys.exc_info()[2]) ))
+			self.mainbox.setStretchFactor(tqt.TQWidget(self.mainbox), 1)
 			self.mainbox.show()
 			self.scrollview.addChild(self.mainbox)
 
@@ -507,42 +507,42 @@ def runGuiApp(copycenter, name):
 			self.updateMainBox()
 
 		def maybeUpdate(self):
-			print "DataSelector.maybeUpdate"
+			print("DataSelector.maybeUpdate")
 			self.removeMainBox()
-			qt.QTimer.singleShot(50, self.activated)
+			tqt.TQTimer.singleShot(50, self.activated)
 
 		def maybeDone(self):
-			print "DataSelector.maybeDone"
+			print("DataSelector.maybeDone")
 			if self.pluginimpl.widget == None: return
 			for optionname in self.pluginimpl.options:
 				self.pluginimpl.options[optionname] = self.pluginimpl.widget.getOptionValue(optionname)
 
 	#--------------------------------------------------------------------
 
-	class Dialog(qt.QDialog):
+	class Dialog(tqt.TQDialog):
 		def __init__(self, copycenter, parent):
 			self.copycenter = copycenter
 
-			import qt
+			from TQt import tqt
 			import os
 			import sys
 
 			self.ListViewDialog = ListViewDialog
-			qt.QDialog.__init__(self, parent, "Dialog", 1, qt.Qt.WDestructiveClose)
+			tqt.TQDialog.__init__(self, parent, "Dialog", 1, tqt.TQt.WDestructiveClose)
 			self.setCaption("Copy Center")
-			layout = qt.QVBoxLayout(self)
-			box = qt.QVBox(self)
+			layout = tqt.TQVBoxLayout(self)
+			box = tqt.TQVBox(self)
 			box.setMargin(6)
 			box.setSpacing(6)
 			layout.addWidget(box)
-			self.tab = qt.QTabWidget(box)
+			self.tab = tqt.TQTabWidget(box)
 			self.tab.setMargin(6)
 			box.setStretchFactor(self.tab,1)
 
 			self.jobsbox = CopyJobWidget(self,self.tab)
 			self.tab.addTab(self.jobsbox,"Jobs")
 
-			self.splitter = qt.QSplitter(self.tab)
+			self.splitter = tqt.TQSplitter(self.tab)
 
 			sourceplugins = []
 			destinationplugins = []
@@ -565,30 +565,30 @@ def runGuiApp(copycenter, name):
 				"Destination:", # caption
 				self.splitter, self, destinationplugins)
 
-			btnbox = qt.QHBox(box)
+			btnbox = tqt.TQHBox(box)
 			btnbox.setSpacing(6)
-			okbtn = qt.QPushButton(btnbox)
+			okbtn = tqt.TQPushButton(btnbox)
 			okbtn.setText("Start Copy")
 			okbtn.setDefault(True)
-			qt.QObject.connect(okbtn,qt.SIGNAL("clicked()"),self.startCopy)
-			cancelbtn = qt.QPushButton(btnbox)
+			tqt.TQObject.connect(okbtn,tqt.SIGNAL("clicked()"),self.startCopy)
+			cancelbtn = tqt.TQPushButton(btnbox)
 			cancelbtn.setText("Cancel")
-			qt.QObject.connect(cancelbtn,qt.SIGNAL("clicked()"),self.close)
+			tqt.TQObject.connect(cancelbtn,tqt.SIGNAL("clicked()"),self.close)
 
 			self.tab.addTab(self.splitter,"Copy")
 			self.tab.setCurrentPage(1)
 
-			self.helpbrowser = qt.QTextBrowser(self.tab)
+			self.helpbrowser = tqt.TQTextBrowser(self.tab)
 			self.helpbrowser.setLinkUnderline(False)
 			self.helpbrowser.setUndoRedoEnabled(False)
 			self.tab.addTab(self.helpbrowser,"Help")
-			qt.QObject.connect(self.tab,qt.SIGNAL("currentChanged(QWidget*)"),self.currentTabChanged)
+			tqt.TQObject.connect(self.tab,tqt.SIGNAL("currentChanged(TQWidget*)"),self.currentTabChanged)
+
+			box.setMinimumSize( tqt.TQSize(760,500) )
 
-			box.setMinimumSize( qt.QSize(760,500) )
-			
 			defaultfile = os.path.join(self.copycenter.homepath,"default.copycenterjob.xml")
 			if os.path.isfile(defaultfile):
-				print "Reading default copy job file: %s" % defaultfile
+				print("Reading default copy job file: %s" % defaultfile)
 				self.jobsbox.jobfilecombobox.setCurrentText(defaultfile)
 
 		def getSourcePluginName(self):
@@ -619,7 +619,7 @@ def runGuiApp(copycenter, name):
 				fh = open(file,'r')
 				self.helpbrowser.setText( fh.read() )
 				fh.close()
-				
+
 		def startCopy(self):
 			dlg = ProgressDialog(self)
 			dlg.show()
@@ -627,10 +627,10 @@ def runGuiApp(copycenter, name):
 	#--------------------------------------------------------------------
 
 	if name == "__main__":
-		qtapp = qt.QApplication(sys.argv)
+		tqtapp = tqt.TQApplication(sys.argv)
 	else:
-		qtapp = qt.tqApp
-	dialog = Dialog(copycenter, qtapp.mainWidget())
+		tqtapp = tqt.tqApp
+	dialog = Dialog(copycenter, tqtapp.mainWidget())
 	dialog.exec_loop()
 
 import os
