@@ -216,7 +216,7 @@ AlterTableTester::AlterTableTester()
  , m_finishedCopying(false)
 {
 	//copy the db file to a temp file
-	qInitNetworkProtocols();
+	tqInitNetworkProtocols();
 	TQPtrList<TQNetworkOperation> list = m_copyOperator.copy( 
 		"file://" + TQDir::current().path() + "/" + origDbFilename, 
 		"file://" + TQDir::current().path() + "/" + dbFilename, false, false );
@@ -687,10 +687,10 @@ int main(int argc, char *argv[])
 
 	newArgc = 2;
 	newArgv = new char*[newArgc];
-	newArgv[0] = qstrdup(argv[0]);
-	newArgv[1] = qstrdup( "--skip-startup-dialog" );
+	newArgv[0] = tqstrdup(argv[0]);
+	newArgv[1] = tqstrdup( "--skip-startup-dialog" );
 
-	KAboutData* aboutdata = Kexi::createAboutData();
+	TDEAboutData* aboutdata = Kexi::createAboutData();
 	aboutdata->setProgramName( "Kexi Alter Table Test" );
 	int result = KexiMainWindowImpl::create(newArgc, newArgv, aboutdata);
 	if (!tqApp)
