@@ -29,16 +29,16 @@
 #include <tqtooltip.h>
 #include <tqwhatsthis.h>
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
 #include <kdebug.h>
-#include <klocale.h>
-#include <kpopupmenu.h>
-#include <klistview.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdepopupmenu.h>
+#include <tdelistview.h>
+#include <tdemessagebox.h>
 #include <klineedit.h>
 #include <kimageeffect.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 
 #include <kexi.h>
 #include <kexipart.h>
@@ -72,7 +72,7 @@ KexiBrowser::KexiBrowser(TQWidget* parent, KexiMainWindow *mainWin, int features
  : TQWidget(parent, "KexiBrowser")
  , m_mainWin(mainWin)
  , m_features(features)
- , m_actions( new KActionCollection(this) )
+ , m_actions( new TDEActionCollection(this) )
  , m_baseItems(199, false)
  , m_normalItems(199)
  , m_prevSelectedPart(0)
@@ -103,12 +103,12 @@ KexiBrowser::KexiBrowser(TQWidget* parent, KexiMainWindow *mainWin, int features
 	m_list->setTooltipColumn(0);
 	m_list->renameLineEdit()->setValidator( new KexiUtils::IdentifierValidator(TQT_TQOBJECT(this)) );
 	m_list->setResizeMode(TQListView::LastColumn);
-	connect(m_list, TQT_SIGNAL(contextMenu(KListView *, TQListViewItem *, const TQPoint &)),
-		TQT_TQOBJECT(this), TQT_SLOT(slotContextMenu(KListView*, TQListViewItem *, const TQPoint&)));
+	connect(m_list, TQT_SIGNAL(contextMenu(TDEListView *, TQListViewItem *, const TQPoint &)),
+		TQT_TQOBJECT(this), TQT_SLOT(slotContextMenu(TDEListView*, TQListViewItem *, const TQPoint&)));
 	connect(m_list, TQT_SIGNAL(selectionChanged(TQListViewItem*)), this,
 		TQT_SLOT(slotSelectionChanged(TQListViewItem*)));
 	
-	KConfig *config = kapp->config();
+	TDEConfig *config = kapp->config();
 	config->setGroup("MainWindow");
 	if ((m_features & SingleClickOpensItemOptionEnabled) 
 		&& config->readBoolEntry("SingleClickOpensItem", false))
@@ -123,7 +123,7 @@ KexiBrowser::KexiBrowser(TQWidget* parent, KexiMainWindow *mainWin, int features
 	}
 
 	// actions
-	m_openAction = new KAction(i18n("&Open"), "fileopen", 0/*TQt::Key_Enter conflict!*/, TQT_TQOBJECT(this), 
+	m_openAction = new TDEAction(i18n("&Open"), "document-open", 0/*TQt::Key_Enter conflict!*/, TQT_TQOBJECT(this), 
 		TQT_SLOT(slotOpenObject()), TQT_TQOBJECT(this), "open_object");
 	m_openAction->setToolTip(i18n("Open object"));
 	m_openAction->setWhatsThis(i18n("Opens object selected in the list"));
@@ -145,12 +145,12 @@ KexiBrowser::KexiBrowser(TQWidget* parent, KexiMainWindow *mainWin, int features
 		m_newObjectPopup = 0;
 	}
 	else {
-		m_deleteAction = new KAction(i18n("&Delete"), "editdelete", 0/*TQt::Key_Delete*/, 
+		m_deleteAction = new TDEAction(i18n("&Delete"), "edit-delete", 0/*TQt::Key_Delete*/, 
 			TQT_TQOBJECT(this), TQT_SLOT(slotRemove()), m_actions, "edit_delete");
 	//! @todo 1.1: just add "Delete" tooltip and what's this
 		m_deleteAction->setToolTip(i18n("&Delete").replace("&",""));
 
-		m_renameAction = new KAction(i18n("&Rename"), "", 0, 
+		m_renameAction = new TDEAction(i18n("&Rename"), "", 0, 
 			TQT_TQOBJECT(this), TQT_SLOT(slotRename()), m_actions, "edit_rename");
 #ifdef KEXI_SHOW_UNIMPLEMENTED
 		//todo	plugSharedAction("edit_cut",TQT_SLOT(slotCut()));
@@ -158,7 +158,7 @@ KexiBrowser::KexiBrowser(TQWidget* parent, KexiMainWindow *mainWin, int features
 		//todo	plugSharedAction("edit_paste",TQT_SLOT(slotPaste()));
 #endif
 
-		m_designAction = new KAction(i18n("&Design"), "edit", 0/*TQt::CTRL + TQt::Key_Enter conflict!*/, TQT_TQOBJECT(this), 
+		m_designAction = new TDEAction(i18n("&Design"), "edit", 0/*TQt::CTRL + TQt::Key_Enter conflict!*/, TQT_TQOBJECT(this), 
 			TQT_SLOT(slotDesignObject()), TQT_TQOBJECT(this), "design_object");
 		m_designAction->setToolTip(i18n("Design object"));
 		m_designAction->setWhatsThis(i18n("Starts designing of the object selected in the list"));
@@ -167,15 +167,15 @@ KexiBrowser::KexiBrowser(TQWidget* parent, KexiMainWindow *mainWin, int features
 			buttons_flyr->add(btn);
 		}
 
-		m_editTextAction = new KAction(i18n("Open in &Text View"), "", 0, TQT_TQOBJECT(this), 
+		m_editTextAction = new TDEAction(i18n("Open in &Text View"), "", 0, TQT_TQOBJECT(this), 
 			TQT_SLOT(slotEditTextObject()), TQT_TQOBJECT(this), "editText_object");
 		m_editTextAction->setToolTip(i18n("Open object in text view"));
 		m_editTextAction->setWhatsThis(i18n("Opens selected object in the list in text view"));
 
-		m_newObjectAction = new KAction("", "filenew", 0, TQT_TQOBJECT(this), TQT_SLOT(slotNewObject()), TQT_TQOBJECT(this), "new_object");
+		m_newObjectAction = new TDEAction("", "document-new", 0, TQT_TQOBJECT(this), TQT_SLOT(slotNewObject()), TQT_TQOBJECT(this), "new_object");
 		if (m_features & Toolbar) {
 			m_newObjectToolButton = new KexiSmallToolButton(this, "", TQIconSet(), "new_object");
-			m_newObjectPopup = new KPopupMenu(this, "newObjectPopup");
+			m_newObjectPopup = new TDEPopupMenu(this, "newObjectPopup");
 			connect(m_newObjectPopup, TQT_SIGNAL(aboutToShow()), TQT_TQOBJECT(this), TQT_SLOT(slotNewObjectPopupAboutToShow()));
 		//	KexiPart::Part* part = Kexi::partManager().part("kexi/table");
 		//	m_newObjectPopup->insertItem( SmallIconSet(part->info()->createItemIcon()), part->instanceName() );
@@ -190,21 +190,21 @@ KexiBrowser::KexiBrowser(TQWidget* parent, KexiMainWindow *mainWin, int features
 		}
 	}
 
-	m_executeAction = new KAction(i18n("Execute"), "player_play", 0, TQT_TQOBJECT(this),
+	m_executeAction = new TDEAction(i18n("Execute"), "media-playback-start", 0, TQT_TQOBJECT(this),
 		TQT_SLOT(slotExecuteObject()), TQT_TQOBJECT(this), "data_execute");
 
-	m_exportActionMenu = new KActionMenu(i18n("Export"));
-	m_dataExportAction = new KAction(i18n("Export->To File as Data &Table... ", "To &File as Data Table..."), 
+	m_exportActionMenu = new TDEActionMenu(i18n("Export"));
+	m_dataExportAction = new TDEAction(i18n("Export->To File as Data &Table... ", "To &File as Data Table..."), 
 		"table", 0, TQT_TQOBJECT(this), TQT_SLOT(slotExportAsDataTable()), TQT_TQOBJECT(this), "exportAsDataTable");
 	m_dataExportAction->setWhatsThis(
 		i18n("Exports data from the currently selected table or query data to a file."));
 	m_exportActionMenu->insert( m_dataExportAction );
 
-	m_printAction = new KAction(i18n("&Print..."), "fileprint", 0, TQT_TQOBJECT(this), 
+	m_printAction = new TDEAction(i18n("&Print..."), "document-print", 0, TQT_TQOBJECT(this), 
 		TQT_SLOT(slotPrintItem()), TQT_TQOBJECT(this), "printItem");
 	m_printAction->setWhatsThis(
 		i18n("Prints data from the currently selected table or query."));
-	m_pageSetupAction = new KAction(i18n("Page Setup..."), "", 0, TQT_TQOBJECT(this), 
+	m_pageSetupAction = new TDEAction(i18n("Page Setup..."), "", 0, TQT_TQOBJECT(this), 
 		TQT_SLOT(slotPageSetupForItem()), TQT_TQOBJECT(this), "pageSetupForItem");
 	m_pageSetupAction->setWhatsThis(
 		i18n("Shows page setup for printing the active table or query."));
@@ -214,7 +214,7 @@ KexiBrowser::KexiBrowser(TQWidget* parent, KexiMainWindow *mainWin, int features
 		m_partPopup = 0;
 	}
 	else {
-		m_partPopup = new KPopupMenu(this, "partPopup");
+		m_partPopup = new TDEPopupMenu(this, "partPopup");
 		m_partPopupTitle_id = m_partPopup->insertTitle("");
 		m_newObjectAction->plug(m_partPopup);
 #ifdef KEXI_SHOW_UNIMPLEMENTED
@@ -225,7 +225,7 @@ KexiBrowser::KexiBrowser(TQWidget* parent, KexiMainWindow *mainWin, int features
 
 	if (m_features & ContextMenus) {
 		//init popups
-		m_itemPopup = new KPopupMenu(this, "itemPopup");
+		m_itemPopup = new TDEPopupMenu(this, "itemPopup");
 		m_itemPopupTitle_id = m_itemPopup->insertTitle("");
 		m_openAction->plug(m_itemPopup);
 		m_openAction_id = m_itemPopup->idAt(m_itemPopup->count()-1);
@@ -411,12 +411,12 @@ KexiBrowser::slotRemoveItem(const KexiPart::Item &item)
 }
 
 void
-KexiBrowser::slotContextMenu(KListView* /*list*/, TQListViewItem *item, const TQPoint &pos)
+KexiBrowser::slotContextMenu(TDEListView* /*list*/, TQListViewItem *item, const TQPoint &pos)
 {
 	if(!item || !(m_features & ContextMenus))
 		return;
 	KexiBrowserItem *bit = static_cast<KexiBrowserItem*>(item);
-	KPopupMenu *pm = 0;
+	TDEPopupMenu *pm = 0;
 	if (bit->item()) {
 		pm = m_itemPopup;
 		//update popup title
@@ -536,10 +536,10 @@ KexiBrowser::slotSelectionChanged(TQListViewItem* i)
 		} else {
 			if (m_newObjectAction) {
 				m_newObjectAction->setText(i18n("&Create Object..."));
-	//			m_newObjectToolbarAction->setIconSet( SmallIconSet("filenew") );
+	//			m_newObjectToolbarAction->setIconSet( SmallIconSet("document-new") );
 	//			m_newObjectToolbarAction->setText(m_newObjectAction->text());
 				if (m_features & Toolbar) {
-					m_newObjectToolButton->setIconSet( "filenew" );
+					m_newObjectToolButton->setIconSet( "document-new" );
 					TQToolTip::add(m_newObjectToolButton, i18n("Create object"));
 					TQWhatsThis::add(m_newObjectToolButton, i18n("Creates a new object"));
 				}
@@ -733,7 +733,7 @@ void KexiBrowser::updateItemName( KexiPart::Item& item, bool dirty )
 
 void KexiBrowser::slotSettingsChanged(int)
 {
-	m_singleClick = KGlobalSettings::singleClick();
+	m_singleClick = TDEGlobalSettings::singleClick();
 }
 
 void KexiBrowser::selectItem(KexiPart::Item& item)
@@ -762,7 +762,7 @@ void KexiBrowser::slotNewObjectPopupAboutToShow()
 		KexiPart::PartInfoList *list = Kexi::partManager().partInfoList(); //this list is properly sorted
 		for (KexiPart::PartInfoListIterator it(*list); it.current(); ++it) {
 			//add an item to "New object" toolbar popup 
-			KAction *action = m_mainWin->actionCollection()->action( 
+			TDEAction *action = m_mainWin->actionCollection()->action( 
 				TQString(KexiPart::nameForCreateAction(*it.current())).ascii() );
 			if (action) {
 				action->plug(m_newObjectPopup);
@@ -853,7 +853,7 @@ void KexiBrowser::clear()
 
 //--------------------------------------------
 KexiBrowserListView::KexiBrowserListView(TQWidget *parent)
- : KListView(parent, "KexiBrowserListView")
+ : TDEListView(parent, "KexiBrowserListView")
  , nameEndsWithAsterisk(false)
  , enableExecuteArea(true)
 {
@@ -876,14 +876,14 @@ void KexiBrowserListView::rename(TQListViewItem *item, int c)
 		nameEndsWithAsterisk = item->text(0).endsWith("*");
 		if (nameEndsWithAsterisk)
 			item->setText(0, item->text(0).left(item->text(0).length()-1));
-		KListView::rename(item, c);
+		TDEListView::rename(item, c);
 		adjustColumn(0);
 	}
 }
 
 bool KexiBrowserListView::isExecuteArea( const TQPoint& point )
 {
-	return enableExecuteArea && KListView::isExecuteArea(point);
+	return enableExecuteArea && TDEListView::isExecuteArea(point);
 }
 
 #include "kexibrowser.moc"
