@@ -97,7 +97,7 @@ class Plugin
 class KSPREAD_EXPORT Doc : public KoDocument, public KoZoomHandler
 {
   Q_OBJECT
-  TQ_OBJECT
+  
   TQ_PROPERTY( bool getShowRowHeader READ getShowRowHeader )
   TQ_PROPERTY( bool getShowColHeader READ getShowColHeader )
   TQ_PROPERTY( double getIndentValue READ getIndentValue WRITE setIndentValue )
@@ -151,7 +151,7 @@ public:
    */
   virtual TQCString mimeType() const { return MIME_TYPE; }
 
-  KLocale *locale () const;
+  TDELocale *locale () const;
   Map *map () const;
   StyleManager *styleManager () const;
   ValueParser *parser () const;
@@ -377,8 +377,8 @@ public:
   * completion mode
   */
 
-  KGlobalSettings::Completion completionMode( )const ;
-  void setCompletionMode( KGlobalSettings::Completion _complMode);
+  TDEGlobalSettings::Completion completionMode( )const ;
+  void setCompletionMode( TDEGlobalSettings::Completion _complMode);
 
   KSpread::MoveTo getMoveToValue()const;
   void setMoveToValue(KSpread::MoveTo _moveTo) ;
@@ -391,9 +391,9 @@ public:
 
 
   /**
-   * get custom kspell config
+   * get custom tdespell config
    */
-  void setKSpellConfig(KSpellConfig _kspell);
+  void setKSpellConfig(KSpellConfig _tdespell);
   KSpellConfig * getKSpellConfig();
 
   bool dontCheckUpperWord() const;
@@ -517,7 +517,7 @@ public:
   void addAreaName(const TQRect &_rect,const TQString & name,const TQString & sheetName);
   const TQValueList<Reference>  & listArea();
   void removeArea( const TQString &name);
-  KCompletion & completion();
+  TDECompletion & completion();
   void addStringCompletion(const TQString & stringCompletion);
 
   void changeAreaSheetName(const TQString & oldName,const TQString &sheetName);
