@@ -34,7 +34,7 @@
 class TQDomElement;
 class TQDomDocument;
 class DCOPObject;
-class KLocale;
+class TDELocale;
 class KoGenStyle;
 class KoGenStyles;
 class KoOasisLoadingContext;
