@@ -14,30 +14,30 @@ Dual-licensed under LGPL v2+higher and the BSD license.
 import os, sys
 
 try:
-	import qt
+	from TQt import tqt
 except (ImportError):
-	raise "Failed to import the required PyQt python module."
+	raise Exception("Failed to import the required PyTQt python module.")
 
 ####################################################################################
 # Samples.
 
-class Widget(qt.QHBox):
+class Widget(tqt.TQHBox):
 	def __init__(self, parentwidget, label = None):
 		self.parentwidget = parentwidget
-		import qt
-		qt.QHBox.__init__(self, parentwidget)
+		from TQt import tqt
+		tqt.TQHBox.__init__(self, parentwidget)
 		self.setMargin(4)
 		self.setSpacing(4)
-		if label != None: qt.QLabel(label, self)
+		if label != None: tqt.TQLabel(label, self)
 	def value(self):
 		return None
 
 class ListWidget(Widget):
 	def __init__(self, parentwidget, label):
-		import qt
+		from TQt import tqt
 		global Widget
 		Widget.__init__(self, parentwidget, label)
-		self.combo = qt.QComboBox(self)
+		self.combo = tqt.TQComboBox(self)
 		self.combo.setEditable(True)
 		self.setStretchFactor(self.combo,1)
 	def value(self):
@@ -45,10 +45,10 @@ class ListWidget(Widget):
 
 class EditWidget(Widget):
 	def __init__(self, parentwidget, label):
-		import qt
+		from TQt import tqt
 		global Widget
 		Widget.__init__(self, parentwidget, label)
-		self.edit = qt.QLineEdit(self)
+		self.edit = tqt.TQLineEdit(self)
 		self.setStretchFactor(self.edit,1)
 	def value(self):
 		return self.edit.text()
@@ -57,20 +57,20 @@ class FileWidget(Widget):
 	def __init__(self, parentwidget, label, filtermask, openfiledialog = True):
 		self.filtermask = filtermask
 		self.openfiledialog = openfiledialog
-		import qt
+		from TQt import tqt
 		global Widget
 		Widget.__init__(self, parentwidget, label)
-		self.edit = qt.QLineEdit(self)
+		self.edit = tqt.TQLineEdit(self)
 		self.setStretchFactor(self.edit,1)
-		btn = qt.QPushButton("...",self)
-		qt.QObject.connect(btn, qt.SIGNAL("clicked()"), self.btnClicked)
+		btn = tqt.TQPushButton("...",self)
+		tqt.TQObject.connect(btn, tqt.SIGNAL("clicked()"), self.btnClicked)
 	def btnClicked(self):
-		import qt
+		from TQt import tqt
 		text = str( self.edit.text() )
 		if self.openfiledialog:
-			filename = str( qt.QFileDialog.getOpenFileName(text, self.filtermask, self.parentwidget) )
+			filename = str( tqt.TQFileDialog.getOpenFileName(text, self.filtermask, self.parentwidget) )
 		else:
-			filename = qt.QFileDialog.getSaveFileName(text, self.filtermask, self.parentwidget)
+			filename = tqt.TQFileDialog.getSaveFileName(text, self.filtermask, self.parentwidget)
 		if filename != "": self.edit.setText( filename )
 	def value(self):
 		return self.edit.text()
@@ -113,13 +113,13 @@ class Samples:
 				return (
 					'import krosskexidb',
 					'drivermanager = krosskexidb.DriverManager()',
-					'print "drivernames: %s" % drivermanager.driverNames()',
+					'print("drivernames: %s" % drivermanager.driverNames())',
 					'',
 					'driver = drivermanager.driver( \"{DriverName}\" )',
-					'print "driver: {DriverName}"',
-					'print "version=%s.%s" % (driver.versionMajor(),driver.versionMinor())',
-					'print "mimetype=%s" % driver.fileDBDriverMimeType()',
-					'print "filedriver=%s" % driver.isFileDriver()',
+					'print("driver: {DriverName}")',
+					'print("version=%s.%s" % (driver.versionMajor(),driver.versionMinor())ú',
+					'print("mimetype=%s" % driver.fileDBDriverMimeType()ú',
+					'print("filedriver=%s" % driver.isFileDriver())',
 				)
 
 		class ConnectWithFile:
@@ -137,7 +137,7 @@ class Samples:
 					'',
 					'# Get the connectiondata from the project file.',
 					'connectiondata = drivermanager.createConnectionDataByFile( "{ProjectFile}" )',
-					'print "Connectiondata: %s" % connectiondata.serverInfoString()',
+					'print("Connectiondata: %s" % connectiondata.serverInfoString())',
 					'',
 					'# Create the driver for the database backend.',
 					'driver = drivermanager.driver( connectiondata.driverName() )',
@@ -146,19 +146,19 @@ class Samples:
 					'connection = driver.createConnection(connectiondata)',
 					'if not connection.isConnected():',
 					'	if not connection.connect():',
-					'		raise "Failed to connect"',
+					'		raise Exception("Failed to connect")',
 					'',
 					'# Open the database for usage.',
-					'print "Databases: %s" % connection.databaseNames()',
+					'print("Databases: %s" % connection.databaseNames())',
 					'if not connection.isDatabaseUsed():',
 					'	if not connection.useDatabase( connectiondata.databaseName() ):',
 					'		if not connection.useDatabase( connectiondata.fileName() ):',
-					'			raise "Failed to use database"',
+					'			raise Exception("Failed to use database")',
 					'',
 					'# Print some infos.',
-					'print "All tables: %s" % connection.allTableNames()',
-					'print "Tables: %s" % connection.tableNames()',
-					'print "Queries: %s" % connection.queryNames()',
+					'print("All tables: %s" % connection.allTableNames())',
+					'print("Tables: %s" % connection.tableNames())',
+					'print("Queries: %s" % connection.queryNames())',
 				)
 
 		class IterateThroughTable:
@@ -177,7 +177,7 @@ class Samples:
 					'',
 					'# Get the connectiondata from the project file.',
 					'connectiondata = drivermanager.createConnectionDataByFile( "{ProjectFile}" )',
-					'print "Connectiondata: %s" % connectiondata.serverInfoString()',
+					'print("Connectiondata: %s" % connectiondata.serverInfoString())',
 					'',
 					'# Create the driver for the database backend.',
 					'driver = drivermanager.driver( connectiondata.driverName() )',
@@ -186,13 +186,13 @@ class Samples:
 					'connection = driver.createConnection(connectiondata)',
 					'if not connection.isConnected():',
 					'	if not connection.connect():',
-					'		raise "Failed to connect"',
+					'		raise Exception("Failed to connect")',
 					'',
 					'# Open the database for usage.',
 					'if not connection.isDatabaseUsed():',
 					'	if not connection.useDatabase( connectiondata.databaseName() ):',
 					'		if not connection.useDatabase( connectiondata.fileName() ):',
-					'			raise "Failed to use database"',
+					'			raise Exception("Failed to use database")',
 					'',
 					'# Get the table and create a query for it.',
 					'table = connection.tableSchema( \"{TableName}\" )',
@@ -201,14 +201,14 @@ class Samples:
 					'# Create a cursor to walk through the records.',
 					'cursor = connection.executeQuerySchema( query )',
 					'if not cursor:',
-					'	raise "Failed to create cursor."',
+					'	raise Exception("Failed to create cursor.")',
 					'',
 					'# Iterate through the records.',
 					'if not cursor.moveFirst():',
-					'	raise "The cursor has no records to read from."',
+					'	raise Exception("The cursor has no records to read from.")',
 					'while not cursor.eof():',
 					'	for i in range( cursor.fieldCount() ):',
-					'		print "%s" % cursor.value(i)',
+					'		print("%s" % cursor.value(i))',
 					'	cursor.moveNext()',
 				)
 
@@ -232,7 +232,7 @@ class Samples:
 				except:
 					import traceback
 					trace = "".join( traceback.format_exception(sys.exc_info()[0],sys.exc_info()[1],sys.exc_info()[2]) )
-					print trace
+					print(trace)
 
 		class _CellsWidget(ListWidget):
 			def __init__(self, parentwidget):
@@ -279,13 +279,13 @@ class Samples:
 					'# Get the sheet defined by the sheetname.',
 					'sheet = document.sheetByName( \"{SheetName}\" )',
 					'if not sheet:',
-					'	raise "No such sheet {SheetName} %s" % document.sheetNames()',
+					'	raise Exception("No such sheet {SheetName} %s" % document.sheetNames())',
 					'',
 					'( (col1,row1),(col2,row2) ) = {Cells}',
 					'for c in range(col1,col2):',
 					'	for r in range(row1,row2):',
 					'		cell = sheet.cell(c,r)',
-					'		print "cell c=%s r=%s v=%s" % (c,r,cell.value())',
+					'		print("cell c=%s r=%s v=%s" % (c,r,cell.value()))',
 					'		cell.setText( \"{Value}\" )',
 				)
 
@@ -311,7 +311,7 @@ class Samples:
 					'# Get the sheet defined by the sheetname.',
 					'sheet = document.sheetByName( \"{SheetName}\" )',
 					'if not sheet:',
-					'	raise "No such sheet {SheetName} %s" % document.sheetNames()',
+					'	raise Exception("No such sheet {SheetName} %s" % document.sheetNames())',
 					'',
 					'( (col1,row1),(col2,row2) ) = {Cells}',
 					'for c in range(col1,col2):',
@@ -340,12 +340,12 @@ class Samples:
 					'# Get the sheet defined by the sheetname.',
 					'sheet = document.sheetByName( \"{SheetName}\" )',
 					'if not sheet:',
-					'	raise "No such sheet {SheetName} %s" % document.sheetNames()',
+					'	raise Exception("No such sheet {SheetName} %s" % document.sheetNames())',
 					'',
 					'# Iterate through the cells that have content (aka that are not empty).',
 					'cell = sheet.firstCell()',
 					'while cell:',
-					'	print "col=%s row=%s value=%s" % (cell.column(),cell.row(),cell.value())',
+					'	print("col=%s row=%s value=%s" % (cell.column(),cell.row(),cell.value()))',
 					'	cell = cell.nextCell()',
 				)
 
@@ -367,10 +367,10 @@ class Samples:
 					'# Get the sheet defined by the sheetname.',
 					'sheet = document.sheetByName( \"{SheetName}\" )',
 					'if not sheet:',
-					'	raise "No such sheet {SheetName} %s" % document.sheetNames()',
+					'	raise Exception("No such sheet {SheetName} %s" % document.sheetNames())',
 					'',
-					'print "name=%s" % sheet.name()',
-					'print "maxcolumns=%s maxrows=%s" % (sheet.maxColumn(),sheet.maxRow())',
+					'print("name=%s" % sheet.name())',
+					'print("maxcolumns=%s maxrows=%s" % (sheet.maxColumn(),sheet.maxRow()))',
 				)
 
 		class LoadDocFromNativeXML:
@@ -383,8 +383,8 @@ class Samples:
 				}
 			def getCode(self):
 				return (
-					'# Import the PyQt module.',
-					'import qt',
+					'# Import the PyTQt module.',
+					'from TQt import tqt',
 					'',
 					'def loadFile(filename):',
 					'	# Import the krosskspreadcore module.',
@@ -395,7 +395,7 @@ class Samples:
 					'		xml = file.read()',
 					'		file.close()',
 					'	except IOError, (errno, strerror):',
-					'		qt.QMessageBox.critical(self,"Error","<qt>Failed to read file %s<br><br>%s</qt>" % (filename,strerror))',
+					'		tqt.TQMessageBox.critical(self,"Error","<qt>Failed to read file %s<br><br>%s</qt>" % (filename,strerror))',
 					'		return',
 					'',
 					'	# Get the current document.',
@@ -405,7 +405,7 @@ class Samples:
 					'',
 					'# Show the openfile dialog',
 					'filename = "{FileName}"',
-					'openfilename = qt.QFileDialog.getOpenFileName(filename,"*.xml;;*", self)',
+					'openfilename = tqt.TQFileDialog.getOpenFileName(filename,"*.xml;;*", self)',
 					'if str(openfilename) != "":',
 					'	loadFile( openfilename )',
 				)
@@ -420,8 +420,8 @@ class Samples:
 				}
 			def getCode(self):
 				return (
-					'# Import the PyQt module.',
-					'import qt',
+					'# Import the PyTQt module.',
+					'from TQt import tqt',
 					'',
 					'def saveFile(filename):',
 					'	# Import the krosskspreadcore module.',
@@ -430,7 +430,7 @@ class Samples:
 					'	try:',
 					'		file = open(filename, "w")',
 					'	except IOError, (errno, strerror):',
-					'		qt.QMessageBox.critical(self,"Error","<qt>Failed to create file %s<br><br>%s</qt>" % (filename,strerror))',
+					'		tqt.TQMessageBox.critical(self,"Error","<qt>Failed to create file %s<br><br>%s</qt>" % (filename,strerror))',
 					'		return',
 					'	# Get the current document.',
 					'	document = krosskspreadcore.get("KSpreadDocument")',
@@ -443,7 +443,7 @@ class Samples:
 					'',
 					'# Show the savefile dialog',
 					'filename = "{FileName}"',
-					'savefilename = qt.QFileDialog.getSaveFileName(filename,"*.xml;;*", self)',
+					'savefilename = tqt.TQFileDialog.getSaveFileName(filename,"*.xml;;*", self)',
 					'if str(savefilename) != "":',
 					'	saveFile( savefilename )',
 				)
@@ -464,10 +464,10 @@ class Samples:
 					'document = krosskspreadcore.get("KSpreadDocument")',
 					'# Get the source sheet.',
 					'fromsheet = document.sheetByName( "{SourceSheet}" )',
-					'if not fromsheet: raise "No such sheet {SourceSheet} %s" % document.sheetNames()',
+					'if not fromsheet: raise Exception("No such sheet {SourceSheet} %s" % document.sheetNames())',
 					'# Get the target sheet.',
 					'tosheet = document.sheetByName( "{TargetSheet}" )',
-					'if not fromsheet: raise "No such sheet {TargetSheet} %s" % document.sheetNames()',
+					'if not fromsheet: raise Exception("No such sheet {TargetSheet} %s" % document.sheetNames())',
 					'# Copy the cells.',
 					'fromcell = fromsheet.firstCell()',
 					'while fromcell:',
@@ -492,13 +492,13 @@ class Samples:
 					'# Get the current document and the sheet.',
 					'document = krosskspreadcore.get("KSpreadDocument")',
 					'sheet = document.sheetByName( "{Sheet}" )',
-					'if not sheet: raise "No such sheet {Sheet} %s" % document.sheetNames()',
+					'if not sheet: raise Exception("No such sheet {Sheet} %s" % document.sheetNames())',
 					'',
 					'filename = "{FileName}"',
 					'try:',
 					'	file = open(filename, "r")',
 					'except IOError:',
-					'	raise "Failed to open CSV File: %s" % filename',
+					'	raise Exception("Failed to open CSV File: %s" % filename)',
 					'',
 					'import csv',
 					'csvparser = csv.reader(file)',
@@ -530,7 +530,7 @@ class Samples:
 					'try:',
 					'	file = open(filename, "w")',
 					'except IOError:',
-					'	raise "Failed to write CSV File: %s" % filename',
+					'	raise Exception("Failed to write CSV File: %s" % filename)',
 					'# Prepare CSV-writer',
 					'import csv',
 					'csvwriter = csv.writer(file)',
@@ -539,7 +539,7 @@ class Samples:
 					'# Get the current document and the sheet.',
 					'document = krosskspreadcore.get("KSpreadDocument")',
 					'sheet = document.sheetByName( "{Sheet}" )',
-					'if not sheet: raise "No such sheet {Sheet} %s" % document.sheetNames()',
+					'if not sheet: raise Exception("No such sheet {Sheet} %s" % document.sheetNames())',
 					'# Iterate over the cells.',
 					'cell = sheet.firstCell()',
 					'record = []',
@@ -554,14 +554,14 @@ class Samples:
 
 
 	####################################################################################
-	# PyQt
+	# PyTQt
 
-	class PyQt:
+	class PyTQt:
 		def __init__(self, parentwidget):
 			self.parentwidget = parentwidget
 
 		class OpenFileDialog:
-			""" Show the usage of the openfile dialog with QFileDialog. """
+			""" Show the usage of the openfile dialog with TQFileDialog. """
 			name = "Open File Dialog"
 			def __init__(self, parent):
 				pass
@@ -570,13 +570,13 @@ class Samples:
 				}
 			def getCode(self):
 				return (
-					'import qt',
-					'openfilename = qt.QFileDialog.getOpenFileName("{FileName}","*.txt *.html;;*", self)',
-					'print "openfile=%s" % openfilename',
+					'from TQt import tqt',
+					'openfilename = tqt.TQFileDialog.getOpenFileName("{FileName}","*.txt *.html;;*", self)',
+					'print("openfile=%s" % openfilename)',
 				)
 
 		class SaveFileDialog:
-			""" Show the usage of the savefile dialog with QFileDialog. """
+			""" Show the usage of the savefile dialog with TQFileDialog. """
 			name = "Save File Dialog"
 			def __init__(self, parent):
 				pass
@@ -585,13 +585,13 @@ class Samples:
 				}
 			def getCode(self):
 				return (
-					'import qt',
-					'savefilename = qt.QFileDialog.getSaveFileName("{FileName}","*.txt *.html;;*", self)',
-					'print "savefile=%s" % savefilename',
+					'from TQt import tqt',
+					'savefilename = tqt.TQFileDialog.getSaveFileName("{FileName}","*.txt *.html;;*", self)',
+					'print("savefile=%s" % savefilename)',
 				)
 
 		class CustomDialog:
-			""" Show a custom dialog that inherits a QDialog. """
+			""" Show a custom dialog that inherits a TQDialog. """
 			name = "Custom Dialog"
 			def __init__(self, parent):
 				pass
@@ -599,25 +599,25 @@ class Samples:
 				}
 			def getCode(self):
 				return (
-					'import qt',
+					'from TQt import tqt',
 					'',
-					'class MyDialog(qt.QDialog):',
+					'class MyDialog(tqt.TQDialog):',
 					'	def __init__(self, parent):',
-					'		import qt',
-					'		qt.QDialog.__init__(self, parent, "MyDialog", 1, qt.Qt.WDestructiveClose)',
+					'		from TQt import tqt',
+					'		tqt.TQDialog.__init__(self, parent, "MyDialog", 1, tqt.TQt.WDestructiveClose)',
 					'		self.setCaption("My Dialog")',
-					'		btn = qt.QPushButton("Click me",self)',
-					'		qt.QObject.connect(btn, qt.SIGNAL("clicked()"), self.buttonClicked)',
+					'		btn = tqt.TQPushButton("Click me",self)',
+					'		tqt.TQObject.connect(btn, tqt.SIGNAL("clicked()"), self.buttonClicked)',
 					'	def buttonClicked(self):',
-					'		import qt',
-					'		qt.QMessageBox.information(self, "The Caption", "This is the message string.")',
+					'		from TQt import tqt',
+					'		tqt.TQMessageBox.information(self, "The Caption", "This is the message string.")',
 					'',
 					'dialog = MyDialog(self)',
 					'dialog.exec_loop()',
 				)
 
 		class InputDialog:
-			""" Show how to use a QInputDialog. """
+			""" Show how to use a TQInputDialog. """
 			name = "Input Dialog"
 			def __init__(self, parent):
 				global EditWidget
@@ -627,13 +627,13 @@ class Samples:
 				}
 			def getCode(self):
 				return (
-					'import qt',
+					'from TQt import tqt',
 					'',
-					'text, ok = qt.QInputDialog.getText("{Caption}", "{Message}", qt.QLineEdit.Normal, "")',
+					'text, ok = tqt.TQInputDialog.getText("{Caption}", "{Message}", tqt.TQLineEdit.Normal, "")',
 					'if ok:',
-					'	print "Text defined: %s" % text',
+					'	print("Text defined: %s" % text)',
 					'else:',
-					'	print "Dialog aborted."',
+					'	print("Dialog aborted.")',
 				)
 
 	####################################################################################
@@ -651,13 +651,14 @@ class Samples:
 				}
 			def getCode(self):
 				return (
-					'import qt, tdecore, dcop, dcopext',
+					'from TQt import tqt',
+					'import tdecore, dcop, dcopext',
 					'dcopclient = tdecore.TDEApplication.dcopClient()',
 					'apps = [ app for app in dcopclient.registeredApplications() if str(app).startswith("klipper") ]',
 					'd = dcopext.DCOPApp(apps[0], dcopclient)',
 					'result,typename,data = d.appclient.call(apps[0],"klipper","getClipboardContents()","")',
-					'ds = qt.QDataStream(data, qt.IO_ReadOnly)',
-					'print "Clipboard content:\\n%s" % tdecore.dcop_next(ds, TQSTRING_OBJECT_NAME_STRING)',
+					'ds = tqt.TQDataStream(data, tqt.IO_ReadOnly)',
+					'print("Clipboard content:\\n%s" % tdecore.dcop_next(ds, TQSTRING_OBJECT_NAME_STRING))',
 				)
 
 		class AmarokCollectionInfos:
@@ -668,7 +669,8 @@ class Samples:
 				}
 			def getCode(self):
 				return (
-					'import qt, tdecore, dcop, dcopext',
+					'from TQt import tqt',
+					'import tdecore, dcop, dcopext',
 					'',
 					'dcopclient = tdecore.TDEApplication.dcopClient()',
 					'apps = [ app for app in dcopclient.registeredApplications() if str(app).startswith("amarok") ]',
@@ -676,13 +678,14 @@ class Samples:
 					'd = dcopext.DCOPApp(app, dcopclient)',
 					'',
 					'def dataToList(data, types = []):',
-					'	import qt, tdecore',
-					'	ds = qt.QDataStream(data, qt.IO_ReadOnly)',
+					'	from TQt import tqt',
+					'	import tdecore',
+					'	ds = tqt.TQDataStream(data, tqt.IO_ReadOnly)',
 					'	return [ tdecore.dcop_next(ds, t) for t in types ]',
 					'',
 					'for funcname in ["totalAlbums","totalArtists","totalCompilations","totalGenres","totalTracks"]:',
 					'	result,replytype,replydata = d.appclient.call("amarok", "collection", "%s()" % funcname,"")',
-					'	print "%s: %s" % ( funcname, dataToList(replydata,["int"])[0] )',
+					'	print("%s: %s" % ( funcname, dataToList(replydata,["int"])[0] ))',
 				)
 
 		class KopeteContacts:
@@ -693,7 +696,8 @@ class Samples:
 				}
 			def getCode(self):
 				return (
-					'import qt, tdecore, dcop, dcopext',
+					'from TQt import tqt',
+					'import tdecore, dcop, dcopext',
 					'',
 					'dcopclient = tdecore.TDEApplication.dcopClient()',
 					'apps = [ app for app in dcopclient.registeredApplications() if str(app).startswith("kopete") ]',
@@ -701,11 +705,11 @@ class Samples:
 					'd = dcopext.DCOPApp(app, dcopclient)',
 					'',
 					'(state,rtype,rdata) = d.appclient.call("kopete", "KopeteIface", "contacts()","")',
-					'if not state: raise "Failed to call the kopete contacts-function"',
+					'if not state: raise Exception("Failed to call the kopete contacts-function")',
 					'',
-					'ds = qt.QDataStream(rdata.data(), qt.IO_ReadOnly)',
+					'ds = tqt.TQDataStream(rdata.data(), tqt.IO_ReadOnly)',
 					'sl = tdecore.dcop_next (ds, TQSTRINGLIST_OBJECT_NAME_STRING)',
-					'print "contacts=%s" % [ str(s) for s in sl ]',
+					'print("contacts=%s" % [ str(s) for s in sl ])',
 				)
 
 		class KWordSelectedText:
@@ -716,16 +720,19 @@ class Samples:
 				}
 			def getCode(self):
 				return (
-					'import qt, tdecore, dcop, dcopext',
+					'from TQt import tqt',
+					'import tdecore, dcop, dcopext',
 					'',
 					'def dataToList(data, types = []):',
-					'	import qt, tdecore',
-					'	ds = qt.QDataStream(data, qt.IO_ReadOnly)',
+					'	from TQt import tqt',
+					'	import tdecore',
+					'	ds = tqt.TQDataStream(data, tqt.IO_ReadOnly)',
 					'	return [ tdecore.dcop_next(ds, t) for t in types ]',
 					'def listToData(listdict):',
-					'	import qt, tdecore',
-					'	ba= qt.QByteArray()',
-					'	ds = qt.QDataStream(ba, qt.IO_WriteOnly)',
+					'	from TQt import tqt',
+					'	import tdecore',
+					'	ba= tqt.TQByteArray()',
+					'	ds = tqt.TQDataStream(ba, tqt.IO_WriteOnly)',
 					'	for (typename,value) in listdict:',
 					'		tdecore.dcop_add (ds, value, typename)',
 					'	return ba',
@@ -733,73 +740,73 @@ class Samples:
 					'# Get the KWord DCOP client.',
 					'dcopclient = tdecore.TDEApplication.dcopClient()',
 					'apps = [ app for app in dcopclient.registeredApplications() if str(app).startswith("kword") ]',
-					'if len(apps) < 1: raise "No KWord instance is running. Please start KWord before!"',
+					'if len(apps) < 1: raise Exception("No KWord instance is running. Please start KWord before!")',
 					'appname = apps[0]',
 					'd = dcopext.DCOPApp(appname, dcopclient)',
 					'',
 					'# Call the getDocuments() function.',
 					'(state,rtype,rdata) = d.appclient.call(appname, "KoApplicationIface", "getDocuments()","")',
-					'if not state: raise "%s: Failed to call getDocuments-function" % appname',
-					'documents = dataToList(rdata,["QValueList<DCOPRef>"])[0]',
-					'print "documents=%s" % [ str( doc.obj() ) for doc in documents ]',
+					'if not state: raise Exception("%s: Failed to call getDocuments-function" % appname)',
+					'documents = dataToList(rdata,["TQValueList<DCOPRef>"])[0]',
+					'print("documents=%s" % [ str( doc.obj() ) for doc in documents ])',
 					'document = documents[0] # Let\'s just take the first document.',
 					'',
 					'# Get the frameset.',
 					'ba = listToData( [ ("int",0) ] )',
 					'(state,rtype,rdata) = d.appclient.call(appname, document.obj(), "textFrameSet(int)", ba)',
-					'if not state: raise "%s: Failed to call frameSet-function" % appname',
+					'if not state: raise Exception("%s: Failed to call frameSet-function" % appname)',
 					'frameset = dataToList( rdata,["DCOPRef"] )[0] # Let\'s just take the first textframe.',
 					'',
 					'# Get the selected text.',
 					'(state,rtype,rdata) = d.appclient.call(appname, frameset.obj(), "selectedText()", "")',
-					'print "Selected Text: %s" % dataToList( rdata,[TQSTRING_OBJECT_NAME_STRING] )[0]',
+					'print("Selected Text: %s" % dataToList( rdata,[TQSTRING_OBJECT_NAME_STRING] )[0])',
 				)
 
 ####################################################################################
 # Dialog implementations.
 
-class SampleDialog(qt.QDialog):
+class SampleDialog(tqt.TQDialog):
 	def __init__(self, parent, sampleclazz, samplechildclazz):
-		import qt
-		qt.QDialog.__init__(self, parent, "SampleDialog", 1)
+		from TQt import tqt
+		tqt.TQDialog.__init__(self, parent, "SampleDialog", 1)
 
-		layout = qt.QVBoxLayout(self)
-		box = qt.QVBox(self)
+		layout = tqt.TQVBoxLayout(self)
+		box = tqt.TQVBox(self)
 		box.setMargin(4)
 		box.setSpacing(10)
 		layout.addWidget(box)
 
-		self.scrollview = qt.QScrollView(box)
-		self.scrollview.setResizePolicy(qt.QScrollView.AutoOne)
-		#self.scrollview.setFrameStyle(qt.QFrame.NoFrame);
-		self.scrollview.setResizePolicy(qt.QScrollView.AutoOneFit);
+		self.scrollview = tqt.TQScrollView(box)
+		self.scrollview.setResizePolicy(tqt.TQScrollView.AutoOne)
+		#self.scrollview.setFrameStyle(tqt.TQFrame.NoFrame);
+		self.scrollview.setResizePolicy(tqt.TQScrollView.AutoOneFit);
 		self.scrollview.viewport().setPaletteBackgroundColor(self.paletteBackgroundColor())
-		mainbox = qt.QVBox( self.scrollview.viewport() )
+		mainbox = tqt.TQVBox( self.scrollview.viewport() )
 		mainbox.setMargin(6)
 		mainbox.setSpacing(6)
-		desclabel = qt.QLabel(mainbox)
-		qt.QFrame(mainbox).setFrameStyle( qt.QFrame.HLine | qt.QFrame.Sunken )
+		desclabel = tqt.TQLabel(mainbox)
+		tqt.TQFrame(mainbox).setFrameStyle( tqt.TQFrame.HLine | tqt.TQFrame.Sunken )
 
 		self.sample = sampleclazz( mainbox )
 		self.samplechild = samplechildclazz( self.sample )
 
 		desclabel.setText( "<qt>%s</qt>" % self.samplechild.__doc__ )
-		mainbox.setStretchFactor(qt.QWidget(mainbox), 1)
+		mainbox.setStretchFactor(tqt.TQWidget(mainbox), 1)
 		mainbox.show()
 		self.scrollview.addChild(mainbox)
 
-		btnbox = qt.QHBox(box)
+		btnbox = tqt.TQHBox(box)
 		btnbox.setMargin(6)
 		btnbox.setSpacing(6)
-		okbtn = qt.QPushButton(btnbox)
+		okbtn = tqt.TQPushButton(btnbox)
 		okbtn.setText("Ok")
-		qt.QObject.connect(okbtn, qt.SIGNAL("clicked()"), self.okClicked)
-		cancelbtn = qt.QPushButton(btnbox)
+		tqt.TQObject.connect(okbtn, tqt.SIGNAL("clicked()"), self.okClicked)
+		cancelbtn = tqt.TQPushButton(btnbox)
 		cancelbtn.setText("Cancel")
-		qt.QObject.connect(cancelbtn, qt.SIGNAL("clicked()"), self.close)
+		tqt.TQObject.connect(cancelbtn, tqt.SIGNAL("clicked()"), self.close)
 
 		self.setCaption(self.samplechild.name)
-		box.setMinimumSize(qt.QSize(500,340))
+		box.setMinimumSize(tqt.TQSize(500,340))
 
 	def okClicked(self):
 		self.code = self.samplechild.getCode()
@@ -808,15 +815,15 @@ class SampleDialog(qt.QDialog):
 	def getCode(self):
 		if not hasattr(self,"code"): return None
 		code = "\n".join( self.code )
-		for widgetname in self.samplechild.widgets.keys():
-			print ".............. %s" % widgetname
+		for widgetname in list(self.samplechild.widgets.keys()):
+			print(".............. %s" % widgetname)
 			widget = self.samplechild.widgets[widgetname]
 			value = widget.value()
 			if value != None:
 				code = code.replace("{%s}" % widgetname, str(value))
 		return code
 
-class MainDialog(qt.QDialog):
+class MainDialog(tqt.TQDialog):
 	def __init__(self, scriptpath, parent):
 		self.scriptpath = scriptpath
 		if not hasattr(__main__,"scripteditorfilename"):
@@ -825,118 +832,119 @@ class MainDialog(qt.QDialog):
 		import krosskspreadcore
 		self.doc = krosskspreadcore.get("KSpreadDocument")
 
-		import os, qt
-		qt.QDialog.__init__(self, parent, "MainDialog", 1, qt.Qt.WDestructiveClose)
+		import os
+		from TQt import tqt
+		tqt.TQDialog.__init__(self, parent, "MainDialog", 1, tqt.TQt.WDestructiveClose)
 		self.setCaption("Script Editor")
-		
-		layout = qt.QVBoxLayout(self)
-		box = qt.QVBox(self)
+
+		layout = tqt.TQVBoxLayout(self)
+		box = tqt.TQVBox(self)
 		box.setMargin(4)
 		box.setSpacing(10)
 		layout.addWidget(box)
 
-		menu = qt.QMenuBar(box)
+		menu = tqt.TQMenuBar(box)
 
-		splitter = qt.QSplitter(box)
-		splitter.setOrientation(qt.Qt.Vertical)
+		splitter = tqt.TQSplitter(box)
+		splitter.setOrientation(tqt.TQt.Vertical)
 
-		self.scripttext = qt.QMultiLineEdit(splitter)
-		self.scripttext.setWordWrap( qt.QTextEdit.NoWrap )
-		self.scripttext.setTextFormat( qt.Qt.PlainText )
-		qt.QObject.connect(self.scripttext, qt.SIGNAL("cursorPositionChanged(int,int)"),self.cursorPositionChanged)
+		self.scripttext = tqt.TQMultiLineEdit(splitter)
+		self.scripttext.setWordWrap( tqt.TQTextEdit.NoWrap )
+		self.scripttext.setTextFormat( tqt.TQt.PlainText )
+		tqt.TQObject.connect(self.scripttext, tqt.SIGNAL("cursorPositionChanged(int,int)"),self.cursorPositionChanged)
 
-		self.console = qt.QTextBrowser(splitter)
-		splitter.setResizeMode(self.console, qt.QSplitter.KeepSize)
+		self.console = tqt.TQTextBrowser(splitter)
+		splitter.setResizeMode(self.console, tqt.TQSplitter.KeepSize)
 
-		statusbar = qt.QStatusBar(box)
-		self.messagestatus = qt.QLabel(statusbar)
+		statusbar = tqt.TQStatusBar(box)
+		self.messagestatus = tqt.TQLabel(statusbar)
 		statusbar.addWidget(self.messagestatus,1)
-		self.cursorstatus = qt.QLabel(statusbar)
+		self.cursorstatus = tqt.TQLabel(statusbar)
 		statusbar.addWidget(self.cursorstatus)
 		self.cursorPositionChanged()
 
-		box.setMinimumSize( qt.QSize(680,540) )
+		box.setMinimumSize( tqt.TQSize(680,540) )
 
-		filemenu = qt.QPopupMenu(menu)
+		filemenu = tqt.TQPopupMenu(menu)
 		menu.insertItem("&File", filemenu)
-		
-		newaction = qt.QAction("New", qt.QKeySequence("CTRL+N"), self)
-		qt.QObject.connect(newaction, qt.SIGNAL("activated()"), self.newFile)
+
+		newaction = tqt.TQAction("New", tqt.TQKeySequence("CTRL+N"), self)
+		tqt.TQObject.connect(newaction, tqt.SIGNAL("activated()"), self.newFile)
 		newaction.addTo(filemenu)
 
-		openaction = qt.QAction("Open...", qt.QKeySequence("CTRL+O"), self)
-		qt.QObject.connect(openaction, qt.SIGNAL("activated()"), self.openFileAs)
+		openaction = tqt.TQAction("Open...", tqt.TQKeySequence("CTRL+O"), self)
+		tqt.TQObject.connect(openaction, tqt.SIGNAL("activated()"), self.openFileAs)
 		openaction.addTo(filemenu)
 
-		saveaction = qt.QAction("Save", qt.QKeySequence("CTRL+S"), self)
-		qt.QObject.connect(saveaction, qt.SIGNAL("activated()"), self.saveFile)
+		saveaction = tqt.TQAction("Save", tqt.TQKeySequence("CTRL+S"), self)
+		tqt.TQObject.connect(saveaction, tqt.SIGNAL("activated()"), self.saveFile)
 		saveaction.addTo(filemenu)
 
-		saveasaction = qt.QAction("Save as...", qt.QKeySequence("CTRL+A"), self)
-		qt.QObject.connect(saveasaction, qt.SIGNAL("activated()"), self.saveFileAs)
+		saveasaction = tqt.TQAction("Save as...", tqt.TQKeySequence("CTRL+A"), self)
+		tqt.TQObject.connect(saveasaction, tqt.SIGNAL("activated()"), self.saveFileAs)
 		saveasaction.addTo(filemenu)
 
 		filemenu.insertSeparator()
-		
-		quitaction = qt.QAction("Quit", qt.QKeySequence("CTRL+Q"), self)
-		qt.QObject.connect(quitaction, qt.SIGNAL("activated()"), self.close)
+
+		quitaction = tqt.TQAction("Quit", tqt.TQKeySequence("CTRL+Q"), self)
+		tqt.TQObject.connect(quitaction, tqt.SIGNAL("activated()"), self.close)
 		quitaction.addTo(filemenu)
 
-		editmenu = qt.QPopupMenu(menu)
+		editmenu = tqt.TQPopupMenu(menu)
 		menu.insertItem("&Edit", editmenu)
 
-		undoaction = qt.QAction("Undo", qt.QKeySequence("CTRL+Z"), self)
-		qt.QObject.connect(undoaction, qt.SIGNAL("activated()"), self.scripttext.undo)
+		undoaction = tqt.TQAction("Undo", tqt.TQKeySequence("CTRL+Z"), self)
+		tqt.TQObject.connect(undoaction, tqt.SIGNAL("activated()"), self.scripttext.undo)
 		undoaction.addTo(editmenu)
 
-		redoaction = qt.QAction("Redo", qt.QKeySequence("CTRL+Shift+Z"), self)
-		qt.QObject.connect(redoaction, qt.SIGNAL("activated()"), self.scripttext.redo)
+		redoaction = tqt.TQAction("Redo", tqt.TQKeySequence("CTRL+Shift+Z"), self)
+		tqt.TQObject.connect(redoaction, tqt.SIGNAL("activated()"), self.scripttext.redo)
 		redoaction.addTo(editmenu)
 
 		editmenu.insertSeparator()
 
-		cutaction = qt.QAction("Cut", qt.QKeySequence("CTRL+X"), self)
-		qt.QObject.connect(cutaction, qt.SIGNAL("activated()"), self.scripttext.cut)
+		cutaction = tqt.TQAction("Cut", tqt.TQKeySequence("CTRL+X"), self)
+		tqt.TQObject.connect(cutaction, tqt.SIGNAL("activated()"), self.scripttext.cut)
 		cutaction.addTo(editmenu)
 
-		copyaction = qt.QAction("Copy", qt.QKeySequence("CTRL+C"), self)
-		qt.QObject.connect(copyaction, qt.SIGNAL("activated()"), self.scripttext.copy)
+		copyaction = tqt.TQAction("Copy", tqt.TQKeySequence("CTRL+C"), self)
+		tqt.TQObject.connect(copyaction, tqt.SIGNAL("activated()"), self.scripttext.copy)
 		copyaction.addTo(editmenu)
 
-		pasteaction = qt.QAction("Paste", qt.QKeySequence("CTRL+V"), self)
-		qt.QObject.connect(pasteaction, qt.SIGNAL("activated()"), self.scripttext.paste)
+		pasteaction = tqt.TQAction("Paste", tqt.TQKeySequence("CTRL+V"), self)
+		tqt.TQObject.connect(pasteaction, tqt.SIGNAL("activated()"), self.scripttext.paste)
 		pasteaction.addTo(editmenu)
 
-		clearaction = qt.QAction("Clear", qt.QKeySequence("CTRL+Shift+X"), self)
-		qt.QObject.connect(clearaction, qt.SIGNAL("activated()"), self.scripttext.clear)
+		clearaction = tqt.TQAction("Clear", tqt.TQKeySequence("CTRL+Shift+X"), self)
+		tqt.TQObject.connect(clearaction, tqt.SIGNAL("activated()"), self.scripttext.clear)
 		clearaction.addTo(editmenu)
 
 		editmenu.insertSeparator()
 
-		selallaction = qt.QAction("Select All", 0, self)
-		qt.QObject.connect(selallaction, qt.SIGNAL("activated()"), self.scripttext.selectAll)
+		selallaction = tqt.TQAction("Select All", 0, self)
+		tqt.TQObject.connect(selallaction, tqt.SIGNAL("activated()"), self.scripttext.selectAll)
 		selallaction.addTo(editmenu)
 
-		scriptmenu = qt.QPopupMenu(menu)
+		scriptmenu = tqt.TQPopupMenu(menu)
 		menu.insertItem("&Script", scriptmenu)
 
-		compileaction = qt.QAction("Compile", qt.QKeySequence("F9"), self)
-		qt.QObject.connect(compileaction, qt.SIGNAL("activated()"), self.compileScript)
+		compileaction = tqt.TQAction("Compile", tqt.TQKeySequence("F9"), self)
+		tqt.TQObject.connect(compileaction, tqt.SIGNAL("activated()"), self.compileScript)
 		compileaction.addTo(scriptmenu)
 
-		executeaction = qt.QAction("Execute", qt.QKeySequence("F10"), self)
-		qt.QObject.connect(executeaction, qt.SIGNAL("activated()"), self.executeScript)
+		executeaction = tqt.TQAction("Execute", tqt.TQKeySequence("F10"), self)
+		tqt.TQObject.connect(executeaction, tqt.SIGNAL("activated()"), self.executeScript)
 		executeaction.addTo(scriptmenu)
 
-		self.samplemenu = qt.QPopupMenu(menu)
+		self.samplemenu = tqt.TQPopupMenu(menu)
 		menu.insertItem("&Samples", self.samplemenu)
 		itemid = 500
 		global Samples
 		for samplename in dir(Samples):
 			if samplename.startswith("_"): continue
 			itemid += 1
-			menu = qt.QPopupMenu(self.samplemenu)
-			qt.QObject.connect(menu, qt.SIGNAL("activated(int)"), self.sampleActivated)
+			menu = tqt.TQPopupMenu(self.samplemenu)
+			tqt.TQObject.connect(menu, tqt.SIGNAL("activated(int)"), self.sampleActivated)
 			self.samplemenu.insertItem(samplename, menu, -1, self.samplemenu.count() - 1)
 			attr = getattr(Samples,samplename)
 			for a in dir(attr):
@@ -983,9 +991,9 @@ class MainDialog(qt.QDialog):
 			self.scripttext.append( code )
 
 	def execCode(self,function):
-		import sys, StringIO
-		codeOut = StringIO.StringIO()
-		codeErr = StringIO.StringIO()
+		import sys, io
+		codeOut = io.StringIO()
+		codeErr = io.StringIO()
 		sys.stdout = codeOut
 		sys.stderr = codeErr
 
@@ -1001,7 +1009,7 @@ class MainDialog(qt.QDialog):
 				while hasattr(tb,"tb_next") and tb.tb_next:
 					tb = tb.tb_next
 				lineno = tb.tb_lineno
-				print "EXCEPTION: lineno=%s" % lineno
+				print("EXCEPTION: lineno=%s" % lineno)
 				self.scripttext.setCursorPosition( lineno - 1, 0 )
 			except:
 				pass
@@ -1011,12 +1019,12 @@ class MainDialog(qt.QDialog):
 
 		s = codeErr.getvalue()
 		if s:
-			print "ERROR:\n%s\n" % s
+			print("ERROR:\n%s\n" % s)
 			self.console.append(s)
 
 		s = codeOut.getvalue()
 		if s:
-			print s
+			print(s)
 			self.console.append(s)
 
 		codeOut.close()
@@ -1034,13 +1042,13 @@ class MainDialog(qt.QDialog):
 		self.console.clear()
 		def doexecute(self):
 			code = str( self.scripttext.text() )
-			exec code in globals(), locals()
+			exec(code, globals(), locals())
 		self.execCode(doexecute)
 		self.console.append("<b>Execution done!</b>")
 
 	def newFile(self):
 		self.console.clear()
-		#if qt.QMessageBox.warning(self,"Remove?","Remove the selected item?",qt.QMessageBox.Yes,qt.QMessageBox.Cancel) != qt.QMessageBox.Yes:
+		#if tqt.TQMessageBox.warning(self,"Remove?","Remove the selected item?",tqt.TQMessageBox.Yes,tqt.TQMessageBox.Cancel) != tqt.TQMessageBox.Yes:
 		self.scripttext.clear()
 
 	def openFile(self, filename):
@@ -1050,13 +1058,14 @@ class MainDialog(qt.QDialog):
 			self.scripttext.setText( str( file.read() ) )
 			file.close()
 			__main__.scripteditorfilename = filename
-		except IOError, (errno, strerror):
-			qt.QMessageBox.critical(self,"Error","<qt>Failed to open script file \"%s\"<br><br>%s</qt>" % (filename,strerror))
+		except IOError as xxx_todo_changeme:
+			(errno, strerror) = xxx_todo_changeme.args
+			tqt.TQMessageBox.critical(self,"Error","<qt>Failed to open script file \"%s\"<br><br>%s</qt>" % (filename,strerror))
 
 	def openFileAs(self):
-		import qt
+		from TQt import tqt
 		self.console.clear()
-		filename = str( qt.QFileDialog.getOpenFileName(__main__.scripteditorfilename,"*.py;;*", self) )
+		filename = str( tqt.TQFileDialog.getOpenFileName(__main__.scripteditorfilename,"*.py;;*", self) )
 		if filename == "": return
 		self.openFile(filename)
 
@@ -1065,12 +1074,13 @@ class MainDialog(qt.QDialog):
 			file = open(__main__.scripteditorfilename, "w")
 			file.write( str( self.scripttext.text() ) )
 			file.close()
-		except IOError, (errno, strerror):
-			qt.QMessageBox.critical(self,"Error","<qt>Failed to open script file \"%s\"<br><br>%s</qt>" % (__main__.scripteditorfilename,strerror))
+		except IOError as xxx_todo_changeme1:
+			(errno, strerror) = xxx_todo_changeme1.args
+			tqt.TQMessageBox.critical(self,"Error","<qt>Failed to open script file \"%s\"<br><br>%s</qt>" % (__main__.scripteditorfilename,strerror))
 
 	def saveFileAs(self):
-		import qt
-		filename = str( qt.QFileDialog.getSaveFileName(__main__.scripteditorfilename,"*.py;;*", self) )
+		from TQt import tqt
+		filename = str( tqt.TQFileDialog.getSaveFileName(__main__.scripteditorfilename,"*.py;;*", self) )
 		if filename == "": return
 		__main__.scripteditorfilename = filename
 		self.saveFile()
@@ -1080,10 +1090,10 @@ class MainDialog(qt.QDialog):
 
 if __name__ == "__main__":
 	scriptpath = os.getcwd()
-	qtapp = qt.QApplication(sys.argv)
+	tqtapp = tqt.TQApplication(sys.argv)
 else:
 	scriptpath = os.path.dirname(__name__)
-	qtapp = qt.tqApp
+	tqtapp = tqt.tqApp
 
-dialog = MainDialog(scriptpath, qtapp.mainWidget())
+dialog = MainDialog(scriptpath, tqtapp.mainWidget())
 dialog.exec_loop()
