@@ -278,7 +278,7 @@ void Canvas::setDetailAttributes( TQDomNode *node )
                             attributes.namedItem( "Level" ).nodeValue().toInt(), this );
     d->props[ "Level" ].setValue( attributes.namedItem( "Level" ).nodeValue().toInt() );
     d->props[ "Height" ].setValue( attributes.namedItem( "Height" ).nodeValue().toInt() );
-    d->props[ "Repeat" ].setValue( TQVariant( attributes.namedItem( "Repeat" ).nodeValue() == "true", 3 ) );
+    d->props[ "Repeat" ].setValue( TQVariant( attributes.namedItem( "Repeat" ).nodeValue() == "true" ) );
     kugarTemplate() ->details[ attributes.namedItem( "Level" ).nodeValue().toInt() ].second = d;
     addReportItems( node, d );
 }
