@@ -27,7 +27,7 @@
 #include <KoParagDia.h>
 
 #include <kcolorbutton.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
 
 #include <tqtabwidget.h>
@@ -197,12 +197,12 @@ void KWFrameStyleManager::setupWidget()
 
 
     m_moveUpButton = new TQPushButton( frame1, "moveUpButton" );
-    m_moveUpButton->setIconSet( SmallIconSet( "up" ) );
+    m_moveUpButton->setIconSet( SmallIconSet( "go-up" ) );
     connect( m_moveUpButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( moveUpStyle() ) );
     frame1Layout->addWidget( m_moveUpButton, 1, 1 );
 
     m_moveDownButton = new TQPushButton( frame1, "moveDownButton" );
-    m_moveDownButton->setIconSet( SmallIconSet( "down" ) );
+    m_moveDownButton->setIconSet( SmallIconSet( "go-down" ) );
     connect( m_moveDownButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( moveDownStyle() ) );
     frame1Layout->addWidget( m_moveDownButton, 1, 0 );
 
