@@ -25,14 +25,14 @@
 #include <KoCustomVariablesDia.h>
 #include "defs.h"
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 #include <kstdaction.h>
-#include <kaction.h>
-#include <kmessagebox.h>
+#include <tdeaction.h>
+#include <tdemessagebox.h>
 #include <kseparator.h>
 #include <kservice.h>
-#include <kmainwindow.h>
+#include <tdemainwindow.h>
 
 #include <tqfile.h>
 #include <tqvbox.h>
@@ -60,10 +60,10 @@ KWMailMergeDataBase::KWMailMergeDataBase( KWDocument *doc_ )
 TQStringList KWMailMergeDataBase::availablePlugins()
 {
     TQStringList tmp;
-    KTrader::OfferList pluginOffers=KTrader::self()->query(TQString::fromLatin1("KWord/MailMergePlugin"),TQString());
-    for (KTrader::OfferList::Iterator it=pluginOffers.begin();*it;++it)
+    TDETrader::OfferList pluginOffers=TDETrader::self()->query(TQString::fromLatin1("KWord/MailMergePlugin"),TQString());
+    for (TDETrader::OfferList::Iterator it=pluginOffers.begin();*it;++it)
     {
-        tmp.append((*it)->property("X-KDE-InternalName").toString());
+        tmp.append((*it)->property("X-TDE-InternalName").toString());
         kdDebug()<<"Found mail merge plugin: "<< (*it)->name()<<endl;
     }
     return tmp;
@@ -77,12 +77,12 @@ bool KWMailMergeDataBase::isConfigDialogShown()
 bool KWMailMergeDataBase::loadPlugin(const TQString &name,const TQString &command)
 {
     if (rejectdcopcall)return false;
-    TQString constrain=TQString("[X-KDE-InternalName] =='"+name+"'");
+    TQString constrain=TQString("[X-TDE-InternalName] =='"+name+"'");
     kdDebug()<<constrain<<endl;
-    KTrader::OfferList pluginOffers=KTrader::self()->query(TQString::fromLatin1("KWord/MailMergePlugin"),constrain);
+    TDETrader::OfferList pluginOffers=TDETrader::self()->query(TQString::fromLatin1("KWord/MailMergePlugin"),constrain);
     KService::Ptr it=pluginOffers.first();
 
-    TQVariant verProp=it->property("X-KDE-PluginVersion");
+    TQVariant verProp=it->property("X-TDE-PluginVersion");
     int version=verProp.toInt();
 
     if (it)
@@ -116,12 +116,12 @@ KWMailMergeDataSource *KWMailMergeDataBase::openPluginFor(int type,int &version)
 {
     version=0;
     KWMailMergeDataSource *ret=0;
-    TQString constrain=TQString("'%1' in [X-KDE-Capabilities]").arg(((type==KWSLCreate)?KWSLCreate_text:KWSLOpen_text));
+    TQString constrain=TQString("'%1' in [X-TDE-Capabilities]").arg(((type==KWSLCreate)?KWSLCreate_text:KWSLOpen_text));
     kdDebug()<<constrain<<endl;
-    KTrader::OfferList pluginOffers=KTrader::self()->query(TQString::fromLatin1("KWord/MailMergePlugin"),constrain);
+    TDETrader::OfferList pluginOffers=TDETrader::self()->query(TQString::fromLatin1("KWord/MailMergePlugin"),constrain);
 
     //Only for debugging
-    for (KTrader::OfferList::Iterator it=pluginOffers.begin();*it;++it)
+    for (TDETrader::OfferList::Iterator it=pluginOffers.begin();*it;++it)
     {
         kdDebug()<<"Found mail merge plugin: "<< (*it)->name()<<endl;
     }
@@ -138,7 +138,7 @@ KWMailMergeDataSource *KWMailMergeDataBase::openPluginFor(int type,int &version)
         KWMailMergeChoosePluginDialog *dia=new KWMailMergeChoosePluginDialog(pluginOffers);
         if (dia->exec()==TQDialog::Accepted)
         {
-            TQVariant verProp=(*(pluginOffers.at(dia->currentPlugin())))->property("X-KDE-PluginVersion");
+            TQVariant verProp=(*(pluginOffers.at(dia->currentPlugin())))->property("X-TDE-PluginVersion");
             version=verProp.toInt();
 
             ret=loadPlugin((*(pluginOffers.at(dia->currentPlugin())))->library());
@@ -168,8 +168,8 @@ KWMailMergeDataSource *KWMailMergeDataBase::loadPlugin(const TQString& name)
           if (create)
           {
               // create the module
-              KWMailMergeDataSource * (*func)(KInstance*,TQObject*);
-              func = (KWMailMergeDataSource* (*)(KInstance*,TQObject*)) create;
+              KWMailMergeDataSource * (*func)(TDEInstance*,TQObject*);
+              func = (KWMailMergeDataSource* (*)(TDEInstance*,TQObject*)) create;
               KWMailMergeDataSource *tmpsource =func(KWFactory::instance(),this);
               if (tmpsource)
               {
@@ -324,7 +324,7 @@ int KWMailMergeDataBase::version() {
  *
  ******************************************************************/
 
-KWMailMergeChoosePluginDialog::KWMailMergeChoosePluginDialog( KTrader::OfferList offers )
+KWMailMergeChoosePluginDialog::KWMailMergeChoosePluginDialog( TDETrader::OfferList offers )
     : KDialogBase( Plain, i18n( "Mail Merge Setup" ), Ok | Cancel, Ok,
       /*parent*/ 0, "", true ), pluginOffers( offers )
 {
@@ -341,7 +341,7 @@ KWMailMergeChoosePluginDialog::KWMailMergeChoosePluginDialog( KTrader::OfferList
   descriptionLabel->setFrameShadow( TQFrame::Sunken );
 
   TQSize old_sizeHint;
-  for ( KTrader::OfferList::Iterator it = pluginOffers.begin(); *it; ++it )
+  for ( TDETrader::OfferList::Iterator it = pluginOffers.begin(); *it; ++it )
   {
     chooser->insertItem( (*it)->name() );
     old_sizeHint = descriptionLabel->sizeHint();
@@ -482,15 +482,15 @@ void KWMailMergeConfigDialog::slotOpenClicked()
 void KWMailMergeConfigDialog::slotPreviewClicked()
 {
     db_->action=KWSLMergePreview;
-    KMainWindow *mw=dynamic_cast<KMainWindow*>(((TQWidget *)parent())->topLevelWidget());
+    TDEMainWindow *mw=dynamic_cast<TDEMainWindow*>(((TQWidget *)parent())->topLevelWidget());
     if (mw)
     {
-        KAction *ac=mw->actionCollection()->action(KStdAction::stdName(KStdAction::PrintPreview));
+        TDEAction *ac=mw->actionCollection()->action(KStdAction::stdName(KStdAction::PrintPreview));
         if (ac) ac->activate();
         else kdWarning()<<"Toplevel doesn't provide a print preview action"<<endl;
     }
     else
-        kdWarning()<<"Toplevel is no KMainWindow->no preview"<<endl;
+        kdWarning()<<"Toplevel is no TDEMainWindow->no preview"<<endl;
 }
 
 void KWMailMergeConfigDialog::slotDocumentClicked()
