@@ -27,9 +27,9 @@
 
 #include <KoRect.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kurl.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
 
