@@ -20,14 +20,14 @@
 #ifndef __koFactory_h__
 #define __koFactory_h__
 
-#include <kparts/factory.h>
+#include <tdeparts/factory.h>
 #include <koffice_export.h>
-class KInstance;
+class TDEInstance;
 
 class KOFFICECORE_EXPORT KoFactory : public KParts::Factory
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 public:
   KoFactory( TQObject *parent = 0, const char *name = 0 );
   virtual ~KoFactory();
