@@ -29,11 +29,11 @@
 #include <tqptrlist.h>
 #include <tqapplication.h>
 
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <KoDocument.h>
 #include <klibloader.h>
-#include <klistbox.h>
+#include <tdelistbox.h>
 #include <kmimetype.h>
 #include <kdebug.h>
 
@@ -64,7 +64,7 @@ KoFilterChooser::KoFilterChooser (TQWidget *parent, const TQStringList &mimeType
     TQLabel *filterLabel = new TQLabel (i18n ("Select a filter:"), page, "filterlabel");
     layout->addWidget (filterLabel);
 
-    m_filterList = new KListBox (page, "filterlist");
+    m_filterList = new TDEListBox (page, "filterlist");
     layout->addWidget (m_filterList);
 
     Q_ASSERT (!m_mimeTypes.isEmpty ());
@@ -344,8 +344,8 @@ namespace  // in order not to mess with the global namespace ;)
         TQValueList<KoDocumentEntry>::ConstIterator partEnd( parts.end() );
 
         while ( partIt != partEnd ) {
-            TQStringList nativeMimeTypes = ( *partIt ).service()->property( "X-KDE-ExtraNativeMimeTypes" ).toStringList();
-            nativeMimeTypes += ( *partIt ).service()->property( "X-KDE-NativeMimeType" ).toString();
+            TQStringList nativeMimeTypes = ( *partIt ).service()->property( "X-TDE-ExtraNativeMimeTypes" ).toStringList();
+            nativeMimeTypes += ( *partIt ).service()->property( "X-TDE-NativeMimeType" ).toString();
             TQStringList::ConstIterator it = nativeMimeTypes.begin();
             const TQStringList::ConstIterator end = nativeMimeTypes.end();
             for ( ; it != end; ++it )
@@ -519,8 +519,8 @@ TQStringList KoFilterManager::mimeFilter()
     Vertex *v = new Vertex( "supercalifragilistic/x-pialadocious" );
     vertices.insert( "supercalifragilistic/x-pialadocious", v );
     while ( partIt != partEnd ) {
-        TQStringList nativeMimeTypes = ( *partIt ).service()->property( "X-KDE-ExtraNativeMimeTypes" ).toStringList();
-        nativeMimeTypes += ( *partIt ).service()->property( "X-KDE-NativeMimeType" ).toString();
+        TQStringList nativeMimeTypes = ( *partIt ).service()->property( "X-TDE-ExtraNativeMimeTypes" ).toStringList();
+        nativeMimeTypes += ( *partIt ).service()->property( "X-TDE-NativeMimeType" ).toString();
         TQStringList::ConstIterator it = nativeMimeTypes.begin();
         const TQStringList::ConstIterator end = nativeMimeTypes.end();
         for ( ; it != end; ++it )
