@@ -24,13 +24,13 @@
 
 #include <kdialogbase.h>
 
-class KListBox;
+class TDEListBox;
 
 
 class KoFilterChooser : public KDialogBase
 {
 Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
     KoFilterChooser (TQWidget *parent, const TQStringList &mimeTypes,
@@ -41,7 +41,7 @@ public:
 
 private:
     TQStringList m_mimeTypes;
-    KListBox *m_filterList;
+    TDEListBox *m_filterList;
 };
 
 #endif
