@@ -32,27 +32,27 @@
 #include "kkbdaccessextensions.h"
 #include "KoSpeaker.h"
 
-#include <kaboutdata.h>
+#include <tdeaboutdata.h>
 #include <kprinter.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 #include <kstdaction.h>
-#include <kapplication.h>
-#include <kmessagebox.h>
+#include <tdeapplication.h>
+#include <tdemessagebox.h>
 #include <kstandarddirs.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
 #include <kkeydialog.h>
 #include <kedittoolbar.h>
 #include <kprogress.h>
 #include <kpushbutton.h>
 #include <kdebug.h>
-#include <ktempfile.h>
-#include <krecentdocument.h>
-#include <kparts/partmanager.h>
-#include <kparts/plugin.h>
-#include <kparts/event.h>
-#include <klocale.h>
+#include <tdetempfile.h>
+#include <tderecentdocument.h>
+#include <tdeparts/partmanager.h>
+#include <tdeparts/plugin.h>
+#include <tdeparts/event.h>
+#include <tdelocale.h>
 #include <kstatusbar.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 #include <ksharedptr.h>
 
 #include <tqobjectlist.h>
@@ -144,16 +144,16 @@ public:
   TQLabel * statusBarLabel;
   KProgress *m_progress;
 
-  TQPtrList<KAction> m_splitViewActionList;
+  TQPtrList<TDEAction> m_splitViewActionList;
   // This additional list is needed, because we don't plug
   // the first list, when an embedded view gets activated (Werner)
-  TQPtrList<KAction> m_veryHackyActionList;
+  TQPtrList<TDEAction> m_veryHackyActionList;
   TQSplitter *m_splitter;
-  KSelectAction *m_orientation;
-  KAction *m_removeView;
+  TDESelectAction *m_orientation;
+  TDEAction *m_removeView;
   KoMainWindowIface *m_dcopObject;
 
-  TQPtrList <KAction> m_toolbarList;
+  TQPtrList <TDEAction> m_toolbarList;
 
   bool bMainWindowGUIBuilt;
   bool m_splitted;
@@ -161,17 +161,17 @@ public:
   bool m_firstTime;
   bool m_windowSizeDirty;
 
-  KAction *m_paDocInfo;
-  KAction *m_paSave;
-  KAction *m_paSaveAs;
-  KAction *m_paPrint;
-  KAction *m_paPrintPreview;
-  KAction *m_sendfile;
-  KAction *m_paCloseFile;
-  KAction *m_reloadfile;
-  KAction *m_versionsfile;
-  KAction *m_importFile;
-  KAction *m_exportFile;
+  TDEAction *m_paDocInfo;
+  TDEAction *m_paSave;
+  TDEAction *m_paSaveAs;
+  TDEAction *m_paPrint;
+  TDEAction *m_paPrintPreview;
+  TDEAction *m_sendfile;
+  TDEAction *m_paCloseFile;
+  TDEAction *m_reloadfile;
+  TDEAction *m_versionsfile;
+  TDEAction *m_importFile;
+  TDEAction *m_exportFile;
 
   bool m_isImporting;
   bool m_isExporting;
@@ -180,11 +180,11 @@ public:
   TQCString m_lastExportFormat;
   int m_lastExportSpecialOutputFlag;
 
-  KSharedPtr<KoSpeaker> m_koSpeaker;
+  TDESharedPtr<KoSpeaker> m_koSpeaker;
 };
 
-KoMainWindow::KoMainWindow( KInstance *instance, const char* name )
-    : KParts::MainWindow( name )
+KoMainWindow::KoMainWindow( TDEInstance *instance, const char* name )
+    : KParts::MainWindow( 0, 0L, name )
 {
     setStandardToolBarMenuEnabled(true); // should there be a check for >= 3.1 ?
     Q_ASSERT(instance);
@@ -201,7 +201,7 @@ KoMainWindow::KoMainWindow( KInstance *instance, const char* name )
     // part's instance! (Simon)
 
     TQString doc;
-    TQStringList allFiles = KGlobal::dirs()->findAllResources( "data", "koffice/koffice_shell.rc" );
+    TQStringList allFiles = TDEGlobal::dirs()->findAllResources( "data", "koffice/koffice_shell.rc" );
     setXMLFile( findMostRecentXMLFile( allFiles, doc ) );
     setLocalXMLFile( locateLocal( "data", "koffice/koffice_shell.rc" ) );
 
@@ -217,24 +217,24 @@ KoMainWindow::KoMainWindow( KInstance *instance, const char* name )
     d->m_paCloseFile = KStdAction::close( TQT_TQOBJECT(this), TQT_SLOT( slotFileClose() ), actionCollection(), "file_close" );
     KStdAction::quit( TQT_TQOBJECT(this), TQT_SLOT( slotFileQuit() ), actionCollection(), "file_quit" );
 
-    d->m_reloadfile = new KAction( i18n( "Reload"), 0,
+    d->m_reloadfile = new TDEAction( i18n( "Reload"), 0,
                     TQT_TQOBJECT(this), TQT_SLOT( slotReloadFile() ),
                     actionCollection(), "file_reload_file");
 
-    d->m_versionsfile = new KAction( i18n( "Versions..."), 0,
+    d->m_versionsfile = new TDEAction( i18n( "Versions..."), 0,
                     TQT_TQOBJECT(this), TQT_SLOT( slotVersionsFile() ),
                     actionCollection(), "file_versions_file");
 
-    d->m_importFile = new KAction( i18n( "I&mport..." ), 0, // clashing accel key :(
+    d->m_importFile = new TDEAction( i18n( "I&mport..." ), 0, // clashing accel key :(
                     TQT_TQOBJECT(this), TQT_SLOT( slotImportFile() ),
                     actionCollection(), "file_import_file");
-    d->m_exportFile = new KAction( i18n( "E&xport..." ), 0,
+    d->m_exportFile = new TDEAction( i18n( "E&xport..." ), 0,
                     TQT_TQOBJECT(this), TQT_SLOT( slotExportFile() ),
                     actionCollection(), "file_export_file");
 
     /* The following entry opens the document information dialog.  Since the action is named so it
         intends to show data this entry should not have a trailing ellipses (...).  */
-    d->m_paDocInfo = new KAction( i18n( "&Document Information" ), "documentinfo", 0,
+    d->m_paDocInfo = new TDEAction( i18n( "&Document Information" ), "documentinfo", 0,
                         TQT_TQOBJECT(this), TQT_SLOT( slotDocumentInfo() ),
                         actionCollection(), "file_documentinfo" );
 
@@ -259,20 +259,20 @@ KoMainWindow::KoMainWindow( KInstance *instance, const char* name )
     new KKbdAccessExtensions(this, "mw-panelSizer");
     // set up the action "list" for "Close all Views" (hacky :) (Werner)
     d->m_veryHackyActionList.append(
-        new KAction(i18n("&Close All Views"), "fileclose",
+        new TDEAction(i18n("&Close All Views"), "window-close",
                     "ctrl+shift+w", TQT_TQOBJECT(this), TQT_SLOT(slotCloseAllViews()),
                     actionCollection(), "view_closeallviews") );
 
     // set up the action list for the splitter stuff
-    d->m_splitViewActionList.append(new KAction(i18n("&Split View"), "view_split", 0,
+    d->m_splitViewActionList.append(new TDEAction(i18n("&Split View"), "view_split", 0,
         TQT_TQOBJECT(this), TQT_SLOT(slotSplitView()),
         actionCollection(), "view_split"));
-    d->m_removeView=new KAction(i18n("&Remove View"), "view_remove", 0,
+    d->m_removeView=new TDEAction(i18n("&Remove View"), "view_remove", 0,
         TQT_TQOBJECT(this), TQT_SLOT(slotRemoveView()),
         actionCollection(), "view_rm_splitter");
     d->m_splitViewActionList.append(d->m_removeView);
     d->m_removeView->setEnabled(false);
-    d->m_orientation=new KSelectAction(i18n("Splitter &Orientation"), "view_orientation", 0,
+    d->m_orientation=new TDESelectAction(i18n("Splitter &Orientation"), "view_orientation", 0,
         TQT_TQOBJECT(this), TQT_SLOT(slotSetOrientation()),
         actionCollection(), "view_splitter_orientation");
     TQStringList items;
@@ -281,10 +281,10 @@ KoMainWindow::KoMainWindow( KInstance *instance, const char* name )
     d->m_orientation->setItems(items);
     d->m_orientation->setCurrentItem(static_cast<int>(d->m_splitter->orientation()));
     d->m_splitViewActionList.append(d->m_orientation);
-    d->m_splitViewActionList.append(new KActionSeparator(TQT_TQOBJECT(this)));
+    d->m_splitViewActionList.append(new TDEActionSeparator(TQT_TQOBJECT(this)));
 
     // Load list of recent files
-    KConfig * config = instance ? instance->config() : KGlobal::config();
+    TDEConfig * config = instance ? instance->config() : TDEGlobal::config();
     m_recent->loadEntries( config );
 
     createShellGUI();
@@ -293,7 +293,7 @@ KoMainWindow::KoMainWindow( KInstance *instance, const char* name )
     if ( !initialGeometrySet() )
     {
         // Default size
-        const int deskWidth = KGlobalSettings::desktopGeometry(this).width();
+        const int deskWidth = TDEGlobalSettings::desktopGeometry(this).width();
         if (deskWidth > 1100) // very big desktop ?
             resize( 1000, 800 );
         if (deskWidth > 850) // big desktop ?
@@ -310,13 +310,19 @@ KoMainWindow::KoMainWindow( KInstance *instance, const char* name )
 
 KoMainWindow::~KoMainWindow()
 {
+    if (!d) {
+        return;
+    }
+
     // The doc and view might still exist (this is the case when closing the window)
-    if (d->m_rootDoc)
+    if (d->m_rootDoc) {
         d->m_rootDoc->removeShell(this);
+    }
 
     if (d->m_docToOpen) {
       d->m_docToOpen->removeShell(this);
       delete d->m_docToOpen;
+      d->m_docToOpen=0L;
     }
 
     // safety first ;)
@@ -337,10 +343,13 @@ KoMainWindow::~KoMainWindow()
     {
         //kdDebug(30003) << "Destructor. No more views, deleting old doc " << d->m_rootDoc << endl;
         delete d->m_rootDoc;
+        d->m_rootDoc=0L;
     }
 
     delete d->m_manager;
+    d->m_manager=0L;
     delete d;
+    d=0L;
 }
 
 void KoMainWindow::setRootDocument( KoDocument *doc )
@@ -443,15 +452,15 @@ void KoMainWindow::addRecentURL( const KURL& url )
         if ( url.isLocalFile() )
         {
             TQString path = url.path( -1 );
-            TQStringList tmpDirs = KGlobal::dirs()->resourceDirs( "tmp" );
+            TQStringList tmpDirs = TDEGlobal::dirs()->resourceDirs( "tmp" );
             for ( TQStringList::Iterator it = tmpDirs.begin() ; ok && it != tmpDirs.end() ; ++it )
                 if ( path.contains( *it ) )
                     ok = false; // it's in the tmp resource
             if ( ok )
-                KRecentDocument::add(path);
+                TDERecentDocument::add(path);
         }
         else
-            KRecentDocument::add(url.url(-1), true);
+            TDERecentDocument::add(url.url(-1), true);
 
         if ( ok )
             m_recent->addURL( url );
@@ -462,23 +471,23 @@ void KoMainWindow::addRecentURL( const KURL& url )
 void KoMainWindow::saveRecentFiles()
 {
     // Save list of recent files
-    KConfig * config = instance() ? instance()->config() : KGlobal::config();
+    TDEConfig * config = instance() ? instance()->config() : TDEGlobal::config();
     kdDebug(30003) << this << " Saving recent files list into config. instance()=" << instance() << endl;
     m_recent->saveEntries( config );
     config->sync();
-    if (KMainWindow::memberList)
+    if (TDEMainWindow::memberList)
     {
         // Tell all windows to reload their list, after saving
         // Doesn't work multi-process, but it's a start
-        KMainWindow *window = KMainWindow::memberList->first();
-        for (; window; window = KMainWindow::memberList->next())
+        TDEMainWindow *window = TDEMainWindow::memberList->first();
+        for (; window; window = TDEMainWindow::memberList->next())
             static_cast<KoMainWindow *>(window)->reloadRecentFileList();
     }
 }
 
 void KoMainWindow::reloadRecentFileList()
 {
-    KConfig * config = instance() ? instance()->config() : KGlobal::config();
+    TDEConfig * config = instance() ? instance()->config() : TDEGlobal::config();
     m_recent->loadEntries( config );
 }
 
@@ -542,7 +551,7 @@ KParts::PartManager *KoMainWindow::partManager()
 
 bool KoMainWindow::openDocument( const KURL & url )
 {
-    if ( !KIO::NetAccess::exists(url,true,0) )
+    if ( !TDEIO::NetAccess::exists(url,true,0) )
     {
         KMessageBox::error(0L, i18n("The file %1 does not exist.").arg(url.url()) );
         m_recent->removeURL(url); //remove the file from the recent-opened-file-list
@@ -555,7 +564,7 @@ bool KoMainWindow::openDocument( const KURL & url )
 // (not virtual)
 bool KoMainWindow::openDocument( KoDocument *newdoc, const KURL & url )
 {
-    if (!KIO::NetAccess::exists(url,true,0) )
+    if (!TDEIO::NetAccess::exists(url,true,0) )
     {
         if (!newdoc->checkAutoSaveFile())
         {
@@ -567,7 +576,7 @@ bool KoMainWindow::openDocument( KoDocument *newdoc, const KURL & url )
         TQString mime = KMimeType::findByURL(url)->name();
         if ( mime.isEmpty() || mime == KMimeType::defaultMimeType() )
             mime = newdoc->nativeFormatMimeType();
-        if ( url.isLocalFile() ) // workaround for kde<=3.3 kparts bug, fixed for 3.4
+        if ( url.isLocalFile() ) // workaround for kde<=3.3 tdeparts bug, fixed for 3.4
             newdoc->setFile(url.path());
         newdoc->setMimeTypeAfterLoading( mime );
         updateCaption();
@@ -757,7 +766,7 @@ bool KoMainWindow::saveDocument( bool saveas, bool silent )
             int c = suggestedFilename.findRev ('.');
 
             KMimeType::Ptr mime = KMimeType::mimeType( _native_format );
-            TQString ext = mime->property( "X-KDE-NativeExtension" ).toString();
+            TQString ext = mime->property( "X-TDE-NativeExtension" ).toString();
             if (!ext.isEmpty ())
             {
                 if (c < 0)
@@ -847,7 +856,7 @@ bool KoMainWindow::saveDocument( bool saveas, bool silent )
 
             // this file exists and we are not just clicking "Save As" to change filter options
             // => ask for confirmation
-            if ( KIO::NetAccess::exists( newURL, false /*will write*/, this ) && !justChangingFilterOptions )
+            if ( TDEIO::NetAccess::exists( newURL, false /*will write*/, this ) && !justChangingFilterOptions )
             {
                 bOk = KMessageBox::questionYesNo( this,
                                                   i18n("A document with this name already exists.\n"\
@@ -998,9 +1007,9 @@ void KoMainWindow::saveWindowSettings()
         d->m_windowSizeDirty = false;
         // Save toolbar position into the config file of the app, under the doc's instance name
         //kdDebug(30003) << "KoMainWindow::closeEvent -> saveMainWindowSettings rootdoc's instance=" << rootDocument()->instance()->instanceName() << endl;
-        saveMainWindowSettings( KGlobal::config(), rootDocument()->instance()->instanceName() );
-        KGlobal::config()->sync();
-        resetAutoSaveSettings(); // Don't let KMainWindow override the good stuff we wrote down
+        saveMainWindowSettings( TDEGlobal::config(), rootDocument()->instance()->instanceName() );
+        TDEGlobal::config()->sync();
+        resetAutoSaveSettings(); // Don't let TDEMainWindow override the good stuff we wrote down
     }
 }
 
@@ -1201,7 +1210,7 @@ void KoMainWindow::print(bool quick) {
     // strip off the native extension (I don't want foobar.kwd.ps when printing into a file)
     KMimeType::Ptr mime = KMimeType::mimeType( rootView()->koDocument()->outputMimeType() );
     if ( mime ) {
-        TQString extension = mime->property( "X-KDE-NativeExtension" ).toString();
+        TQString extension = mime->property( "X-TDE-NativeExtension" ).toString();
 
         if ( fileName.endsWith( extension ) )
             fileName.truncate( fileName.length() - extension.length() );
@@ -1212,7 +1221,7 @@ void KoMainWindow::print(bool quick) {
     if ( title.isEmpty() ) {
         // #139905 - breaks message freeze though
         //const TQString programName = instance()->aboutData() ? instance()->aboutData()->programName() : instance()->instanceName();
-        //title = i18n("%1 unsaved document (%2)").arg(programName).arg(KGlobal::locale()->formatDate(TQDate::currentDate(), true/*short*/));
+        //title = i18n("%1 unsaved document (%2)").arg(programName).arg(TDEGlobal::locale()->formatDate(TQDate::currentDate(), true/*short*/));
     }
     printer.setDocName( title );
     printer.setDocFileName( fileName );
@@ -1253,7 +1262,7 @@ void KoMainWindow::slotFilePrintPreview()
     printer.setOutputFileName( tmpFile.name() );
     int oldNumCopies = printer.numCopies();
     printer.setNumCopies( 1 );
-    // Disable kdeprint's own preview, we'd get two. This shows that KPrinter needs
+    // Disable tdeprint's own preview, we'd get two. This shows that KPrinter needs
     // a "don't use the previous settings" mode. The current way is really too much of a hack.
     TQString oldKDEPreview = printer.option( "kde-preview" );
     printer.setOption( "kde-preview", "0" );
@@ -1275,7 +1284,7 @@ void KoMainWindow::slotConfigureKeys()
 void KoMainWindow::slotConfigureToolbars()
 {
     if (rootDocument())
-        saveMainWindowSettings( KGlobal::config(), rootDocument()->instance()->instanceName() );
+        saveMainWindowSettings( TDEGlobal::config(), rootDocument()->instance()->instanceName() );
     KEditToolbar edit(factory(), this);
     connect(&edit,TQT_SIGNAL(newToolbarConfig()),this,TQT_SLOT(slotNewToolbarConfig()));
     (void) edit.exec();
@@ -1284,7 +1293,7 @@ void KoMainWindow::slotConfigureToolbars()
 void KoMainWindow::slotNewToolbarConfig()
 {
   if (rootDocument())
-      applyMainWindowSettings( KGlobal::config(), rootDocument()->instance()->instanceName() );
+      applyMainWindowSettings( TDEGlobal::config(), rootDocument()->instance()->instanceName() );
   KXMLGUIFactory *factory = guiFactory();
 
   // Check if there's an active view
@@ -1306,7 +1315,7 @@ void KoMainWindow::slotToolbarToggled( bool toggle )
 {
   //kdDebug(30003) << "KoMainWindow::slotToolbarToggled " << sender()->name() << " toggle=" << true << endl;
   // The action (sender) and the toolbar have the same name
-  KToolBar * bar = toolBar( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() );
+  TDEToolBar * bar = toolBar( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() );
   if (bar)
   {
     if (toggle)
@@ -1315,7 +1324,7 @@ void KoMainWindow::slotToolbarToggled( bool toggle )
       bar->hide();
 
     if (rootDocument())
-        saveMainWindowSettings( KGlobal::config(), rootDocument()->instance()->instanceName() );
+        saveMainWindowSettings( TDEGlobal::config(), rootDocument()->instance()->instanceName() );
   }
   else
     kdWarning(30003) << "slotToolbarToggled : Toolbar " << TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() << " not found!" << endl;
@@ -1341,12 +1350,12 @@ void KoMainWindow::showToolbar( const char * tbName, bool shown )
         tb->hide();
 
     // Update the action appropriately
-    TQPtrListIterator<KAction> it( d->m_toolbarList );
+    TQPtrListIterator<TDEAction> it( d->m_toolbarList );
     for ( ; it.current() ; ++it )
         if ( !strcmp( it.current()->name(), tbName ) )
         {
             //kdDebug(30003) << "KoMainWindow::showToolbar setChecked " << shown << endl;
-            static_cast<KToggleAction *>(it.current())->setChecked( shown );
+            static_cast<TDEToggleAction *>(it.current())->setChecked( shown );
             break;
         }
 }
@@ -1521,15 +1530,15 @@ void KoMainWindow::slotActivePartChanged( KParts::Part *newPart )
     setAutoSaveSettings( newPart->instance()->instanceName(), false );
 
     // Create and plug toolbar list for Settings menu
-    //TQPtrListIterator<KToolBar> it = toolBarIterator();
+    //TQPtrListIterator<TDEToolBar> it = toolBarIterator();
     TQPtrList<TQWidget> toolBarList = factory->containers( "ToolBar" );
     TQPtrListIterator<TQWidget> it( toolBarList );
     for ( ; it.current() ; ++it )
     {
-      if ( it.current()->inherits("KToolBar") )
+      if ( it.current()->inherits("TDEToolBar") )
       {
-          KToolBar * tb = static_cast<KToolBar *>(it.current());
-          KToggleAction * act = new KToggleAction( i18n("Show %1 Toolbar").arg( tb->text() ), 0,
+          TDEToolBar * tb = static_cast<TDEToolBar *>(it.current());
+          TDEToggleAction * act = new TDEToggleAction( i18n("Show %1 Toolbar").arg( tb->text() ), 0,
                                                actionCollection(), tb->name() );
 	  act->setCheckedState(i18n("Hide %1 Toolbar").arg( tb->text() ));
 	  connect( act, TQT_SIGNAL( toggled( bool ) ), TQT_TQOBJECT(this), TQT_SLOT( slotToolbarToggled( bool ) ) );
