@@ -24,15 +24,15 @@
 #include <KoViewIface.h>
 #include <KoDocumentChild.h>
 
-#include <klocale.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
 #include <kdebug.h>
-#include <kparts/partmanager.h>
-#include <kparts/event.h>
+#include <tdeparts/partmanager.h>
+#include <tdeparts/event.h>
 #include <kcursor.h>
 #include <assert.h>
 #include <kstatusbar.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <tqtimer.h>
 
 class KoViewPrivate
@@ -132,11 +132,11 @@ KoView::KoView( KoDocument *document, TQWidget *parent, const char *name )
 
   actionCollection()->setWidget( this );
   setupGlobalActions();
-  KActionCollection *coll = actionCollection();
+  TDEActionCollection *coll = actionCollection();
   /**** not needed anymore, according to David (Werner)
-  TQValueList<KAction*> docActions = document->actionCollection()->actions();
-  TQValueList<KAction*>::ConstIterator it = docActions.begin();
-  TQValueList<KAction*>::ConstIterator end = docActions.end();
+  TQValueList<TDEAction*> docActions = document->actionCollection()->actions();
+  TQValueList<TDEAction*>::ConstIterator it = docActions.begin();
+  TQValueList<TDEAction*>::ConstIterator end = docActions.end();
   for (; it != end; ++it )
       coll->insert( *it );
   */
@@ -217,12 +217,12 @@ KParts::PartManager *KoView::partManager() const
   return d->m_manager;
 }
 
-KAction *KoView::action( const TQDomElement &element ) const
+TDEAction *KoView::action( const TQDomElement &element ) const
 {
-  static const TQString &attrName = KGlobal::staticQString( "name" );
+  static const TQString &attrName = TDEGlobal::staticQString( "name" );
   TQString name = element.attribute( attrName );
 
-  KAction *act = KXMLGUIClient::action( name.utf8() );
+  TDEAction *act = KXMLGUIClient::action( name.utf8() );
 
   if ( !act )
     act = d->m_doc->KXMLGUIClient::action( name.utf8() );
@@ -626,7 +626,7 @@ void KoView::slotAutoScroll(  )
 
 
 void KoView::setupGlobalActions() {
-    actionNewView = new KAction( i18n( "&New View" ), "window_new", 0,
+    actionNewView = new TDEAction( i18n( "&New View" ), "window-new", 0,
         TQT_TQOBJECT(this), TQT_SLOT( newView() ),
         actionCollection(), "view_newview" );
 }
@@ -674,9 +674,9 @@ KoMainWindow * KoView::shell() const
     return dynamic_cast<KoMainWindow *>( topLevelWidget() );
 }
 
-KMainWindow * KoView::mainWindow() const
+TDEMainWindow * KoView::mainWindow() const
 {
-    return dynamic_cast<KMainWindow *>( topLevelWidget() );
+    return dynamic_cast<TDEMainWindow *>( topLevelWidget() );
 }
 
 KStatusBar * KoView::statusBar() const
