@@ -29,11 +29,11 @@
 #include <tqtooltip.h>
 
 // KDE includes
-#include <klocale.h>
-#include <kglobal.h>
-#include <kapplication.h>
-#include <kmainwindow.h>
-#include <kaction.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
+#include <tdeapplication.h>
+#include <tdemainwindow.h>
+#include <tdeaction.h>
 #include <kdebug.h>
 
 // KKbdAccessExtensions includes
@@ -122,7 +122,7 @@ class KKbdAccessExtensionsPrivate
         ~KKbdAccessExtensionsPrivate()
         {
             delete icon;
-            // TODO: This crashes, but should delete in the event that KMainWindow is not deleted.
+            // TODO: This crashes, but should delete in the event that TDEMainWindow is not deleted.
             if (accessKeyLabels) {
                 accessKeyLabels->setAutoDelete(false);
                 delete accessKeyLabels;
@@ -130,11 +130,11 @@ class KKbdAccessExtensionsPrivate
         }
 
         // Action that starts panel sizing (defaults to F8), forward and reverse;
-        KAction* fwdAction;
-        KAction* revAction;
+        TDEAction* fwdAction;
+        TDEAction* revAction;
 
         // Action that starts access keys.
-        KAction* accessKeysAction;
+        TDEAction* accessKeysAction;
 
         // The splitter or dockwindow currently being sized.  If 0, sizing is not in progress.
         TQWidget* panel;
@@ -153,21 +153,21 @@ class KKbdAccessExtensionsPrivate
         // List of the access key TQLabels.  If not 0, access keys are onscreen.
         TQPtrList<TQLabel>* accessKeyLabels;
 
-        // Pointer to the KMainWindow.
-        KMainWindow* mainWindow;
+        // Pointer to the TDEMainWindow.
+        TDEMainWindow* mainWindow;
 };
 
-KKbdAccessExtensions::KKbdAccessExtensions(KMainWindow* parent, const char* name) :
+KKbdAccessExtensions::KKbdAccessExtensions(TDEMainWindow* parent, const char* name) :
     TQObject(parent, name)
 {
     // kdDebug() << "KKbdAccessExtensions::KKbdAccessExtensions: running." << endl;
     d = new KKbdAccessExtensionsPrivate;
     d->mainWindow = parent;
-    d->fwdAction = new KAction(i18n("Resize Panel Forward"), KShortcut("F8"),
+    d->fwdAction = new TDEAction(i18n("Resize Panel Forward"), TDEShortcut("F8"),
         0, 0, parent->actionCollection(), "resize_panel_forward");
-    d->revAction = new KAction(i18n("Resize Panel Reverse"), KShortcut("Shift+F8"),
+    d->revAction = new TDEAction(i18n("Resize Panel Reverse"), TDEShortcut("Shift+F8"),
         0, 0, parent->actionCollection(), "resize_panel_reverse");
-    d->accessKeysAction = new KAction(i18n("Access Keys"), KShortcut("Alt+F8"),
+    d->accessKeysAction = new TDEAction(i18n("Access Keys"), TDEShortcut("Alt+F8"),
         0, 0, parent->actionCollection(), "access_keys");
     // "Disable" the shortcuts so we can see them in eventFilter.
     d->fwdAction->setEnabled(false);
@@ -193,15 +193,15 @@ bool KKbdAccessExtensions::eventFilter( TQObject *o, TQEvent *e )
     if ( e->type() == TQEvent::KeyPress ) {
         // TODO: This permits only a single-key shortcut.  For example, Alt+S,R would not work.
         // If user configures a multi-key shortcut, it is undefined what will happen here.
-        // It would be better to handle these as KShortcut activate() signals, but the problem
-        // is that once a TQDockWindow is undocked and has focus, the KShortcut activate() signals
+        // It would be better to handle these as TDEShortcut activate() signals, but the problem
+        // is that once a TQDockWindow is undocked and has focus, the TDEShortcut activate() signals
         // don't fire anymore.
-        KShortcut fwdSc = d->fwdAction->shortcut();
-        KShortcut revSc = d->revAction->shortcut();
-        KShortcut accessKeysSc = d->accessKeysAction->shortcut();
+        TDEShortcut fwdSc = d->fwdAction->shortcut();
+        TDEShortcut revSc = d->revAction->shortcut();
+        TDEShortcut accessKeysSc = d->accessKeysAction->shortcut();
         TQKeyEvent* kev = dynamic_cast<TQKeyEvent *>(e);
         KKey k = KKey(kev);
-        KShortcut sc = KShortcut(k);
+        TDEShortcut sc = TDEShortcut(k);
         // kdDebug() << "KKbdAccessExtensions::eventFilter: Key press " << sc << endl;
         if (!d->accessKeyLabels) {
             if (sc == fwdSc) {
@@ -555,10 +555,10 @@ void KKbdAccessExtensions::displayAccessKeys()
     while( (client=it.current()) !=0 )
     {
         ++it;
-        KActionPtrList actions = client->actionCollection()->actions();
+        TDEActionPtrList actions = client->actionCollection()->actions();
         for (int j = 0; j < (int)actions.count(); j++) {
-            KAction* action = actions[j];
-            KShortcut sc = action->shortcut();
+            TDEAction* action = actions[j];
+            TDEShortcut sc = action->shortcut();
             for (int i = 0; i < (int)sc.count(); i++) {
                 KKeySequence seq = sc.seq(i);
                 if (seq.count() == 1) {
