@@ -27,11 +27,11 @@
 #include <tqsimplerichtext.h>
 
 #include <kpixmap.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 #include <kiconloader.h>
 #include <kcursor.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <tqstring.h>
 
 KoVerticalLabel::KoVerticalLabel( TQWidget* parent, const char* name )
@@ -507,8 +507,8 @@ void KoContextHelpPopup::keyReleaseEvent( TQKeyEvent* e )
 	}
 } // KoContextHelpPopup::keyPressEvent
 
-KoContextHelpAction::KoContextHelpAction( KActionCollection* parent, TQWidget* /*popupParent*/ )
-		: KToggleAction( i18n( "Context Help" ), BarIcon( "help" ), KShortcut( "CTRL+SHIFT+F1" ), 0, 0, parent, "help_context" )
+KoContextHelpAction::KoContextHelpAction( TDEActionCollection* parent, TQWidget* /*popupParent*/ )
+		: TDEToggleAction( i18n( "Context Help" ), BarIcon( "help" ), TDEShortcut( "CTRL+SHIFT+F1" ), 0, 0, parent, "help_context" )
 {
 	m_popup = new KoContextHelpPopup( 0L );
 	connect( m_popup, TQT_SIGNAL( wantsToBeClosed() ), this, TQT_SLOT( closePopup() ) );
