@@ -22,8 +22,8 @@
 /******************************************************************/
 
 #include "KoRuler.h"
-#include <klocale.h>
-#include <kglobalsettings.h>
+#include <tdelocale.h>
+#include <tdeglobalsettings.h>
 #include <kdebug.h>
 #include <kiconloader.h>
 #include <tqcursor.h>
@@ -203,7 +203,7 @@ double KoRuler::lineDistance() const
 /*================================================================*/
 void KoRuler::drawHorizontal( TQPainter *_painter )
 {
-    TQFont font = KGlobalSettings::toolBarFont();
+    TQFont font = TDEGlobalSettings::toolBarFont();
     TQFontMetrics fm( font );
     resize( width(), TQMAX( fm.height() + 4, 20 ) );
 
@@ -366,7 +366,7 @@ void KoRuler::drawTabs( TQPainter &_painter )
 /*================================================================*/
 void KoRuler::drawVertical( TQPainter *_painter )
 {
-    TQFont font = KGlobalSettings::toolBarFont();
+    TQFont font = TDEGlobalSettings::toolBarFont();
     TQFontMetrics fm( font );
     resize( TQMAX( fm.height() + 4, 20 ), height() );
 
@@ -550,7 +550,7 @@ void KoRuler::mousePressEvent( TQMouseEvent *e )
                 break;
             case KoTabChooser::TAB_DEC_PNT:
                 tab.type = T_DEC_PNT;
-                tab.alignChar = KGlobal::locale()->decimalSymbol()[0];
+                tab.alignChar = TDEGlobal::locale()->decimalSymbol()[0];
                 break;
             default: break;
             }
@@ -1006,7 +1006,7 @@ double KoRuler::makeIntern( double _v )
 void KoRuler::setupMenu()
 {
     d->rb_menu = new TQPopupMenu();
-    Q_CHECK_PTR( d->rb_menu );
+    TQ_CHECK_PTR( d->rb_menu );
     for ( uint i = 0 ; i <= KoUnit::U_LASTUNIT ; ++i )
     {
         KoUnit::Unit unit = static_cast<KoUnit::Unit>( i );
@@ -1179,7 +1179,7 @@ void KoRuler::slotMenuActivated( int i )
 TQSize KoRuler::minimumSizeHint() const
 {
     TQSize size;
-    TQFont font = KGlobalSettings::toolBarFont();
+    TQFont font = TDEGlobalSettings::toolBarFont();
     TQFontMetrics fm( font );
 
     size.setWidth( TQMAX( fm.height() + 4, 20 ) );
