@@ -25,11 +25,11 @@
 #include <tqstyle.h>
 #include <tqpopupmenu.h>
 
-#include <kglobalsettings.h>
-#include <ktoolbar.h>
+#include <tdeglobalsettings.h>
+#include <tdetoolbar.h>
 #include <KoTooluButton.h>
 #include <kcolordrag.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kcolordialog.h>
 #include <kdebug.h>
 
@@ -646,15 +646,15 @@ void KoColorPopupProxy::slotMoreColors()
 
 
 KoToolButton::KoToolButton( const TQString& icon, int id, TQWidget* parent,
-                            const char* name, const TQString& txt, KInstance* _instance ) :
-    KToolBarButton( icon, id, parent, name, txt, _instance ), m_arrowPressed( false )
+                            const char* name, const TQString& txt, TDEInstance* _instance ) :
+    TDEToolBarButton( icon, id, parent, name, txt, _instance ), m_arrowPressed( false )
 {
     init();
 }
 
 KoToolButton::KoToolButton( const TQPixmap& pixmap, int id, TQWidget* parent,
                             const char* name, const TQString& txt ) :
-    KToolBarButton( pixmap, id, parent, name, txt ), m_arrowPressed( false )
+    TDEToolBarButton( pixmap, id, parent, name, txt ), m_arrowPressed( false )
 {
     init();
 }
@@ -670,7 +670,7 @@ TQSize KoToolButton::sizeHint() const
 
 TQSize KoToolButton::minimumSizeHint() const
 {
-    TQSize size = KToolBarButton::minimumSizeHint();
+    TQSize size = TDEToolBarButton::minimumSizeHint();
     size.setWidth( size.width() + ARROW_WIDTH );
     return size;
 }
@@ -695,7 +695,7 @@ void KoToolButton::drawButton(TQPainter *_painter)
 
     if ( isEnabled() ) {
   	flags |= TQStyle::Style_Enabled;
-        if ( KToolBarButton::isRaised() || m_arrowPressed )
+        if ( TDEToolBarButton::isRaised() || m_arrowPressed )
             flags |= TQStyle::Style_Raised;
     }
     if ( isOn() )
@@ -723,18 +723,18 @@ void KoToolButton::drawButton(TQPainter *_painter)
     style().tqdrawPrimitive( TQStyle::PE_ArrowDown, _painter, TQRect( width() - ARROW_WIDTH - 1, 0, ARROW_WIDTH, height() ),
                            cg, flags, opt );
 
-    if ( KToolBarButton::isRaised() || m_arrowPressed )
+    if ( TDEToolBarButton::isRaised() || m_arrowPressed )
         qDrawShadeLine( _painter, width() - ARROW_WIDTH - 1, 0, width() - ARROW_WIDTH - 1, height() - 1, colorGroup(), true );
 
     int dx, dy;
-    TQFont tmp_font( KGlobalSettings::toolBarFont() );
+    TQFont tmp_font( TDEGlobalSettings::toolBarFont() );
     TQFontMetrics fm( tmp_font );
     TQRect textRect;
     int textFlags = 0;
 
-    if ( static_cast<KToolBar::IconText>( iconTextMode() ) == KToolBar::IconOnly ) { // icon only
+    if ( static_cast<TDEToolBar::IconText>( iconTextMode() ) == TDEToolBar::IconOnly ) { // icon only
         TQPixmap pixmap = iconSet().pixmap( TQIconSet::Automatic,
-                                           isEnabled() ? ( KToolBarButton::isActive() ? TQIconSet::Active : TQIconSet::Normal ) :
+                                           isEnabled() ? ( TDEToolBarButton::isActive() ? TQIconSet::Active : TQIconSet::Normal ) :
                                            TQIconSet::Disabled, isOn() ? TQIconSet::On : TQIconSet::Off );
         if ( !pixmap.isNull() ) {
             dx = ( width() - ARROW_WIDTH - pixmap.width() ) / 2;
@@ -743,9 +743,9 @@ void KoToolButton::drawButton(TQPainter *_painter)
             _painter->drawPixmap( dx, dy, pixmap );
         }
     }
-    else if ( static_cast<KToolBar::IconText>( iconTextMode() ) == KToolBar::IconTextRight ) { // icon and text (if any)
+    else if ( static_cast<TDEToolBar::IconText>( iconTextMode() ) == TDEToolBar::IconTextRight ) { // icon and text (if any)
         TQPixmap pixmap = iconSet().pixmap( TQIconSet::Automatic,
-                                           isEnabled() ? ( KToolBarButton::isActive() ? TQIconSet::Active : TQIconSet::Normal ) :
+                                           isEnabled() ? ( TDEToolBarButton::isActive() ? TQIconSet::Active : TQIconSet::Normal ) :
                                            TQIconSet::Disabled, isOn() ? TQIconSet::On : TQIconSet::Off );
         if( !pixmap.isNull()) {
             dx = 4;
@@ -765,7 +765,7 @@ void KoToolButton::drawButton(TQPainter *_painter)
             textRect = TQRect( dx, dy, width() - dx, height() );
         }
     }
-    else if ( static_cast<KToolBar::IconText>( iconTextMode() ) == KToolBar::TextOnly ) {
+    else if ( static_cast<TDEToolBar::IconText>( iconTextMode() ) == TDEToolBar::TextOnly ) {
         if ( !textLabel().isNull() ) {
             textFlags = AlignTop | AlignLeft;
             dx = ( width() - ARROW_WIDTH - fm.width( textLabel() ) ) / 2;
@@ -774,9 +774,9 @@ void KoToolButton::drawButton(TQPainter *_painter)
             textRect = TQRect( dx, dy, fm.width(textLabel()), fm.lineSpacing() );
         }
     }
-    else if ( static_cast<KToolBar::IconText>( iconTextMode() ) == KToolBar::IconTextBottom ) {
+    else if ( static_cast<TDEToolBar::IconText>( iconTextMode() ) == TDEToolBar::IconTextBottom ) {
         TQPixmap pixmap = iconSet().pixmap( TQIconSet::Automatic,
-                                           isEnabled() ? ( KToolBarButton::isActive() ? TQIconSet::Active : TQIconSet::Normal ) :
+                                           isEnabled() ? ( TDEToolBarButton::isActive() ? TQIconSet::Active : TQIconSet::Normal ) :
                                            TQIconSet::Disabled, isOn() ? TQIconSet::On : TQIconSet::Off );
         if( !pixmap.isNull()) {
             dx = ( width() - ARROW_WIDTH - pixmap.width() ) / 2;
@@ -796,11 +796,11 @@ void KoToolButton::drawButton(TQPainter *_painter)
 
     // Draw the text at the position given by textRect, and using textFlags
     if (!textLabel().isNull() && !textRect.isNull()) {
-        _painter->setFont( KGlobalSettings::toolBarFont() );
+        _painter->setFont( TDEGlobalSettings::toolBarFont() );
         if ( !isEnabled() )
             _painter->setPen( palette().disabled().dark() );
-        else if( KToolBarButton::isRaised() )
-            _painter->setPen( KGlobalSettings::toolBarHighlightColor() );
+        else if( TDEToolBarButton::isRaised() )
+            _painter->setPen( TDEGlobalSettings::toolBarHighlightColor() );
         else
             _painter->setPen( colorGroup().buttonText() );
         _painter->drawText( textRect, textFlags, textLabel() );
@@ -827,7 +827,7 @@ bool KoToolButton::eventFilter( TQObject* o, TQEvent* e )
     }
     else if ( e->type() == TQEvent::MouseButtonRelease )
         m_arrowPressed = false;
-    return KToolBarButton::eventFilter( o, e );
+    return TDEToolBarButton::eventFilter( o, e );
 }
 
 void KoToolButton::init()
