@@ -40,9 +40,9 @@
 
 #include <kdebug.h>
 #include <kiconloader.h>
-#include <klocale.h>
-#include <kdeversion.h>
-#include <kapplication.h>
+#include <tdelocale.h>
+#include <tdeversion.h>
+#include <tdeapplication.h>
 
 namespace KoProperty {
 
@@ -72,7 +72,7 @@ class EditorPrivate
 			itemToSelectLater = 0;
 			if (!kofficeAppDirAdded) {
 				kofficeAppDirAdded = true;
-				KGlobal::iconLoader()->addAppDir("koffice");
+				TDEGlobal::iconLoader()->addAppDir("koffice");
 			}
 			previouslyCollapsedGroupItem = 0;
 			childFormPreviouslyCollapsedGroupItem = 0;
@@ -120,7 +120,7 @@ class EditorPrivate
 using namespace KoProperty;
 
 Editor::Editor(TQWidget *parent, bool autoSync, const char *name)
- : KListView(parent, name)
+ : TDEListView(parent, name)
 {
 	d = new EditorPrivate(this);
 	d->itemDict.setAutoDelete(false);
@@ -138,7 +138,7 @@ Editor::Editor(TQWidget *parent, bool autoSync, const char *name)
 	d->undoButton->setFocusPolicy(TQ_NoFocus);
 	setFocusPolicy(TQ_ClickFocus);
 	d->undoButton->setMinimumSize(TQSize(5,5)); // allow to resize undoButton even below pixmap size
-	d->undoButton->setPixmap(SmallIcon("undo"));
+	d->undoButton->setPixmap(SmallIcon("edit-undo"));
 	TQToolTip::add(d->undoButton, i18n("Undo changes"));
 	d->undoButton->hide();
 	connect(d->undoButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(undo()));
@@ -189,7 +189,7 @@ Editor::fill()
 	d->itemToSelectLater = 0;
 	tqApp->eventLoop()->processEvents(TQEventLoop::AllEvents);
 	hideEditor();
-	KListView::clear();
+	TDEListView::clear();
 	d->itemDict.clear();
 	clearWidgetCache();
 	if(!d->set) {
@@ -416,7 +416,7 @@ Editor::clear(bool editorOnly)
 		if(d->set)
 			d->set->disconnect(this);
 		clearWidgetCache(); 
-		KListView::clear();
+		TDEListView::clear();
 		d->itemDict.clear();
 		d->topItem = 0;
 	}
@@ -872,7 +872,7 @@ TQSize
 Editor::sizeHint() const
 {
 	return TQSize( TQFontMetrics(font()).width(columnText(0)+columnText(1)+"   "),
-		KListView::sizeHint().height());
+		TDEListView::sizeHint().height());
 }
 
 void
@@ -897,15 +897,15 @@ Editor::setFocus()
 		d->currentWidget->setFocus();
 	}
 	else {
-//		kopropertydbg << "KListView::setFocus()" << endl;
-		KListView::setFocus();
+//		kopropertydbg << "TDEListView::setFocus()" << endl;
+		TDEListView::setFocus();
 	}
 }
 
 void
 Editor::resizeEvent(TQResizeEvent *ev)
 {
-	KListView::resizeEvent(ev);
+	TDEListView::resizeEvent(ev);
 	if(d->undoButton->isVisible())
 		showUndoButton(true);
 	update();
@@ -919,7 +919,7 @@ Editor::eventFilter( TQObject * watched, TQEvent * e )
 		if (handleKeyPress(TQT_TQKEYEVENT(e)))
 			return true;
 	}
-	return KListView::eventFilter(watched, e);
+	return TDEListView::eventFilter(watched, e);
 }
 
 bool
@@ -998,7 +998,7 @@ Editor::event( TQEvent * e )
 	if (e->type()==TQEvent::ParentFontChange) {
 		updateFont();
 	}
-	return KListView::event(e);
+	return TDEListView::event(e);
 }
 
 void
@@ -1009,7 +1009,7 @@ Editor::contentsMousePressEvent( TQMouseEvent * e )
 		setOpen( item, !isOpen(item) );
 		return;
 	}
-	KListView::contentsMousePressEvent(e);
+	TDEListView::contentsMousePressEvent(e);
 }
 
 void
@@ -1017,7 +1017,7 @@ Editor::setSorting( int column, bool ascending )
 {
 	if (d->set && d->set->groupNames().count()>1) //do not sort when groups are present (maybe reenable this later?)
 		return;
-	KListView::setSorting( column, ascending );
+	TDEListView::setSorting( column, ascending );
 	updateEditorGeometry();
 	updateGroupLabelsPosition();
 	repaintContents();
