@@ -35,9 +35,9 @@
 
 #include <kdebug.h>
 #include <kiconloader.h>
-#include <kstyle.h>
-#include <kpopupmenu.h>
-#include <kapplication.h>
+#include <tdestyle.h>
+#include <tdepopupmenu.h>
+#include <tdeapplication.h>
 
 #define BRANCHBOX_SIZE 9
 
@@ -61,11 +61,11 @@ static void paintListViewExpander(TQPainter* p, TQWidget* w, int height, const T
 //		if (dynamic_cast<EditorGroupItem*>(item))
 //				xmarg = xmarg * 10 / 14 -1;
 #if 0 
-//! @todo disabled: kstyles do not paint background yet... reenable in the future...
-	KStyle* kstyle = dynamic_cast<KStyle*>(widget->style());
-	if (kstyle) {
-		kstyle->drawKStylePrimitive(
-			KStyle::KPE_ListViewExpander, p, w, TQRect( xmarg, marg, BRANCHBOX_SIZE, BRANCHBOX_SIZE ), 
+//! @todo disabled: tdestyles do not paint background yet... reenable in the future...
+	TDEStyle* tdestyle = dynamic_cast<TDEStyle*>(widget->style());
+	if (tdestyle) {
+		tdestyle->drawTDEStylePrimitive(
+			TDEStyle::KPE_ListViewExpander, p, w, TQRect( xmarg, marg, BRANCHBOX_SIZE, BRANCHBOX_SIZE ), 
 			cg, isOpen ? 0 : TQStyle::Style_On,
 				TQStyleOption::Default);
 	}
@@ -89,7 +89,7 @@ static void paintListViewExpander(TQPainter* p, TQWidget* w, int height, const T
 }
 
 //! @internal
-//! Based on KPopupTitle, see kpopupmenu.cpp
+//! Based on TDEPopupTitle, see tdepopupmenu.cpp
 class GroupWidgetBase : public TQWidget
 {
 	public:
@@ -255,7 +255,7 @@ bool GroupContainer::event( TQEvent * e ) {
 //////////////////////////////////////////////////////
 
 EditorItem::EditorItem(Editor *editor, EditorItem *parent, Property *property, TQListViewItem *after)
- : KListViewItem(parent, after,
+ : TDEListViewItem(parent, after,
 	property->captionForDisplaying().isEmpty() ? property->name() : property->captionForDisplaying())
 {
 	d = new EditorItemPrivate();
@@ -280,8 +280,8 @@ EditorItem::EditorItem(Editor *editor, EditorItem *parent, Property *property, T
 */
 }
 
-EditorItem::EditorItem(KListView *parent)
- : KListViewItem(parent)
+EditorItem::EditorItem(TDEListView *parent)
+ : TDEListViewItem(parent)
 {
 	d = new EditorItemPrivate();
 	d->property = 0;
@@ -290,7 +290,7 @@ EditorItem::EditorItem(KListView *parent)
 }
 
 EditorItem::EditorItem(EditorItem *parent, const TQString &text)
- : KListViewItem(parent, text)
+ : TDEListViewItem(parent, text)
 {
 	d = new EditorItemPrivate();
 	d->property = 0;
@@ -299,7 +299,7 @@ EditorItem::EditorItem(EditorItem *parent, const TQString &text)
 }
 
 EditorItem::EditorItem(EditorItem *parent, EditorItem *after, const TQString &text)
- : KListViewItem(parent, after, text)
+ : TDEListViewItem(parent, after, text)
 {
 	d = new EditorItemPrivate();
 	d->property = 0;
@@ -333,7 +333,7 @@ EditorItem::paintCell(TQPainter *p, const TQColorGroup & cg, int column, int wid
 		p->setFont(font);
 		p->setBrush(cg.highlight());
 		p->setPen(cg.highlightedText());
-		KListViewItem::paintCell(p, cg, column, width, align);
+		TDEListViewItem::paintCell(p, cg, column, width, align);
 		p->fillRect(parent() ? 0 : 50, 0, width, height()-1,
 			TQBrush(isSelected() ? cg.highlight() : backgroundColor()));
 		p->setPen(isSelected() ? cg.highlightedText() : cg.text());
@@ -384,7 +384,7 @@ void
 EditorItem::paintBranches(TQPainter *p, const TQColorGroup &cg, int w, int y, int h)
 {
 	p->eraseRect(0,0,w,h);
-	KListViewItem *item = static_cast<KListViewItem*>(firstChild());
+	TDEListViewItem *item = static_cast<TDEListViewItem*>(firstChild());
 	if(!item)
 		return;
 
@@ -475,7 +475,7 @@ EditorItem::paintBranches(TQPainter *p, const TQColorGroup &cg, int w, int y, in
 		}
 
 		p->translate(0, item->totalHeight());
-		item = (KListViewItem*)item->nextSibling();
+		item = (TDEListViewItem*)item->nextSibling();
 	}
 	p->restore();
 }
@@ -507,7 +507,7 @@ EditorItem::compare( TQListViewItem *i, int col, bool ascending ) const
 void
 EditorItem::setHeight( int height )
 {
-	KListViewItem::setHeight(height);
+	TDEListViewItem::setHeight(height);
 }
 
 //////////////////////////////////////////////////////
@@ -575,7 +575,7 @@ EditorGroupItem::paintCell(TQPainter *p, const TQColorGroup & cg, int column, in
 	p->setFont(font);
 	p->setBrush(cg.highlight());
 	//p->setPen(cg.highlightedText());
-	KListViewItem::paintCell(p, cg, column, width, align);
+	TDEListViewItem::paintCell(p, cg, column, width, align);
 	p->setPen(cg.text());
 	p->drawText(TQRect(0,0, totalWidth, height()),
 		TQt::AlignLeft | TQt::AlignVCenter | TQt::SingleLine, text(0));*/
@@ -584,7 +584,7 @@ EditorGroupItem::paintCell(TQPainter *p, const TQColorGroup & cg, int column, in
 void
 EditorGroupItem::setup()
 {
-	KListViewItem::setup();
+	TDEListViewItem::setup();
 	setHeight( height()+4 );
 }
 
@@ -602,7 +602,7 @@ EditorGroupItem::compare( TQListViewItem *i, int col, bool ascending ) const
 
 ////////////////////////////////////////////////////////
 
-EditorDummyItem::EditorDummyItem(KListView *listview)
+EditorDummyItem::EditorDummyItem(TDEListView *listview)
  : EditorItem(listview)
 {
 	setSelectable(false);
