@@ -60,7 +60,7 @@ BoolEdit::~BoolEdit()
 TQVariant
 BoolEdit::value() const
 {
-    return TQVariant(m_toggle->isOn(), 4);
+    return TQVariant(m_toggle->isOn());
 }
 
 void
@@ -173,7 +173,7 @@ ThreeStateBoolEdit::value() const
 	// list items: true, false, NULL
 	const int idx = m_edit->currentItem();
 	if (idx==0)
-		return TQVariant(true, 1);
+		return TQVariant(true);
 	else
 		return idx==1 ? TQVariant(false) : TQVariant();
 }
