@@ -43,7 +43,7 @@ class KOPROPERTY_EXPORT CursorEdit : public ComboBox
 		virtual void drawViewer(TQPainter *p, const TQColorGroup &cg, const TQRect &r, const TQVariant &value);
 
 	private:
-		static TQMap<TQString, TQVariant> *m_spValues;
+		static TQStringVariantMap *m_spValues;
 };
 
 }
