@@ -52,7 +52,7 @@ class KOPROPERTY_EXPORT SizePolicyEdit : public Widget
 	private:
 		TQVariant  m_value;
 		TQLabel  *m_edit;
-		static TQMap<TQString, TQVariant> *m_spValues;
+		static TQStringVariantMap *m_spValues;
 };
 
 }
