@@ -78,7 +78,7 @@ class PropertyPrivate
 	TQVariant oldValue;
 	/*! The string-to-value correspondence list of the property.*/
 	Property::ListData* listData;
-//	TQMap<TQString, TQVariant> *valueList;
+//	TQStringVariantMap *valueList;
 	TQString icon;
 
 	bool changed : 1;
@@ -153,10 +153,10 @@ TQStringList Property::ListData::keysAsStringList() const
 /////////////////////////////////////////////////////////////////
 
 /*
-KOPROPERTY_EXPORT TQMap<TQString, TQVariant>
+KOPROPERTY_EXPORT TQStringVariantMap
 KoProperty::createValueListFromStringLists(const TQStringList &keys, const TQStringList &values)
 {
-	TQMap<TQString, TQVariant> map;
+	TQStringVariantMap map;
 	if(keys.count() != values.count())
 		return map;
 
@@ -423,7 +423,7 @@ Property::resetValue()
 	}
 }
 
-//const TQMap<TQString, TQVariant>*
+//const TQStringVariantMap*
 Property::ListData*
 Property::listData() const
 {
@@ -431,10 +431,10 @@ Property::listData() const
 }
 
 void
-Property::setListData(ListData* list) //const TQMap<TQString, TQVariant> &list)
+Property::setListData(ListData* list) //const TQStringVariantMap &list)
 {
 //	if(!d->valueList)
-//		d->valueList = new TQMap<TQString, TQVariant>();
+//		d->valueList = new TQStringVariantMap();
 	if (list == d->listData)
 		return;
 	delete d->listData;
@@ -448,7 +448,7 @@ Property::setListData(const TQStringList &keys, const TQStringList &names)
 	setListData(list);
 
 //	if(!d->valueList)
-//		d->valueList = new TQMap<TQString, TQVariant>();
+//		d->valueList = new TQStringVariantMap();
 //	*(d->valueList) = createValueListFromStringLists(keys, values);
 }
 
@@ -590,7 +590,7 @@ Property::operator= (const Property &property)
 	d->options = property.d->options;
 
 	if(property.d->listData) {
-		d->listData = new ListData(*property.d->listData); //TQMap<TQString, TQVariant>(*(property.d->valueList));
+		d->listData = new ListData(*property.d->listData); //TQStringVariantMap(*(property.d->valueList));
 	}
 	if(property.d->custom) {
 		d->custom = FactoryManager::self()->createCustomProperty(this);
