@@ -62,7 +62,7 @@ Test::Test()
 
 	m_set->addProperty(new Property("Int", 2, "Int"), group);
 	m_set->addProperty(new Property("Double", 3.1415,"Double"), group);
-	m_set->addProperty(new Property("Bool", TQVariant(true, 4), "Bool"), group);
+	m_set->addProperty(new Property("Bool", TQVariant(true), "Bool"), group);
 	m_set->addProperty(p = new Property("3 States", TQVariant(), "3 States", "", Boolean), group);
 	p->setOption("3rdState", "None");
 	m_set->addProperty(p = new Property("Date", TQDate::currentDate(),"Date"), group);
