@@ -33,12 +33,12 @@
 #include <kcolorbutton.h>
 #include <kdebug.h>
 #include <kiconloader.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <knumvalidator.h>
 #include <KoGlobal.h>
 #include <tqgroupbox.h>
 #include <knuminput.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 #include <kpushbutton.h>
 #include <kcombobox.h>
 
@@ -794,7 +794,7 @@ KoStylePreview::KoStylePreview( const TQString& title, const TQString& text, TQW
     setMinimumHeight(80);
     m_zoomHandler = new KoTextZoomHandler;
     TQFont font = KoGlobal::defaultFont();
-    m_textdoc = new KoTextDocument( m_zoomHandler, new KoTextFormatCollection( font, TQColor(), KGlobal::locale()->language(), false ) );
+    m_textdoc = new KoTextDocument( m_zoomHandler, new KoTextFormatCollection( font, TQColor(), TDEGlobal::locale()->language(), false ) );
 
     m_textdoc->setFlow( new MyFlow(this, m_zoomHandler) );
     //m_textdoc->setWidth( KoTextZoomHandler::ptToLayoutUnitPt( 1000 ) );
@@ -1827,7 +1827,7 @@ KoParagTabulatorsWidget::KoParagTabulatorsWidget( KoUnit::Unit unit, double fram
 
     sAlignChar = new TQLineEdit( bgAlign);
     sAlignChar->setMaximumSize( TQSize( 60, 32767 ) );
-    sAlignChar->setText(TQString(KGlobal::locale()->decimalSymbol()[0]));
+    sAlignChar->setText(TQString(TDEGlobal::locale()->decimalSymbol()[0]));
     Layout8->addWidget( sAlignChar );
     TQSpacerItem* spacer_2 = new TQSpacerItem( 20, 20, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
     Layout8->addItem( spacer_2 );
