@@ -29,8 +29,8 @@
 #include <kcolorbutton.h>
 #include <kcommand.h>
 #include <kdebug.h>
-#include <kfontcombo.h>
-#include <klocale.h>
+#include <tdefontcombo.h>
+#include <tdelocale.h>
 #include <kseparator.h>
 
 #include <tqbuttongroup.h>
@@ -589,7 +589,7 @@ KoFormatDia::KoFormatDia( TQWidget* parent, const TQString & _caption, KoSearchC
 
     m_checkVertAlign = new TQCheckBox( i18n( "Vertical alignment:" ), page );
 
-    m_familyItem = new KFontCombo(page);
+    m_familyItem = new TDEFontCombo(page);
     m_familyItem->setCurrentFont(m_ctx->m_family);
 
     m_sizeItem = new TQSpinBox( 4, 100, 1, page );
