@@ -36,15 +36,15 @@
 #include <KoXmlNS.h>
 #include <KoDom.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <kdialogbase.h>
-#include <kconfig.h>
-#include <kdeversion.h>
+#include <tdeconfig.h>
+#include <tdeversion.h>
 #include <kinstance.h>
 #include <kcalendarsystem.h>
-#include <kaboutdata.h>
+#include <tdeaboutdata.h>
 
 #include <tqstringlist.h>
 #include <tqcombobox.h>
@@ -235,18 +235,18 @@ TQString KoVariableDateFormat::convert( const TQVariant& data ) const
         return i18n("No date set"); // e.g. old KWord documents
 
     if (m_strFormat.lower() == "locale" || m_strFormat.isEmpty())
-        return KGlobal::locale()->formatDate( dateTime.date(), false );
+        return TDEGlobal::locale()->formatDate( dateTime.date(), false );
     else if ( m_strFormat.lower() == "localeshort" )
-        return KGlobal::locale()->formatDate( dateTime.date(), true );
+        return TDEGlobal::locale()->formatDate( dateTime.date(), true );
     else if ( m_strFormat.lower() == "localedatetime" )
-        return KGlobal::locale()->formatDateTime( dateTime, false );
+        return TDEGlobal::locale()->formatDateTime( dateTime, false );
     else if ( m_strFormat.lower() == "localedatetimeshort" )
-        return KGlobal::locale()->formatDateTime( dateTime, true );
+        return TDEGlobal::locale()->formatDateTime( dateTime, true );
 
     TQString tmp ( dateTime.toString(m_strFormat) );
     const int month = dateTime.date().month();
-    tmp.replace("PPPP", KGlobal::locale()->calendar()->monthNamePossessive(month, false)); //long possessive month name
-    tmp.replace("PPP",  KGlobal::locale()->calendar()->monthNamePossessive(month, true));  //short possessive month name
+    tmp.replace("PPPP", TDEGlobal::locale()->calendar()->monthNamePossessive(month, false)); //long possessive month name
+    tmp.replace("PPP",  TDEGlobal::locale()->calendar()->monthNamePossessive(month, true));  //short possessive month name
     return tmp;
 }
 
@@ -350,7 +350,7 @@ TQString KoVariableTimeFormat::convert( const TQVariant & time ) const
     }
 
     if( m_strFormat.lower() == "locale" || m_strFormat.isEmpty() )
-	return KGlobal::locale()->formatTime( time.toTime() );
+	return TDEGlobal::locale()->formatTime( time.toTime() );
     return time.toTime().toString(m_strFormat);
 }
 
@@ -569,10 +569,10 @@ void KoVariableCollection::setVariableSelected(KoVariable * var)
     m_varSelected=var;
 }
 
-// TODO change to TQValueList<KAction *>, but only once plugActionList takes that
-TQPtrList<KAction> KoVariableCollection::popupActionList() const
+// TODO change to TQValueList<TDEAction *>, but only once plugActionList takes that
+TQPtrList<TDEAction> KoVariableCollection::popupActionList() const
 {
-    TQPtrList<KAction> listAction;
+    TQPtrList<TDEAction> listAction;
     // Insert list of actions that change the subtype
     const TQStringList subTypeList = m_varSelected->subTypeList();
     kdDebug() << k_funcinfo << "current subtype=" << m_varSelected->subType() << endl;
@@ -583,7 +583,7 @@ TQPtrList<KAction> KoVariableCollection::popupActionList() const
         {
             // We store the subtype number as the action name
             TQCString name; name.setNum(i);
-            KToggleAction * act = new KToggleAction( *it, KShortcut(), 0, name );
+            TDEToggleAction * act = new TDEToggleAction( *it, TDEShortcut(), 0, name );
             connect( act, TQT_SIGNAL(activated()), this, TQT_SLOT(slotChangeSubType()) );
             if ( i == m_varSelected->subType() )
                 act->setChecked( true );
@@ -600,14 +600,14 @@ TQPtrList<KAction> KoVariableCollection::popupActionList() const
     for ( int i = 0; it != list.end() ; ++it, ++i )
     {
         if( i == 0 ) // first item, and list not empty
-            listAction.append( new KActionSeparator() );
+            listAction.append( new TDEActionSeparator() );
 
         if ( !(*it).isEmpty() ) // in case of removed subtypes or placeholders
         {
             format->setFormatProperties( *it ); // temporary change
             TQString text = format->convert( m_varSelected->varValue() );
             // We store the raw format as the action name
-            KToggleAction * act = new KToggleAction(text, KShortcut(), 0, (*it).utf8());
+            TDEToggleAction * act = new TDEToggleAction(text, TDEShortcut(), 0, (*it).utf8());
             connect( act, TQT_SIGNAL(activated()), this, TQT_SLOT(slotChangeFormat()) );
             if ( (*it) == currentFormat )
                 act->setChecked( true );
@@ -622,7 +622,7 @@ TQPtrList<KAction> KoVariableCollection::popupActionList() const
 
 void KoVariableCollection::slotChangeSubType()
 {
-    KAction * act = (KAction *)(sender());
+    TDEAction * act = (TDEAction *)(sender());
     int menuNumber = TQCString(act->name()).toInt();
     int newSubType = m_varSelected->variableSubType(menuNumber);
     kdDebug(32500) << "slotChangeSubType: menuNumber=" << menuNumber << " newSubType=" << newSubType << endl;
@@ -637,7 +637,7 @@ void KoVariableCollection::slotChangeSubType()
 
 void KoVariableCollection::slotChangeFormat()
 {
-    KAction * act = (KAction *)(sender());
+    TDEAction * act = (TDEAction *)(sender());
     TQString newFormat = TQString::fromUtf8(act->name());
     TQString oldFormat = m_varSelected->variableFormat()->formatProperties();
     if (oldFormat != newFormat )
@@ -1198,11 +1198,11 @@ void KoDateVariable::resize()
     TQString oldLanguage;
     if ( !fmt->language().isEmpty())
     {
-         oldLanguage=KGlobal::locale()->language();
-         bool changeLanguage = KGlobal::locale()->setLanguage( fmt->language() );
+         oldLanguage=TDEGlobal::locale()->language();
+         bool changeLanguage = TDEGlobal::locale()->setLanguage( fmt->language() );
          KoVariable::resize();
          if ( changeLanguage )
-             KGlobal::locale()->setLanguage( oldLanguage );
+             TDEGlobal::locale()->setLanguage( oldLanguage );
     }
     else
         KoVariable::resize();
@@ -1315,13 +1315,13 @@ void KoDateVariable::saveOasis( KoXmlWriter& writer, KoSavingContext& context )
          value.lower() == "localedatetimeshort" )
     {
         if ( value.lower() == "locale" || value.isEmpty())
-            value =  KGlobal::locale()->dateFormat();
+            value =  TDEGlobal::locale()->dateFormat();
         else if ( value.lower() == "localeshort" )
-            value = KGlobal::locale()->dateFormatShort();
+            value = TDEGlobal::locale()->dateFormatShort();
         else if ( value.lower() == "localedatetime" )
-            value =  TQString( "%1 %2" ).arg( KGlobal::locale()->dateFormat() ).arg( KGlobal::locale()->timeFormat() );
+            value =  TQString( "%1 %2" ).arg( TDEGlobal::locale()->dateFormat() ).arg( TDEGlobal::locale()->timeFormat() );
         else if ( value.lower() == "localedatetimeshort" )
-            value =  TQString( "%1 %2" ).arg( KGlobal::locale()->dateFormatShort() ).arg( KGlobal::locale()->timeFormat() );
+            value =  TQString( "%1 %2" ).arg( TDEGlobal::locale()->dateFormatShort() ).arg( TDEGlobal::locale()->timeFormat() );
         klocaleFormat = true;
     }
     writer.addAttribute( "style:data-style-name", KoOasisStyles::saveOasisDateStyle(context.mainStyles(), value, klocaleFormat ) );
@@ -1390,10 +1390,10 @@ TQCString KoDateVariable::formatStr(int & correct)
     DateFormatWidget* widget=new DateFormatWidget(dialog);
     int count=0;
     dialog->setMainWidget(widget);
-    KConfig* config = KoGlobal::kofficeConfig();
+    TDEConfig* config = KoGlobal::kofficeConfig();
     if( config->hasGroup("Date format history") )
     {
-        KConfigGroupSaver cgs( config, "Date format history");
+        TDEConfigGroupSaver cgs( config, "Date format history");
         const int noe=config->readNumEntry("Number Of Entries", 5);
         for(int i=0;i<noe;i++)
         {
@@ -1466,11 +1466,11 @@ void KoTimeVariable::resize()
     KoTextFormat * fmt = format();
     if ( !fmt->language().isEmpty() )
     {
-        TQString oldLanguage = KGlobal::locale()->language();
-        bool changeLanguage = KGlobal::locale()->setLanguage( fmt->language() );
+        TQString oldLanguage = TDEGlobal::locale()->language();
+        bool changeLanguage = TDEGlobal::locale()->setLanguage( fmt->language() );
         KoVariable::resize();
         if ( changeLanguage )
-            KGlobal::locale()->setLanguage( oldLanguage );
+            TDEGlobal::locale()->setLanguage( oldLanguage );
     }
     else
         KoVariable::resize();
@@ -1570,7 +1570,7 @@ void KoTimeVariable::saveOasis( KoXmlWriter& writer, KoSavingContext& context )
     bool klocaleFormat = false;
     if ( value.lower() == "locale" )
     {
-        value = KGlobal::locale()->timeFormat();
+        value = TDEGlobal::locale()->timeFormat();
         klocaleFormat = true;
     }
     writer.addAttribute( "style:data-style-name", KoOasisStyles::saveOasisTimeStyle(context.mainStyles(), m_varFormat->formatProperties(), klocaleFormat ) );
@@ -1601,11 +1601,11 @@ TQCString KoTimeVariable::formatStr(int & _correct)
     KDialogBase* dialog=new KDialogBase(0, 0, true, i18n("Time Format"), KDialogBase::Ok|KDialogBase::Cancel);
     TimeFormatWidget* widget=new TimeFormatWidget(dialog);
     dialog->setMainWidget(widget);
-    KConfig* config = KoGlobal::kofficeConfig();
+    TDEConfig* config = KoGlobal::kofficeConfig();
     int count=0;
     if( config->hasGroup("Time format history") )
     {
-        KConfigGroupSaver cgs( config, "Time format history" );
+        TDEConfigGroupSaver cgs( config, "Time format history" );
         const int noe=config->readNumEntry("Number Of Entries", 5);
         for(int i=0;i<noe;i++)
         {
@@ -2517,7 +2517,7 @@ TQString KoNoteVariable::fieldCode()
 
 TQString KoNoteVariable::createdNote() const
 {
-    return KGlobal::locale()->formatDate( m_createdNoteDate, false );
+    return TDEGlobal::locale()->formatDate( m_createdNoteDate, false );
 }
 
 void KoNoteVariable::loadOasis( const TQDomElement &elem, KoOasisContext& /*context*/ )
