@@ -26,7 +26,7 @@
 #include <tqptrlist.h>
 #include <tqmap.h>
 #include <tqobject.h>
-#include <kaction.h>
+#include <tdeaction.h>
 #include "KoRichText.h"
 #include <tqvariant.h>
 #include <koffice_export.h>
@@ -292,7 +292,7 @@ class KoVariableCollection;
 class KOTEXT_EXPORT KoVariableCollection : public TQObject
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     // Note that the KoVariableSettings becomes owned by the collection;
     // we take it as argument so that it can be subclassed though.
@@ -326,8 +326,8 @@ public:
     void setVariableSelected(KoVariable * var);
     KoVariable *selectedVariable()const {return m_varSelected;}
 
-    /// List of KActions to put into the popupmenu on a variable
-    TQPtrList<KAction> popupActionList() const;
+    /// List of TDEActions to put into the popupmenu on a variable
+    TQPtrList<TDEAction> popupActionList() const;
 
  protected slots:
     // This is here because variables and formats are not TQObjects
@@ -335,7 +335,7 @@ public:
     void slotChangeFormat();
 
  private:
-    //typedef TQMap<KAction *, int> VariableSubTextMap;
+    //typedef TQMap<TDEAction *, int> VariableSubTextMap;
     //VariableSubTextMap m_variableSubTextMap;
 
     TQPtrList<KoVariable> variables;
@@ -446,7 +446,7 @@ protected:
     TQVariant m_varValue;
     int m_ascent;
 
-    //typedef TQMap<KAction *, int> SubTextMap;
+    //typedef TQMap<TDEAction *, int> SubTextMap;
     //SubTextMap m_subTextMap;
     class Private;
     Private *d;
