@@ -181,7 +181,7 @@ Kross::Api::Object::Ptr QtObject::callSlot(Kross::Api::List::Ptr args)
     m_object->tqt_invoke(slotid, uo);
     delete [] uo;
 
-    return new Variant( TQVariant(true,0) );
+    return new Variant( TQVariant(true) );
 }
 
 Kross::Api::Object::Ptr QtObject::signalNames(Kross::Api::List::Ptr)
